/********************************************************************************
** Form generated from reading UI file 'audiowidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUDIOWIDGET_H
#define UI_AUDIOWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_AudioWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *playButton;
    QPushButton *recordButton;
    QPushButton *downloadButton;
    QSpacerItem *spacerItem;
    KUrlRequester *audioUrlRequester;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *AudioWidget)
    {
        if (AudioWidget->objectName().isEmpty())
            AudioWidget->setObjectName("AudioWidget");
        AudioWidget->resize(236, 137);
        vboxLayout = new QVBoxLayout(AudioWidget);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        playButton = new QPushButton(AudioWidget);
        playButton->setObjectName("playButton");

        hboxLayout->addWidget(playButton);

        recordButton = new QPushButton(AudioWidget);
        recordButton->setObjectName("recordButton");

        hboxLayout->addWidget(recordButton);

        downloadButton = new QPushButton(AudioWidget);
        downloadButton->setObjectName("downloadButton");

        hboxLayout->addWidget(downloadButton);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);


        vboxLayout->addLayout(hboxLayout);

        audioUrlRequester = new KUrlRequester(AudioWidget);
        audioUrlRequester->setObjectName("audioUrlRequester");

        vboxLayout->addWidget(audioUrlRequester);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(AudioWidget);

        QMetaObject::connectSlotsByName(AudioWidget);
    } // setupUi

    void retranslateUi(QWidget *AudioWidget)
    {
        playButton->setText(tr2i18n("Play", nullptr));
        recordButton->setText(tr2i18n("Record", nullptr));
#if QT_CONFIG(tooltip)
        downloadButton->setToolTip(tr2i18n("Download audio file with webservice", nullptr));
#endif // QT_CONFIG(tooltip)
        downloadButton->setText(tr2i18n("Download", nullptr));
        (void)AudioWidget;
    } // retranslateUi

};

namespace Ui {
    class AudioWidget: public Ui_AudioWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AUDIOWIDGET_H

