/********************************************************************************
** Form generated from reading UI file 'blockoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BLOCKOPTIONS_H
#define UI_BLOCKOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_BlockOptionsBase
{
public:
    QGridLayout *gridLayout;
    KComboBox *expire2;
    KComboBox *expire7;
    QLabel *l_lev2;
    KComboBox *expire1;
    QLabel *l_lev5;
    QLabel *l_lev6;
    QCheckBox *kcfg_Expire;
    KComboBox *block4;
    QCheckBox *kcfg_Block;
    KComboBox *block1;
    KComboBox *block7;
    KComboBox *expire6;
    QLabel *l_lev4;
    QLabel *l_lev7;
    KComboBox *expire5;
    KComboBox *block3;
    KComboBox *block2;
    KComboBox *expire4;
    QLabel *l_lev1;
    QSpacerItem *spacerItem;
    KComboBox *expire3;
    KComboBox *block5;
    KComboBox *block6;
    QLabel *l_lev3;
    QSpacerItem *spacerItem1;
    QLabel *label;
    QLabel *label_2;

    void setupUi(QWidget *BlockOptionsBase)
    {
        if (BlockOptionsBase->objectName().isEmpty())
            BlockOptionsBase->setObjectName("BlockOptionsBase");
        BlockOptionsBase->resize(486, 412);
        gridLayout = new QGridLayout(BlockOptionsBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(6);
        gridLayout->setVerticalSpacing(6);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        expire2 = new KComboBox(BlockOptionsBase);
        expire2->setObjectName("expire2");

        gridLayout->addWidget(expire2, 7, 2, 1, 1);

        expire7 = new KComboBox(BlockOptionsBase);
        expire7->setObjectName("expire7");

        gridLayout->addWidget(expire7, 2, 2, 1, 1);

        l_lev2 = new QLabel(BlockOptionsBase);
        l_lev2->setObjectName("l_lev2");

        gridLayout->addWidget(l_lev2, 7, 0, 1, 1);

        expire1 = new KComboBox(BlockOptionsBase);
        expire1->setObjectName("expire1");

        gridLayout->addWidget(expire1, 8, 2, 1, 1);

        l_lev5 = new QLabel(BlockOptionsBase);
        l_lev5->setObjectName("l_lev5");

        gridLayout->addWidget(l_lev5, 4, 0, 1, 1);

        l_lev6 = new QLabel(BlockOptionsBase);
        l_lev6->setObjectName("l_lev6");

        gridLayout->addWidget(l_lev6, 3, 0, 1, 1);

        kcfg_Expire = new QCheckBox(BlockOptionsBase);
        kcfg_Expire->setObjectName("kcfg_Expire");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_Expire->sizePolicy().hasHeightForWidth());
        kcfg_Expire->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_Expire, 0, 2, 1, 1);

        block4 = new KComboBox(BlockOptionsBase);
        block4->setObjectName("block4");

        gridLayout->addWidget(block4, 5, 1, 1, 1);

        kcfg_Block = new QCheckBox(BlockOptionsBase);
        kcfg_Block->setObjectName("kcfg_Block");
        sizePolicy.setHeightForWidth(kcfg_Block->sizePolicy().hasHeightForWidth());
        kcfg_Block->setSizePolicy(sizePolicy);

        gridLayout->addWidget(kcfg_Block, 0, 1, 1, 1);

        block1 = new KComboBox(BlockOptionsBase);
        block1->setObjectName("block1");

        gridLayout->addWidget(block1, 8, 1, 1, 1);

        block7 = new KComboBox(BlockOptionsBase);
        block7->setObjectName("block7");
        sizePolicy.setHeightForWidth(block7->sizePolicy().hasHeightForWidth());
        block7->setSizePolicy(sizePolicy);

        gridLayout->addWidget(block7, 2, 1, 1, 1);

        expire6 = new KComboBox(BlockOptionsBase);
        expire6->setObjectName("expire6");

        gridLayout->addWidget(expire6, 3, 2, 1, 1);

        l_lev4 = new QLabel(BlockOptionsBase);
        l_lev4->setObjectName("l_lev4");

        gridLayout->addWidget(l_lev4, 5, 0, 1, 1);

        l_lev7 = new QLabel(BlockOptionsBase);
        l_lev7->setObjectName("l_lev7");

        gridLayout->addWidget(l_lev7, 2, 0, 1, 1);

        expire5 = new KComboBox(BlockOptionsBase);
        expire5->setObjectName("expire5");

        gridLayout->addWidget(expire5, 4, 2, 1, 1);

        block3 = new KComboBox(BlockOptionsBase);
        block3->setObjectName("block3");

        gridLayout->addWidget(block3, 6, 1, 1, 1);

        block2 = new KComboBox(BlockOptionsBase);
        block2->setObjectName("block2");

        gridLayout->addWidget(block2, 7, 1, 1, 1);

        expire4 = new KComboBox(BlockOptionsBase);
        expire4->setObjectName("expire4");

        gridLayout->addWidget(expire4, 5, 2, 1, 1);

        l_lev1 = new QLabel(BlockOptionsBase);
        l_lev1->setObjectName("l_lev1");

        gridLayout->addWidget(l_lev1, 8, 0, 1, 1);

        spacerItem = new QSpacerItem(41, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 0, 1, 1);

        expire3 = new KComboBox(BlockOptionsBase);
        expire3->setObjectName("expire3");

        gridLayout->addWidget(expire3, 6, 2, 1, 1);

        block5 = new KComboBox(BlockOptionsBase);
        block5->setObjectName("block5");

        gridLayout->addWidget(block5, 4, 1, 1, 1);

        block6 = new KComboBox(BlockOptionsBase);
        block6->setObjectName("block6");
        sizePolicy.setHeightForWidth(block6->sizePolicy().hasHeightForWidth());
        block6->setSizePolicy(sizePolicy);

        gridLayout->addWidget(block6, 3, 1, 1, 1);

        l_lev3 = new QLabel(BlockOptionsBase);
        l_lev3->setObjectName("l_lev3");

        gridLayout->addWidget(l_lev3, 6, 0, 1, 1);

        spacerItem1 = new QSpacerItem(380, 30, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 10, 0, 1, 3);

        label = new QLabel(BlockOptionsBase);
        label->setObjectName("label");
        label->setWordWrap(true);

        gridLayout->addWidget(label, 1, 1, 1, 1);

        label_2 = new QLabel(BlockOptionsBase);
        label_2->setObjectName("label_2");
        label_2->setWordWrap(true);

        gridLayout->addWidget(label_2, 1, 2, 1, 1);

#if QT_CONFIG(shortcut)
        l_lev2->setBuddy(block2);
        l_lev5->setBuddy(block5);
        l_lev6->setBuddy(block6);
        l_lev4->setBuddy(block4);
        l_lev7->setBuddy(block7);
        l_lev1->setBuddy(block1);
        l_lev3->setBuddy(block3);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_Block, kcfg_Expire);
        QWidget::setTabOrder(kcfg_Expire, block7);
        QWidget::setTabOrder(block7, expire7);
        QWidget::setTabOrder(expire7, block6);
        QWidget::setTabOrder(block6, expire6);
        QWidget::setTabOrder(expire6, block5);
        QWidget::setTabOrder(block5, expire5);
        QWidget::setTabOrder(expire5, block4);
        QWidget::setTabOrder(block4, expire4);
        QWidget::setTabOrder(expire4, block3);
        QWidget::setTabOrder(block3, expire3);
        QWidget::setTabOrder(expire3, block2);
        QWidget::setTabOrder(block2, expire2);
        QWidget::setTabOrder(expire2, block1);
        QWidget::setTabOrder(block1, expire1);

        retranslateUi(BlockOptionsBase);

        QMetaObject::connectSlotsByName(BlockOptionsBase);
    } // setupUi

    void retranslateUi(QWidget *BlockOptionsBase)
    {
        l_lev2->setText(tr2i18n("Level &2:", nullptr));
        l_lev5->setText(tr2i18n("Level &5:", nullptr));
        l_lev6->setText(tr2i18n("Level &6:", nullptr));
        kcfg_Expire->setText(tr2i18n("E&xpiring", nullptr));
        kcfg_Block->setText(tr2i18n("Bl&ocking", nullptr));
        l_lev4->setText(tr2i18n("Level &4:", nullptr));
        l_lev7->setText(tr2i18n("Level &7:", nullptr));
        l_lev1->setText(tr2i18n("Level &1:", nullptr));
        l_lev3->setText(tr2i18n("Level &3:", nullptr));
        label->setText(tr2i18n("Do not practice vocabulary that has been asked within:", nullptr));
        label_2->setText(tr2i18n("Vocabulary drops one grade after this much time:", nullptr));
        (void)BlockOptionsBase;
    } // retranslateUi

};

namespace Ui {
    class BlockOptionsBase: public Ui_BlockOptionsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BLOCKOPTIONS_H

