/********************************************************************************
** Form generated from reading UI file 'browserwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BROWSERWIDGET_H
#define UI_BROWSERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_BrowserWidget
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *showCurrentButton;
    KComboBox *providerComboBox;
    QWidget *widget;
    QCheckBox *followTableCheckBox;

    void setupUi(QWidget *BrowserWidget)
    {
        if (BrowserWidget->objectName().isEmpty())
            BrowserWidget->setObjectName("BrowserWidget");
        BrowserWidget->resize(514, 535);
        vboxLayout = new QVBoxLayout(BrowserWidget);
        vboxLayout->setObjectName("vboxLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        showCurrentButton = new QPushButton(BrowserWidget);
        showCurrentButton->setObjectName("showCurrentButton");

        hboxLayout->addWidget(showCurrentButton);

        providerComboBox = new KComboBox(BrowserWidget);
        providerComboBox->setObjectName("providerComboBox");

        hboxLayout->addWidget(providerComboBox);


        vboxLayout->addLayout(hboxLayout);

        widget = new QWidget(BrowserWidget);
        widget->setObjectName("widget");

        vboxLayout->addWidget(widget);

        followTableCheckBox = new QCheckBox(BrowserWidget);
        followTableCheckBox->setObjectName("followTableCheckBox");

        vboxLayout->addWidget(followTableCheckBox);


        retranslateUi(BrowserWidget);

        QMetaObject::connectSlotsByName(BrowserWidget);
    } // setupUi

    void retranslateUi(QWidget *BrowserWidget)
    {
        showCurrentButton->setText(tr2i18n("Lookup Current", nullptr));
        followTableCheckBox->setText(tr2i18n("Follow Table", nullptr));
        (void)BrowserWidget;
    } // retranslateUi

};

namespace Ui {
    class BrowserWidget: public Ui_BrowserWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BROWSERWIDGET_H

