/********************************************************************************
** Form generated from reading UI file 'documentproperties.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DOCUMENTPROPERTIES_H
#define UI_DOCUMENTPROPERTIES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "ktextedit.h"

QT_BEGIN_NAMESPACE

class Ui_DocumentProperties
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *tiltle_group;
    QGridLayout *gridLayout;
    QLabel *label_title;
    QLineEdit *titleLineEdit;
    QLabel *label_author;
    QLineEdit *authorLineEdit;
    QLabel *label_author_2;
    QLineEdit *contactLineEdit;
    QLabel *label_remark;
    KTextEdit *commentTextEdit;
    QLabel *label;
    KComboBox *categoryComboBox;
    QLabel *label_license;
    KComboBox *licenseComboBox;
    QGroupBox *languageGroupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_language_1;
    KComboBox *firstLanguageComboBox;
    QLabel *label_language_2;
    KComboBox *secondLanguageComboBox;
    QCheckBox *grammarCheckBox;
    QCheckBox *downloadGrammarCheckBox;

    void setupUi(QWidget *DocumentProperties)
    {
        if (DocumentProperties->objectName().isEmpty())
            DocumentProperties->setObjectName("DocumentProperties");
        DocumentProperties->resize(426, 437);
        DocumentProperties->setMinimumSize(QSize(300, 200));
        verticalLayout = new QVBoxLayout(DocumentProperties);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tiltle_group = new QGroupBox(DocumentProperties);
        tiltle_group->setObjectName("tiltle_group");
        gridLayout = new QGridLayout(tiltle_group);
        gridLayout->setObjectName("gridLayout");
        label_title = new QLabel(tiltle_group);
        label_title->setObjectName("label_title");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_title->sizePolicy().hasHeightForWidth());
        label_title->setSizePolicy(sizePolicy);
        label_title->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_title, 0, 0, 1, 1);

        titleLineEdit = new QLineEdit(tiltle_group);
        titleLineEdit->setObjectName("titleLineEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(titleLineEdit->sizePolicy().hasHeightForWidth());
        titleLineEdit->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(titleLineEdit, 0, 1, 1, 1);

        label_author = new QLabel(tiltle_group);
        label_author->setObjectName("label_author");
        label_author->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_author, 1, 0, 1, 1);

        authorLineEdit = new QLineEdit(tiltle_group);
        authorLineEdit->setObjectName("authorLineEdit");
        sizePolicy1.setHeightForWidth(authorLineEdit->sizePolicy().hasHeightForWidth());
        authorLineEdit->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(authorLineEdit, 1, 1, 1, 1);

        label_author_2 = new QLabel(tiltle_group);
        label_author_2->setObjectName("label_author_2");
        label_author_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_author_2, 2, 0, 1, 1);

        contactLineEdit = new QLineEdit(tiltle_group);
        contactLineEdit->setObjectName("contactLineEdit");
        sizePolicy1.setHeightForWidth(contactLineEdit->sizePolicy().hasHeightForWidth());
        contactLineEdit->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(contactLineEdit, 2, 1, 1, 1);

        label_remark = new QLabel(tiltle_group);
        label_remark->setObjectName("label_remark");
        label_remark->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_remark, 3, 0, 1, 1);

        commentTextEdit = new KTextEdit(tiltle_group);
        commentTextEdit->setObjectName("commentTextEdit");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(commentTextEdit->sizePolicy().hasHeightForWidth());
        commentTextEdit->setSizePolicy(sizePolicy2);
        commentTextEdit->setTabChangesFocus(true);
        commentTextEdit->setAcceptRichText(false);

        gridLayout->addWidget(commentTextEdit, 3, 1, 1, 1);

        label = new QLabel(tiltle_group);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 4, 0, 1, 1);

        categoryComboBox = new KComboBox(tiltle_group);
        categoryComboBox->addItem(QString());
        categoryComboBox->addItem(QString());
        categoryComboBox->addItem(QString());
        categoryComboBox->addItem(QString());
        categoryComboBox->addItem(QString());
        categoryComboBox->addItem(QString());
        categoryComboBox->setObjectName("categoryComboBox");
        categoryComboBox->setEditable(true);

        gridLayout->addWidget(categoryComboBox, 4, 1, 1, 1);

        label_license = new QLabel(tiltle_group);
        label_license->setObjectName("label_license");
        label_license->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_license, 5, 0, 1, 1);

        licenseComboBox = new KComboBox(tiltle_group);
        licenseComboBox->addItem(QString());
        licenseComboBox->addItem(QString());
        licenseComboBox->setObjectName("licenseComboBox");
        licenseComboBox->setEditable(true);

        gridLayout->addWidget(licenseComboBox, 5, 1, 1, 1);


        verticalLayout->addWidget(tiltle_group);

        languageGroupBox = new QGroupBox(DocumentProperties);
        languageGroupBox->setObjectName("languageGroupBox");
        gridLayout_2 = new QGridLayout(languageGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        label_language_1 = new QLabel(languageGroupBox);
        label_language_1->setObjectName("label_language_1");
        label_language_1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_language_1, 0, 1, 1, 1);

        firstLanguageComboBox = new KComboBox(languageGroupBox);
        firstLanguageComboBox->setObjectName("firstLanguageComboBox");
        sizePolicy1.setHeightForWidth(firstLanguageComboBox->sizePolicy().hasHeightForWidth());
        firstLanguageComboBox->setSizePolicy(sizePolicy1);
        firstLanguageComboBox->setEditable(true);

        gridLayout_2->addWidget(firstLanguageComboBox, 0, 2, 1, 1);

        label_language_2 = new QLabel(languageGroupBox);
        label_language_2->setObjectName("label_language_2");
        label_language_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_language_2, 2, 1, 1, 1);

        secondLanguageComboBox = new KComboBox(languageGroupBox);
        secondLanguageComboBox->setObjectName("secondLanguageComboBox");
        sizePolicy1.setHeightForWidth(secondLanguageComboBox->sizePolicy().hasHeightForWidth());
        secondLanguageComboBox->setSizePolicy(sizePolicy1);
        secondLanguageComboBox->setEditable(true);
        secondLanguageComboBox->setAutoCompletion(false);

        gridLayout_2->addWidget(secondLanguageComboBox, 2, 2, 1, 1);

        grammarCheckBox = new QCheckBox(languageGroupBox);
        grammarCheckBox->setObjectName("grammarCheckBox");
        grammarCheckBox->setChecked(true);

        gridLayout_2->addWidget(grammarCheckBox, 4, 2, 1, 1);

        downloadGrammarCheckBox = new QCheckBox(languageGroupBox);
        downloadGrammarCheckBox->setObjectName("downloadGrammarCheckBox");
        downloadGrammarCheckBox->setChecked(true);

        gridLayout_2->addWidget(downloadGrammarCheckBox, 5, 2, 1, 1);


        verticalLayout->addWidget(languageGroupBox);

#if QT_CONFIG(shortcut)
        label_title->setBuddy(titleLineEdit);
        label_author->setBuddy(authorLineEdit);
        label_author_2->setBuddy(contactLineEdit);
        label_remark->setBuddy(commentTextEdit);
        label->setBuddy(categoryComboBox);
        label_license->setBuddy(licenseComboBox);
        label_language_1->setBuddy(firstLanguageComboBox);
        label_language_2->setBuddy(secondLanguageComboBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(titleLineEdit, authorLineEdit);
        QWidget::setTabOrder(authorLineEdit, contactLineEdit);
        QWidget::setTabOrder(contactLineEdit, commentTextEdit);
        QWidget::setTabOrder(commentTextEdit, categoryComboBox);
        QWidget::setTabOrder(categoryComboBox, licenseComboBox);
        QWidget::setTabOrder(licenseComboBox, firstLanguageComboBox);
        QWidget::setTabOrder(firstLanguageComboBox, secondLanguageComboBox);
        QWidget::setTabOrder(secondLanguageComboBox, grammarCheckBox);

        retranslateUi(DocumentProperties);

        QMetaObject::connectSlotsByName(DocumentProperties);
    } // setupUi

    void retranslateUi(QWidget *DocumentProperties)
    {
        DocumentProperties->setWindowTitle(tr2i18n("-", nullptr));
        tiltle_group->setTitle(tr2i18n("General Document Properties", nullptr));
        label_title->setText(tr2i18n("&Title:", nullptr));
#if QT_CONFIG(tooltip)
        titleLineEdit->setToolTip(tr2i18n("A title for your document.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_author->setText(tr2i18n("&Author:", nullptr));
#if QT_CONFIG(tooltip)
        authorLineEdit->setToolTip(tr2i18n("A title for your document.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_author_2->setText(tr2i18n("E&mail:", nullptr));
#if QT_CONFIG(tooltip)
        contactLineEdit->setToolTip(tr2i18n("A way to contact you (email or a webpage).", nullptr));
#endif // QT_CONFIG(tooltip)
        label_remark->setText(tr2i18n("&Comment:", nullptr));
#if QT_CONFIG(tooltip)
        commentTextEdit->setToolTip(tr2i18n("Any additional information.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Cate&gory:", nullptr));
        categoryComboBox->setItemText(0, tr2i18n("Languages", nullptr));
        categoryComboBox->setItemText(1, tr2i18n("Music", nullptr));
        categoryComboBox->setItemText(2, tr2i18n("Geography", nullptr));
        categoryComboBox->setItemText(3, tr2i18n("Anatomy", nullptr));
        categoryComboBox->setItemText(4, tr2i18n("History", nullptr));
        categoryComboBox->setItemText(5, tr2i18n("Test Preparation", nullptr));

#if QT_CONFIG(tooltip)
        categoryComboBox->setToolTip(tr2i18n("A general category into which your document belongs.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_license->setText(tr2i18n("&License:", nullptr));
        licenseComboBox->setItemText(0, tr2i18n("Public Domain", nullptr));
        licenseComboBox->setItemText(1, tr2i18n("GPLv2+ (GNU General Public License version 2 or later)", nullptr));

#if QT_CONFIG(tooltip)
        licenseComboBox->setToolTip(tr2i18n("The license under which your document will be.\n"
"If you consider contributing your file to KDE in the future, an appropriate license is required.", nullptr));
#endif // QT_CONFIG(tooltip)
        languageGroupBox->setTitle(tr2i18n("Languages", nullptr));
        label_language_1->setText(tr2i18n("&First language:", nullptr));
        label_language_2->setText(tr2i18n("&Second language:", nullptr));
        grammarCheckBox->setText(tr2i18n("&Setup grammar details", nullptr));
        downloadGrammarCheckBox->setText(tr2i18n("Download grammar", "Attept to download grammar properties for the selected languages"));
    } // retranslateUi

};

namespace Ui {
    class DocumentProperties: public Ui_DocumentProperties {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DOCUMENTPROPERTIES_H

