/********************************************************************************
** Form generated from reading UI file 'specificpracticeoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPECIFICPRACTICEOPTIONS_H
#define UI_SPECIFICPRACTICEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpecificPracticeOptions
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_MultipleChoiceWordTypeConsistancy;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    QSpinBox *kcfg_NumberMultipleChoiceAnswers;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *SpecificPracticeOptions)
    {
        if (SpecificPracticeOptions->objectName().isEmpty())
            SpecificPracticeOptions->setObjectName("SpecificPracticeOptions");
        SpecificPracticeOptions->resize(585, 413);
        gridLayout = new QGridLayout(SpecificPracticeOptions);
        gridLayout->setObjectName("gridLayout");
        groupBox_2 = new QGroupBox(SpecificPracticeOptions);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_MultipleChoiceWordTypeConsistancy = new QCheckBox(groupBox_2);
        kcfg_MultipleChoiceWordTypeConsistancy->setObjectName("kcfg_MultipleChoiceWordTypeConsistancy");
        kcfg_MultipleChoiceWordTypeConsistancy->setChecked(true);

        verticalLayout_2->addWidget(kcfg_MultipleChoiceWordTypeConsistancy);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");
        label_4->setLineWidth(1);
        label_4->setIndent(0);

        horizontalLayout->addWidget(label_4);

        kcfg_NumberMultipleChoiceAnswers = new QSpinBox(groupBox_2);
        kcfg_NumberMultipleChoiceAnswers->setObjectName("kcfg_NumberMultipleChoiceAnswers");
        kcfg_NumberMultipleChoiceAnswers->setMaximumSize(QSize(74, 16777215));
        kcfg_NumberMultipleChoiceAnswers->setMinimum(2);
        kcfg_NumberMultipleChoiceAnswers->setMaximum(5);
        kcfg_NumberMultipleChoiceAnswers->setValue(5);

        horizontalLayout->addWidget(kcfg_NumberMultipleChoiceAnswers);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);


        gridLayout->addWidget(groupBox_2, 0, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 2);


        retranslateUi(SpecificPracticeOptions);

        QMetaObject::connectSlotsByName(SpecificPracticeOptions);
    } // setupUi

    void retranslateUi(QWidget *SpecificPracticeOptions)
    {
        groupBox_2->setTitle(tr2i18n("Multiple Choice", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_MultipleChoiceWordTypeConsistancy->setToolTip(tr2i18n("When creating multiple choice practices, try to show answers of the same word type.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_MultipleChoiceWordTypeConsistancy->setText(tr2i18n("Use choices of the same word type", nullptr));
        label_4->setText(tr2i18n("Number of choices:", nullptr));
        (void)SpecificPracticeOptions;
    } // retranslateUi

};

namespace Ui {
    class SpecificPracticeOptions: public Ui_SpecificPracticeOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPECIFICPRACTICEOPTIONS_H

