/********************************************************************************
** Form generated from reading UI file 'viewoptionsbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VIEWOPTIONSBASE_H
#define UI_VIEWOPTIONSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <kcolorbutton.h>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ViewOptionsBase
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem;
    QGridLayout *gridLayout1;
    KFontRequester *kcfg_IPAFont;
    QLabel *IPAFontLabel;
    QGridLayout *gridLayout2;
    QLabel *gradeColorLabel;
    KColorButton *kcfg_GradeColor;
    QLabel *preGradeColorLabel;
    KColorButton *kcfg_PreGradeColor;
    QLabel *invalidUnitColorLabel;
    KColorButton *kcfg_InvalidUnitColor;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *ViewOptionsBase)
    {
        if (ViewOptionsBase->objectName().isEmpty())
            ViewOptionsBase->setObjectName("ViewOptionsBase");
        ViewOptionsBase->resize(377, 381);
        gridLayout = new QGridLayout(ViewOptionsBase);
        gridLayout->setObjectName("gridLayout");
        spacerItem = new QSpacerItem(291, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 2, 0, 1, 2);

        gridLayout1 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        gridLayout1->setContentsMargins(0, 0, 0, 0);
#endif
        gridLayout1->setObjectName("gridLayout1");
        kcfg_IPAFont = new KFontRequester(ViewOptionsBase);
        kcfg_IPAFont->setObjectName("kcfg_IPAFont");

        gridLayout1->addWidget(kcfg_IPAFont, 0, 1, 1, 1);

        IPAFontLabel = new QLabel(ViewOptionsBase);
        IPAFontLabel->setObjectName("IPAFontLabel");
        IPAFontLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout1->addWidget(IPAFontLabel, 0, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 2);

        gridLayout2 = new QGridLayout();
#ifndef UI_Q_OS_MAC
        gridLayout2->setSpacing(6);
#endif
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout2->setObjectName("gridLayout2");
        gradeColorLabel = new QLabel(ViewOptionsBase);
        gradeColorLabel->setObjectName("gradeColorLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gradeColorLabel->sizePolicy().hasHeightForWidth());
        gradeColorLabel->setSizePolicy(sizePolicy);
        gradeColorLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(gradeColorLabel, 0, 0, 1, 1);

        kcfg_GradeColor = new KColorButton(ViewOptionsBase);
        kcfg_GradeColor->setObjectName("kcfg_GradeColor");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_GradeColor->sizePolicy().hasHeightForWidth());
        kcfg_GradeColor->setSizePolicy(sizePolicy1);
        kcfg_GradeColor->setFlat(false);

        gridLayout2->addWidget(kcfg_GradeColor, 0, 1, 1, 1);

        preGradeColorLabel = new QLabel(ViewOptionsBase);
        preGradeColorLabel->setObjectName("preGradeColorLabel");
        sizePolicy.setHeightForWidth(preGradeColorLabel->sizePolicy().hasHeightForWidth());
        preGradeColorLabel->setSizePolicy(sizePolicy);
        preGradeColorLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(preGradeColorLabel, 1, 0, 1, 1);

        kcfg_PreGradeColor = new KColorButton(ViewOptionsBase);
        kcfg_PreGradeColor->setObjectName("kcfg_PreGradeColor");
        sizePolicy1.setHeightForWidth(kcfg_PreGradeColor->sizePolicy().hasHeightForWidth());
        kcfg_PreGradeColor->setSizePolicy(sizePolicy1);
        kcfg_PreGradeColor->setFlat(false);

        gridLayout2->addWidget(kcfg_PreGradeColor, 1, 1, 1, 1);

        invalidUnitColorLabel = new QLabel(ViewOptionsBase);
        invalidUnitColorLabel->setObjectName("invalidUnitColorLabel");
        sizePolicy.setHeightForWidth(invalidUnitColorLabel->sizePolicy().hasHeightForWidth());
        invalidUnitColorLabel->setSizePolicy(sizePolicy);
        invalidUnitColorLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout2->addWidget(invalidUnitColorLabel, 2, 0, 1, 1);

        kcfg_InvalidUnitColor = new KColorButton(ViewOptionsBase);
        kcfg_InvalidUnitColor->setObjectName("kcfg_InvalidUnitColor");
        sizePolicy1.setHeightForWidth(kcfg_InvalidUnitColor->sizePolicy().hasHeightForWidth());
        kcfg_InvalidUnitColor->setSizePolicy(sizePolicy1);
        kcfg_InvalidUnitColor->setFlat(false);

        gridLayout2->addWidget(kcfg_InvalidUnitColor, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(horizontalSpacer, 3, 2, 1, 1);


        gridLayout->addLayout(gridLayout2, 1, 0, 1, 2);

#if QT_CONFIG(shortcut)
        IPAFontLabel->setBuddy(kcfg_IPAFont);
        gradeColorLabel->setBuddy(kcfg_GradeColor);
        preGradeColorLabel->setBuddy(kcfg_PreGradeColor);
        invalidUnitColorLabel->setBuddy(kcfg_InvalidUnitColor);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ViewOptionsBase);

        QMetaObject::connectSlotsByName(ViewOptionsBase);
    } // setupUi

    void retranslateUi(QWidget *ViewOptionsBase)
    {
#if QT_CONFIG(whatsthis)
        kcfg_IPAFont->setWhatsThis(tr2i18n("Specify which font to use for displaying pronunciations using phonetic symbols.", nullptr));
#endif // QT_CONFIG(whatsthis)
        IPAFontLabel->setText(tr2i18n("&Pronunciation symbols font:", nullptr));
        gradeColorLabel->setText(tr2i18n("Base color for displaying grades:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_GradeColor->setToolTip(tr2i18n("Color used to display the progress", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_GradeColor->setWhatsThis(tr2i18n("Click here to change the color used to display the progress.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_GradeColor->setText(tr2i18n("&Base", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_GradeColor->setShortcut(tr2i18n("Alt+0", nullptr));
#endif // QT_CONFIG(shortcut)
        preGradeColorLabel->setText(tr2i18n("Color for displaying early progress:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PreGradeColor->setToolTip(tr2i18n("Color used to display the early progress", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_PreGradeColor->setWhatsThis(tr2i18n("Click here to change the color used to display the early progress.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_PreGradeColor->setText(tr2i18n("&Base", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_PreGradeColor->setShortcut(tr2i18n("Alt+1", nullptr));
#endif // QT_CONFIG(shortcut)
        invalidUnitColorLabel->setText(tr2i18n("Color used to display the grades:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_InvalidUnitColor->setToolTip(tr2i18n("Color used to display invalid units", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_InvalidUnitColor->setWhatsThis(tr2i18n("Click here to change the color used to display invalid units.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_InvalidUnitColor->setText(tr2i18n("&Base", nullptr));
#if QT_CONFIG(shortcut)
        kcfg_InvalidUnitColor->setShortcut(tr2i18n("Alt+2", nullptr));
#endif // QT_CONFIG(shortcut)
        (void)ViewOptionsBase;
    } // retranslateUi

};

namespace Ui {
    class ViewOptionsBase: public Ui_ViewOptionsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VIEWOPTIONSBASE_H

