/********************************************************************************
** Form generated from reading UI file 'languagepropertiespage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LANGUAGEPROPERTIESPAGE_H
#define UI_LANGUAGEPROPERTIESPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kfontrequester.h"

QT_BEGIN_NAMESPACE

class Ui_LanguagePropertiesPage
{
public:
    QHBoxLayout *horizontalLayout;
    QTabWidget *ktabwidget;
    QWidget *tab;
    QGridLayout *gridLayout_3;
    KComboBox *localeComboBox;
    QLabel *nameLabel;
    QLineEdit *identifierNameLineEdit;
    QLabel *keyboardLayoutLabel;
    KComboBox *keyboardLayoutComboBox;
    QSpacerItem *spacer_2;
    QPushButton *downloadGrammarButton;
    KComboBox *spellcheckerComboBox;
    QLabel *spellcheckerLabel;
    QLabel *localeSelectionLabel;
    KFontRequester *practiceFont;
    QLabel *fontLabel_2;
    QLabel *fontLabel_3;
    KFontRequester *editorFont;
    QWidget *tab_2;
    QGridLayout *gridLayout;
    QLabel *TextLabel3;
    QLabel *TextLabel4;
    QLabel *male_label;
    QLineEdit *def_male;
    QLabel *female_label;
    QLineEdit *def_female;
    QLineEdit *indef_female;
    QLabel *natural_label;
    QLineEdit *def_natural;
    QLineEdit *indef_natural;
    QSpacerItem *verticalSpacer;
    QLineEdit *def_natural_plural;
    QLineEdit *def_female_plural;
    QLineEdit *def_male_plural;
    QLineEdit *indef_male;
    QLineEdit *indef_male_plural;
    QLineEdit *indef_female_plural;
    QLineEdit *indef_natural_plural;
    QLabel *natural_label_2;
    QLabel *female_label_2;
    QLabel *male_label_2;
    QLabel *male_label_3;
    QLabel *male_label_4;
    QLabel *TextLabel3_2;
    QLabel *TextLabel4_2;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_3;
    QWidget *tab_3;
    QGridLayout *gridLayout_2;
    QSpacerItem *spacer;
    QSpacerItem *verticalSpacer_5;
    QLabel *TextLabel4_2_2;
    QLabel *dualLabel;
    QLabel *TextLabel4_3;
    QLabel *pers1_label;
    QLineEdit *first_singular;
    QLineEdit *dualFirstLineEdit;
    QLineEdit *first_plural;
    QLabel *pers2_label;
    QLineEdit *second_singular;
    QLineEdit *dualSecondLineEdit;
    QLineEdit *second_plural;
    QLabel *pers3_label;
    QLabel *male_c_label;
    QLineEdit *thirdM_singular;
    QLineEdit *dualThirdMaleLineEdit;
    QLineEdit *thirdM_plural;
    QLabel *female_c_label;
    QLineEdit *thirdF_singular;
    QLineEdit *dualThirdFemaleLineEdit;
    QLineEdit *thirdF_plural;
    QLabel *natural_c_label;
    QLineEdit *thirdN_singular;
    QLineEdit *dualThirdNeutralLineEdit;
    QLineEdit *thirdN_plural;
    QCheckBox *dualCheckBox;
    QCheckBox *neutralCheckBox;
    QCheckBox *maleFemaleDifferCheckBox;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout;
    QListWidget *tenseList;
    QHBoxLayout *_2;
    QPushButton *newButton;
    QPushButton *modifyButton;
    QPushButton *deleteButton;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *LanguagePropertiesPage)
    {
        if (LanguagePropertiesPage->objectName().isEmpty())
            LanguagePropertiesPage->setObjectName("LanguagePropertiesPage");
        LanguagePropertiesPage->resize(631, 556);
        horizontalLayout = new QHBoxLayout(LanguagePropertiesPage);
        horizontalLayout->setObjectName("horizontalLayout");
        ktabwidget = new QTabWidget(LanguagePropertiesPage);
        ktabwidget->setObjectName("ktabwidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_3 = new QGridLayout(tab);
        gridLayout_3->setObjectName("gridLayout_3");
        localeComboBox = new KComboBox(tab);
        localeComboBox->setObjectName("localeComboBox");

        gridLayout_3->addWidget(localeComboBox, 0, 2, 1, 2);

        nameLabel = new QLabel(tab);
        nameLabel->setObjectName("nameLabel");
        nameLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(nameLabel, 1, 0, 1, 1);

        identifierNameLineEdit = new QLineEdit(tab);
        identifierNameLineEdit->setObjectName("identifierNameLineEdit");

        gridLayout_3->addWidget(identifierNameLineEdit, 1, 2, 1, 2);

        keyboardLayoutLabel = new QLabel(tab);
        keyboardLayoutLabel->setObjectName("keyboardLayoutLabel");
        keyboardLayoutLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(keyboardLayoutLabel, 4, 0, 1, 1);

        keyboardLayoutComboBox = new KComboBox(tab);
        keyboardLayoutComboBox->setObjectName("keyboardLayoutComboBox");

        gridLayout_3->addWidget(keyboardLayoutComboBox, 4, 2, 1, 2);

        spacer_2 = new QSpacerItem(20, 169, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(spacer_2, 9, 2, 1, 1);

        downloadGrammarButton = new QPushButton(tab);
        downloadGrammarButton->setObjectName("downloadGrammarButton");
        downloadGrammarButton->setCheckable(false);

        gridLayout_3->addWidget(downloadGrammarButton, 10, 2, 1, 1);

        spellcheckerComboBox = new KComboBox(tab);
        spellcheckerComboBox->setObjectName("spellcheckerComboBox");

        gridLayout_3->addWidget(spellcheckerComboBox, 6, 2, 1, 2);

        spellcheckerLabel = new QLabel(tab);
        spellcheckerLabel->setObjectName("spellcheckerLabel");
        spellcheckerLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(spellcheckerLabel, 6, 0, 1, 1);

        localeSelectionLabel = new QLabel(tab);
        localeSelectionLabel->setObjectName("localeSelectionLabel");
        localeSelectionLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(localeSelectionLabel, 0, 0, 1, 1);

        practiceFont = new KFontRequester(tab);
        practiceFont->setObjectName("practiceFont");

        gridLayout_3->addWidget(practiceFont, 2, 2, 1, 1);

        fontLabel_2 = new QLabel(tab);
        fontLabel_2->setObjectName("fontLabel_2");
        fontLabel_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(fontLabel_2, 2, 0, 1, 1);

        fontLabel_3 = new QLabel(tab);
        fontLabel_3->setObjectName("fontLabel_3");
        fontLabel_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(fontLabel_3, 3, 0, 1, 1);

        editorFont = new KFontRequester(tab);
        editorFont->setObjectName("editorFont");

        gridLayout_3->addWidget(editorFont, 3, 2, 1, 1);

        ktabwidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout = new QGridLayout(tab_2);
        gridLayout->setObjectName("gridLayout");
        TextLabel3 = new QLabel(tab_2);
        TextLabel3->setObjectName("TextLabel3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(TextLabel3->sizePolicy().hasHeightForWidth());
        TextLabel3->setSizePolicy(sizePolicy);

        gridLayout->addWidget(TextLabel3, 0, 2, 1, 1);

        TextLabel4 = new QLabel(tab_2);
        TextLabel4->setObjectName("TextLabel4");

        gridLayout->addWidget(TextLabel4, 0, 3, 1, 1);

        male_label = new QLabel(tab_2);
        male_label->setObjectName("male_label");
        male_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(male_label, 1, 0, 1, 1);

        def_male = new QLineEdit(tab_2);
        def_male->setObjectName("def_male");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(def_male->sizePolicy().hasHeightForWidth());
        def_male->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(def_male, 1, 2, 1, 1);

        female_label = new QLabel(tab_2);
        female_label->setObjectName("female_label");
        female_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(female_label, 2, 0, 1, 1);

        def_female = new QLineEdit(tab_2);
        def_female->setObjectName("def_female");
        sizePolicy1.setHeightForWidth(def_female->sizePolicy().hasHeightForWidth());
        def_female->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(def_female, 2, 2, 1, 1);

        indef_female = new QLineEdit(tab_2);
        indef_female->setObjectName("indef_female");
        sizePolicy1.setHeightForWidth(indef_female->sizePolicy().hasHeightForWidth());
        indef_female->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(indef_female, 2, 3, 1, 1);

        natural_label = new QLabel(tab_2);
        natural_label->setObjectName("natural_label");
        natural_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(natural_label, 3, 0, 1, 1);

        def_natural = new QLineEdit(tab_2);
        def_natural->setObjectName("def_natural");
        sizePolicy1.setHeightForWidth(def_natural->sizePolicy().hasHeightForWidth());
        def_natural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(def_natural, 3, 2, 1, 1);

        indef_natural = new QLineEdit(tab_2);
        indef_natural->setObjectName("indef_natural");
        sizePolicy1.setHeightForWidth(indef_natural->sizePolicy().hasHeightForWidth());
        indef_natural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(indef_natural, 3, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 10, 2, 1, 1);

        def_natural_plural = new QLineEdit(tab_2);
        def_natural_plural->setObjectName("def_natural_plural");
        sizePolicy1.setHeightForWidth(def_natural_plural->sizePolicy().hasHeightForWidth());
        def_natural_plural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(def_natural_plural, 9, 2, 1, 1);

        def_female_plural = new QLineEdit(tab_2);
        def_female_plural->setObjectName("def_female_plural");
        sizePolicy1.setHeightForWidth(def_female_plural->sizePolicy().hasHeightForWidth());
        def_female_plural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(def_female_plural, 8, 2, 1, 1);

        def_male_plural = new QLineEdit(tab_2);
        def_male_plural->setObjectName("def_male_plural");
        sizePolicy1.setHeightForWidth(def_male_plural->sizePolicy().hasHeightForWidth());
        def_male_plural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(def_male_plural, 6, 2, 1, 1);

        indef_male = new QLineEdit(tab_2);
        indef_male->setObjectName("indef_male");
        sizePolicy1.setHeightForWidth(indef_male->sizePolicy().hasHeightForWidth());
        indef_male->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(indef_male, 1, 3, 1, 1);

        indef_male_plural = new QLineEdit(tab_2);
        indef_male_plural->setObjectName("indef_male_plural");
        sizePolicy1.setHeightForWidth(indef_male_plural->sizePolicy().hasHeightForWidth());
        indef_male_plural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(indef_male_plural, 6, 3, 1, 1);

        indef_female_plural = new QLineEdit(tab_2);
        indef_female_plural->setObjectName("indef_female_plural");
        sizePolicy1.setHeightForWidth(indef_female_plural->sizePolicy().hasHeightForWidth());
        indef_female_plural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(indef_female_plural, 8, 3, 1, 1);

        indef_natural_plural = new QLineEdit(tab_2);
        indef_natural_plural->setObjectName("indef_natural_plural");
        sizePolicy1.setHeightForWidth(indef_natural_plural->sizePolicy().hasHeightForWidth());
        indef_natural_plural->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(indef_natural_plural, 9, 3, 1, 1);

        natural_label_2 = new QLabel(tab_2);
        natural_label_2->setObjectName("natural_label_2");
        natural_label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(natural_label_2, 9, 0, 1, 1);

        female_label_2 = new QLabel(tab_2);
        female_label_2->setObjectName("female_label_2");
        female_label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(female_label_2, 8, 0, 1, 1);

        male_label_2 = new QLabel(tab_2);
        male_label_2->setObjectName("male_label_2");
        male_label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(male_label_2, 6, 0, 1, 1);

        male_label_3 = new QLabel(tab_2);
        male_label_3->setObjectName("male_label_3");
        male_label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(male_label_3, 0, 0, 1, 1);

        male_label_4 = new QLabel(tab_2);
        male_label_4->setObjectName("male_label_4");
        male_label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(male_label_4, 5, 0, 1, 1);

        TextLabel3_2 = new QLabel(tab_2);
        TextLabel3_2->setObjectName("TextLabel3_2");
        sizePolicy.setHeightForWidth(TextLabel3_2->sizePolicy().hasHeightForWidth());
        TextLabel3_2->setSizePolicy(sizePolicy);

        gridLayout->addWidget(TextLabel3_2, 5, 2, 1, 1);

        TextLabel4_2 = new QLabel(tab_2);
        TextLabel4_2->setObjectName("TextLabel4_2");

        gridLayout->addWidget(TextLabel4_2, 5, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 4, 0, 1, 1);

        ktabwidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_2 = new QGridLayout(tab_3);
        gridLayout_2->setObjectName("gridLayout_2");
        spacer = new QSpacerItem(61, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(spacer, 0, 0, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_5, 10, 1, 1, 1);

        TextLabel4_2_2 = new QLabel(tab_3);
        TextLabel4_2_2->setObjectName("TextLabel4_2_2");

        gridLayout_2->addWidget(TextLabel4_2_2, 0, 1, 1, 1);

        dualLabel = new QLabel(tab_3);
        dualLabel->setObjectName("dualLabel");

        gridLayout_2->addWidget(dualLabel, 0, 2, 1, 1);

        TextLabel4_3 = new QLabel(tab_3);
        TextLabel4_3->setObjectName("TextLabel4_3");

        gridLayout_2->addWidget(TextLabel4_3, 0, 3, 1, 1);

        pers1_label = new QLabel(tab_3);
        pers1_label->setObjectName("pers1_label");
        pers1_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(pers1_label, 1, 0, 1, 1);

        first_singular = new QLineEdit(tab_3);
        first_singular->setObjectName("first_singular");
        sizePolicy1.setHeightForWidth(first_singular->sizePolicy().hasHeightForWidth());
        first_singular->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(first_singular, 1, 1, 1, 1);

        dualFirstLineEdit = new QLineEdit(tab_3);
        dualFirstLineEdit->setObjectName("dualFirstLineEdit");

        gridLayout_2->addWidget(dualFirstLineEdit, 1, 2, 1, 1);

        first_plural = new QLineEdit(tab_3);
        first_plural->setObjectName("first_plural");
        sizePolicy1.setHeightForWidth(first_plural->sizePolicy().hasHeightForWidth());
        first_plural->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(first_plural, 1, 3, 1, 1);

        pers2_label = new QLabel(tab_3);
        pers2_label->setObjectName("pers2_label");
        pers2_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(pers2_label, 2, 0, 1, 1);

        second_singular = new QLineEdit(tab_3);
        second_singular->setObjectName("second_singular");
        sizePolicy1.setHeightForWidth(second_singular->sizePolicy().hasHeightForWidth());
        second_singular->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(second_singular, 2, 1, 1, 1);

        dualSecondLineEdit = new QLineEdit(tab_3);
        dualSecondLineEdit->setObjectName("dualSecondLineEdit");

        gridLayout_2->addWidget(dualSecondLineEdit, 2, 2, 1, 1);

        second_plural = new QLineEdit(tab_3);
        second_plural->setObjectName("second_plural");
        sizePolicy1.setHeightForWidth(second_plural->sizePolicy().hasHeightForWidth());
        second_plural->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(second_plural, 2, 3, 1, 1);

        pers3_label = new QLabel(tab_3);
        pers3_label->setObjectName("pers3_label");
        pers3_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(pers3_label, 3, 0, 1, 1);

        male_c_label = new QLabel(tab_3);
        male_c_label->setObjectName("male_c_label");
        male_c_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(male_c_label, 4, 0, 1, 1);

        thirdM_singular = new QLineEdit(tab_3);
        thirdM_singular->setObjectName("thirdM_singular");
        sizePolicy1.setHeightForWidth(thirdM_singular->sizePolicy().hasHeightForWidth());
        thirdM_singular->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(thirdM_singular, 4, 1, 1, 1);

        dualThirdMaleLineEdit = new QLineEdit(tab_3);
        dualThirdMaleLineEdit->setObjectName("dualThirdMaleLineEdit");

        gridLayout_2->addWidget(dualThirdMaleLineEdit, 4, 2, 1, 1);

        thirdM_plural = new QLineEdit(tab_3);
        thirdM_plural->setObjectName("thirdM_plural");
        sizePolicy1.setHeightForWidth(thirdM_plural->sizePolicy().hasHeightForWidth());
        thirdM_plural->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(thirdM_plural, 4, 3, 1, 1);

        female_c_label = new QLabel(tab_3);
        female_c_label->setObjectName("female_c_label");
        female_c_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(female_c_label, 5, 0, 1, 1);

        thirdF_singular = new QLineEdit(tab_3);
        thirdF_singular->setObjectName("thirdF_singular");
        sizePolicy1.setHeightForWidth(thirdF_singular->sizePolicy().hasHeightForWidth());
        thirdF_singular->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(thirdF_singular, 5, 1, 1, 1);

        dualThirdFemaleLineEdit = new QLineEdit(tab_3);
        dualThirdFemaleLineEdit->setObjectName("dualThirdFemaleLineEdit");

        gridLayout_2->addWidget(dualThirdFemaleLineEdit, 5, 2, 1, 1);

        thirdF_plural = new QLineEdit(tab_3);
        thirdF_plural->setObjectName("thirdF_plural");
        sizePolicy1.setHeightForWidth(thirdF_plural->sizePolicy().hasHeightForWidth());
        thirdF_plural->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(thirdF_plural, 5, 3, 1, 1);

        natural_c_label = new QLabel(tab_3);
        natural_c_label->setObjectName("natural_c_label");
        natural_c_label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(natural_c_label, 6, 0, 1, 1);

        thirdN_singular = new QLineEdit(tab_3);
        thirdN_singular->setObjectName("thirdN_singular");
        sizePolicy1.setHeightForWidth(thirdN_singular->sizePolicy().hasHeightForWidth());
        thirdN_singular->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(thirdN_singular, 6, 1, 1, 1);

        dualThirdNeutralLineEdit = new QLineEdit(tab_3);
        dualThirdNeutralLineEdit->setObjectName("dualThirdNeutralLineEdit");

        gridLayout_2->addWidget(dualThirdNeutralLineEdit, 6, 2, 1, 1);

        thirdN_plural = new QLineEdit(tab_3);
        thirdN_plural->setObjectName("thirdN_plural");
        sizePolicy1.setHeightForWidth(thirdN_plural->sizePolicy().hasHeightForWidth());
        thirdN_plural->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(thirdN_plural, 6, 3, 1, 1);

        dualCheckBox = new QCheckBox(tab_3);
        dualCheckBox->setObjectName("dualCheckBox");

        gridLayout_2->addWidget(dualCheckBox, 9, 1, 1, 1);

        neutralCheckBox = new QCheckBox(tab_3);
        neutralCheckBox->setObjectName("neutralCheckBox");

        gridLayout_2->addWidget(neutralCheckBox, 8, 1, 1, 2);

        maleFemaleDifferCheckBox = new QCheckBox(tab_3);
        maleFemaleDifferCheckBox->setObjectName("maleFemaleDifferCheckBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(maleFemaleDifferCheckBox->sizePolicy().hasHeightForWidth());
        maleFemaleDifferCheckBox->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(maleFemaleDifferCheckBox, 7, 1, 1, 3);

        ktabwidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout = new QVBoxLayout(tab_4);
        verticalLayout->setObjectName("verticalLayout");
        tenseList = new QListWidget(tab_4);
        tenseList->setObjectName("tenseList");
        tenseList->setSelectionBehavior(QAbstractItemView::SelectRows);

        verticalLayout->addWidget(tenseList);

        _2 = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        _2->setSpacing(6);
#endif
        _2->setContentsMargins(0, 0, 0, 0);
        _2->setObjectName("_2");
        newButton = new QPushButton(tab_4);
        newButton->setObjectName("newButton");
        sizePolicy.setHeightForWidth(newButton->sizePolicy().hasHeightForWidth());
        newButton->setSizePolicy(sizePolicy);

        _2->addWidget(newButton);

        modifyButton = new QPushButton(tab_4);
        modifyButton->setObjectName("modifyButton");
        sizePolicy.setHeightForWidth(modifyButton->sizePolicy().hasHeightForWidth());
        modifyButton->setSizePolicy(sizePolicy);

        _2->addWidget(modifyButton);

        deleteButton = new QPushButton(tab_4);
        deleteButton->setObjectName("deleteButton");
        sizePolicy.setHeightForWidth(deleteButton->sizePolicy().hasHeightForWidth());
        deleteButton->setSizePolicy(sizePolicy);

        _2->addWidget(deleteButton);

        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _2->addItem(spacerItem);


        verticalLayout->addLayout(_2);

        ktabwidget->addTab(tab_4, QString());

        horizontalLayout->addWidget(ktabwidget);

#if QT_CONFIG(shortcut)
        nameLabel->setBuddy(identifierNameLineEdit);
        keyboardLayoutLabel->setBuddy(keyboardLayoutComboBox);
        spellcheckerLabel->setBuddy(spellcheckerComboBox);
        localeSelectionLabel->setBuddy(localeComboBox);
        male_label->setBuddy(def_male);
        female_label->setBuddy(def_female);
        natural_label->setBuddy(def_natural);
        natural_label_2->setBuddy(def_natural_plural);
        female_label_2->setBuddy(def_female_plural);
        male_label_2->setBuddy(def_male_plural);
        pers1_label->setBuddy(first_singular);
        pers2_label->setBuddy(second_singular);
        male_c_label->setBuddy(thirdM_singular);
        female_c_label->setBuddy(thirdF_singular);
        natural_c_label->setBuddy(thirdN_singular);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(newButton, modifyButton);
        QWidget::setTabOrder(modifyButton, deleteButton);
        QWidget::setTabOrder(deleteButton, ktabwidget);
        QWidget::setTabOrder(ktabwidget, localeComboBox);
        QWidget::setTabOrder(localeComboBox, identifierNameLineEdit);
        QWidget::setTabOrder(identifierNameLineEdit, keyboardLayoutComboBox);
        QWidget::setTabOrder(keyboardLayoutComboBox, spellcheckerComboBox);
        QWidget::setTabOrder(spellcheckerComboBox, downloadGrammarButton);
        QWidget::setTabOrder(downloadGrammarButton, def_male);
        QWidget::setTabOrder(def_male, def_female);
        QWidget::setTabOrder(def_female, def_natural);
        QWidget::setTabOrder(def_natural, def_male_plural);
        QWidget::setTabOrder(def_male_plural, def_female_plural);
        QWidget::setTabOrder(def_female_plural, def_natural_plural);
        QWidget::setTabOrder(def_natural_plural, indef_male);
        QWidget::setTabOrder(indef_male, indef_female);
        QWidget::setTabOrder(indef_female, indef_natural);
        QWidget::setTabOrder(indef_natural, indef_male_plural);
        QWidget::setTabOrder(indef_male_plural, indef_female_plural);
        QWidget::setTabOrder(indef_female_plural, indef_natural_plural);
        QWidget::setTabOrder(indef_natural_plural, first_singular);
        QWidget::setTabOrder(first_singular, second_singular);
        QWidget::setTabOrder(second_singular, thirdM_singular);
        QWidget::setTabOrder(thirdM_singular, thirdF_singular);
        QWidget::setTabOrder(thirdF_singular, thirdN_singular);
        QWidget::setTabOrder(thirdN_singular, dualFirstLineEdit);
        QWidget::setTabOrder(dualFirstLineEdit, dualSecondLineEdit);
        QWidget::setTabOrder(dualSecondLineEdit, dualThirdMaleLineEdit);
        QWidget::setTabOrder(dualThirdMaleLineEdit, dualThirdFemaleLineEdit);
        QWidget::setTabOrder(dualThirdFemaleLineEdit, dualThirdNeutralLineEdit);
        QWidget::setTabOrder(dualThirdNeutralLineEdit, first_plural);
        QWidget::setTabOrder(first_plural, second_plural);
        QWidget::setTabOrder(second_plural, thirdM_plural);
        QWidget::setTabOrder(thirdM_plural, thirdF_plural);
        QWidget::setTabOrder(thirdF_plural, thirdN_plural);
        QWidget::setTabOrder(thirdN_plural, maleFemaleDifferCheckBox);
        QWidget::setTabOrder(maleFemaleDifferCheckBox, neutralCheckBox);
        QWidget::setTabOrder(neutralCheckBox, dualCheckBox);
        QWidget::setTabOrder(dualCheckBox, tenseList);

        retranslateUi(LanguagePropertiesPage);

        ktabwidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(LanguagePropertiesPage);
    } // setupUi

    void retranslateUi(QWidget *LanguagePropertiesPage)
    {
        nameLabel->setText(tr2i18n("Name:", nullptr));
        keyboardLayoutLabel->setText(tr2i18n("Keyboard layout:", nullptr));
        downloadGrammarButton->setText(tr2i18n("&Download grammar", nullptr));
        spellcheckerLabel->setText(tr2i18n("Spell checker:", nullptr));
        localeSelectionLabel->setText(tr2i18n("Language:", nullptr));
        fontLabel_2->setText(tr2i18n("Font (practice):", nullptr));
        fontLabel_3->setText(tr2i18n("Font (editor):", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab), tr2i18n("General", nullptr));
        TextLabel3->setText(tr2i18n("Definite", nullptr));
        TextLabel4->setText(tr2i18n("Indefinite", nullptr));
        male_label->setText(tr2i18n("&Male:", nullptr));
        female_label->setText(tr2i18n("&Female:", nullptr));
        natural_label->setText(tr2i18n("&Neutral:", nullptr));
        natural_label_2->setText(tr2i18n("&Neutral:", nullptr));
        female_label_2->setText(tr2i18n("&Female:", nullptr));
        male_label_2->setText(tr2i18n("&Male:", nullptr));
        male_label_3->setText(tr2i18n("Singular", nullptr));
        male_label_4->setText(tr2i18n("Plural", nullptr));
        TextLabel3_2->setText(tr2i18n("Definite", nullptr));
        TextLabel4_2->setText(tr2i18n("Indefinite", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab_2), tr2i18n("Articles", nullptr));
        TextLabel4_2_2->setText(tr2i18n("Singular", nullptr));
        dualLabel->setText(tr2i18n("Dual", nullptr));
        TextLabel4_3->setText(tr2i18n("Plural", nullptr));
        pers1_label->setText(tr2i18n("&1. Person:", nullptr));
        pers2_label->setText(tr2i18n("&2. Person:", nullptr));
        pers3_label->setText(tr2i18n("3. Person:", nullptr));
        male_c_label->setText(tr2i18n("M&ale:", nullptr));
        female_c_label->setText(tr2i18n("F&emale:", nullptr));
        natural_c_label->setText(tr2i18n("Neu&ter:", nullptr));
        dualCheckBox->setText(tr2i18n("Dual conjugations", nullptr));
        neutralCheckBox->setText(tr2i18n("A neutral conjugation form exists", nullptr));
        maleFemaleDifferCheckBox->setText(tr2i18n("Male/female have different conjugations", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab_3), tr2i18n("Personal Pronouns", nullptr));
        newButton->setText(tr2i18n("&New...", nullptr));
        modifyButton->setText(tr2i18n("&Modify...", nullptr));
        deleteButton->setText(tr2i18n("&Delete", nullptr));
        ktabwidget->setTabText(ktabwidget->indexOf(tab_4), tr2i18n("Tenses", nullptr));
        (void)LanguagePropertiesPage;
    } // retranslateUi

};

namespace Ui {
    class LanguagePropertiesPage: public Ui_LanguagePropertiesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LANGUAGEPROPERTIESPAGE_H

