/****************************************************************************
** Meta object code from reading C++ file 'parleydocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../parley-26.04.0/src/parleydocument.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'parleydocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ParleyDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto ParleyDocument::qt_create_metaobjectdata<qt_meta_tag_ZN14ParleyDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ParleyDocument",
        "documentChanged",
        "",
        "std::shared_ptr<KEduVocDocument>",
        "newDocument",
        "languagesChanged",
        "statesNeedSaving",
        "slotFileNew",
        "slotFileOpen",
        "slotFileOpenRecent",
        "QUrl",
        "url",
        "openGHNS",
        "slotGHNS",
        "QList<KNSCore::Entry>",
        "entries",
        "open",
        "close",
        "queryClose",
        "slotFileMerge",
        "save",
        "saveAs",
        "file",
        "exportDialog",
        "wizard",
        "documentProperties",
        "languageProperties"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentChanged'
        QtMocHelpers::SignalData<void(const std::shared_ptr<KEduVocDocument> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'languagesChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statesNeedSaving'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileNew'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileOpen'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileOpenRecent'
        QtMocHelpers::SlotData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'openGHNS'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGHNS'
        QtMocHelpers::SlotData<void(const QList<KNSCore::Entry> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<bool(const QUrl &)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'queryClose'
        QtMocHelpers::SlotData<bool()>(18, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotFileMerge'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void(QUrl)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 22 },
        }}),
        // Slot 'saveAs'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'exportDialog'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newDocument'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'documentProperties'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'languageProperties'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ParleyDocument, qt_meta_tag_ZN14ParleyDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ParleyDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ParleyDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ParleyDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ParleyDocumentE_t>.metaTypes,
    nullptr
} };

void ParleyDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ParleyDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentChanged((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<KEduVocDocument>>>(_a[1]))); break;
        case 1: _t->languagesChanged(); break;
        case 2: _t->statesNeedSaving(); break;
        case 3: _t->slotFileNew(); break;
        case 4: _t->slotFileOpen(); break;
        case 5: _t->slotFileOpenRecent((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->openGHNS(); break;
        case 7: _t->slotGHNS((*reinterpret_cast<std::add_pointer_t<QList<KNSCore::Entry>>>(_a[1]))); break;
        case 8: { bool _r = _t->open((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->close(); break;
        case 10: { bool _r = _t->queryClose();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->slotFileMerge(); break;
        case 12: _t->save(); break;
        case 13: _t->saveAs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->saveAs(); break;
        case 15: _t->exportDialog(); break;
        case 16: _t->newDocument((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->documentProperties(); break;
        case 18: _t->languageProperties(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ParleyDocument::*)(const std::shared_ptr<KEduVocDocument> & )>(_a, &ParleyDocument::documentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ParleyDocument::*)()>(_a, &ParleyDocument::languagesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ParleyDocument::*)()>(_a, &ParleyDocument::statesNeedSaving, 2))
            return;
    }
}

const QMetaObject *ParleyDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ParleyDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ParleyDocumentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ParleyDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void ParleyDocument::documentChanged(const std::shared_ptr<KEduVocDocument> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ParleyDocument::languagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ParleyDocument::statesNeedSaving()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
