/********************************************************************************
** Form generated from reading UI file 'thresholdoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THRESHOLDOPTIONS_H
#define UI_THRESHOLDOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ThresholdOptions
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *label_8;
    QGridLayout *gridLayout;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label;
    QLabel *label_4;
    QSpinBox *kcfg_PracticeMinimumTimesAsked;
    QSpinBox *kcfg_PracticeMaximumTimesAsked;
    QLabel *label_6;
    QSpinBox *kcfg_PracticeMinimumWrongCount;
    QSpinBox *kcfg_PracticeMaximumWrongCount;
    QSlider *kcfg_PracticeMinimumGrade;
    QSlider *kcfg_PracticeMaximumGrade;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ThresholdOptions)
    {
        if (ThresholdOptions->objectName().isEmpty())
            ThresholdOptions->setObjectName("ThresholdOptions");
        ThresholdOptions->resize(597, 395);
        vboxLayout = new QVBoxLayout(ThresholdOptions);
        vboxLayout->setObjectName("vboxLayout");
        label_8 = new QLabel(ThresholdOptions);
        label_8->setObjectName("label_8");

        vboxLayout->addWidget(label_8);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(ThresholdOptions);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 1, 1, 1);

        label_3 = new QLabel(ThresholdOptions);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 0, 2, 1, 1);

        label = new QLabel(ThresholdOptions);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        label_4 = new QLabel(ThresholdOptions);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 2, 0, 1, 1);

        kcfg_PracticeMinimumTimesAsked = new QSpinBox(ThresholdOptions);
        kcfg_PracticeMinimumTimesAsked->setObjectName("kcfg_PracticeMinimumTimesAsked");
        kcfg_PracticeMinimumTimesAsked->setMaximum(1000);

        gridLayout->addWidget(kcfg_PracticeMinimumTimesAsked, 2, 1, 1, 1);

        kcfg_PracticeMaximumTimesAsked = new QSpinBox(ThresholdOptions);
        kcfg_PracticeMaximumTimesAsked->setObjectName("kcfg_PracticeMaximumTimesAsked");
        kcfg_PracticeMaximumTimesAsked->setMaximum(1000);
        kcfg_PracticeMaximumTimesAsked->setValue(1000);

        gridLayout->addWidget(kcfg_PracticeMaximumTimesAsked, 2, 2, 1, 1);

        label_6 = new QLabel(ThresholdOptions);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 3, 0, 1, 1);

        kcfg_PracticeMinimumWrongCount = new QSpinBox(ThresholdOptions);
        kcfg_PracticeMinimumWrongCount->setObjectName("kcfg_PracticeMinimumWrongCount");
        kcfg_PracticeMinimumWrongCount->setMaximum(1000);

        gridLayout->addWidget(kcfg_PracticeMinimumWrongCount, 3, 1, 1, 1);

        kcfg_PracticeMaximumWrongCount = new QSpinBox(ThresholdOptions);
        kcfg_PracticeMaximumWrongCount->setObjectName("kcfg_PracticeMaximumWrongCount");
        kcfg_PracticeMaximumWrongCount->setMaximum(1000);
        kcfg_PracticeMaximumWrongCount->setValue(1000);

        gridLayout->addWidget(kcfg_PracticeMaximumWrongCount, 3, 2, 1, 1);

        kcfg_PracticeMinimumGrade = new QSlider(ThresholdOptions);
        kcfg_PracticeMinimumGrade->setObjectName("kcfg_PracticeMinimumGrade");
        kcfg_PracticeMinimumGrade->setMaximum(7);
        kcfg_PracticeMinimumGrade->setPageStep(8);
        kcfg_PracticeMinimumGrade->setSliderPosition(0);
        kcfg_PracticeMinimumGrade->setOrientation(Qt::Horizontal);
        kcfg_PracticeMinimumGrade->setTickPosition(QSlider::TicksBelow);
        kcfg_PracticeMinimumGrade->setTickInterval(1);

        gridLayout->addWidget(kcfg_PracticeMinimumGrade, 1, 1, 1, 1);

        kcfg_PracticeMaximumGrade = new QSlider(ThresholdOptions);
        kcfg_PracticeMaximumGrade->setObjectName("kcfg_PracticeMaximumGrade");
        kcfg_PracticeMaximumGrade->setMaximum(7);
        kcfg_PracticeMaximumGrade->setPageStep(8);
        kcfg_PracticeMaximumGrade->setValue(7);
        kcfg_PracticeMaximumGrade->setOrientation(Qt::Horizontal);
        kcfg_PracticeMaximumGrade->setTickPosition(QSlider::TicksBelow);
        kcfg_PracticeMaximumGrade->setTickInterval(1);

        gridLayout->addWidget(kcfg_PracticeMaximumGrade, 1, 2, 1, 1);


        vboxLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(verticalSpacer);


        retranslateUi(ThresholdOptions);

        QMetaObject::connectSlotsByName(ThresholdOptions);
    } // setupUi

    void retranslateUi(QWidget *ThresholdOptions)
    {
        label_8->setText(tr2i18n("Only practice vocabulary that fulfills the following conditions:", nullptr));
        label_2->setText(tr2i18n("At least", nullptr));
        label_3->setText(tr2i18n("At most", nullptr));
        label->setText(tr2i18n("Grade:", nullptr));
        label_4->setText(tr2i18n("Times practiced:", nullptr));
        label_6->setText(tr2i18n("Answered incorrectly:", nullptr));
        (void)ThresholdOptions;
    } // retranslateUi

};

namespace Ui {
    class ThresholdOptions: public Ui_ThresholdOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // THRESHOLDOPTIONS_H

