/********************************************************************************
** Form generated from reading UI file 'practice_mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRACTICE_MAINWINDOW_H
#define UI_PRACTICE_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "practice/boxeswidget.h"
#include "practice/imagewidget.h"
#include "practice/statustoggle.h"

QT_BEGIN_NAMESPACE

class Ui_PracticeMainWindow
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *lessonLabel;
    QLabel *gradeLabel;
    QSpacerItem *verticalSpacer;
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer_12;
    QSpacerItem *horizontalSpacer_13;
    QSpacerItem *horizontalSpacer_14;
    QVBoxLayout *verticalLayout_11;
    QSpacerItem *verticalSpacer_4;
    QWidget *rightContainer;
    QVBoxLayout *verticalLayout_2;
    Practice::StatusToggle *statusToggle;
    QPushButton *answerLaterButton;
    QPushButton *hintButton;
    QSpacerItem *verticalSpacer_5;
    QSpacerItem *horizontalSpacer_15;
    QWidget *centralPracticeWidget;
    QStackedWidget *buttonStack;
    QWidget *page;
    QVBoxLayout *verticalLayout_3;
    QPushButton *continueButton;
    QWidget *page_2;
    QHBoxLayout *horizontalLayout;
    QPushButton *countAsWrongButton;
    QPushButton *countAsCorrectButton;
    Practice::ImageWidget *imageWidget;
    QHBoxLayout *horizontalLayout_2;
    Practice::BoxesWidget *boxesWidget;
    QVBoxLayout *verticalLayout_4;
    QSpacerItem *verticalSpacer_2;
    QProgressBar *totalProgress;

    void setupUi(QWidget *PracticeMainWindow)
    {
        if (PracticeMainWindow->objectName().isEmpty())
            PracticeMainWindow->setObjectName("PracticeMainWindow");
        PracticeMainWindow->resize(871, 604);
        verticalLayout = new QVBoxLayout(PracticeMainWindow);
        verticalLayout->setObjectName("verticalLayout");
        lessonLabel = new QLabel(PracticeMainWindow);
        lessonLabel->setObjectName("lessonLabel");
        lessonLabel->setText(QString::fromUtf8("Unit 2: Nature Destroyed"));
        lessonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout->addWidget(lessonLabel);

        gradeLabel = new QLabel(PracticeMainWindow);
        gradeLabel->setObjectName("gradeLabel");
        gradeLabel->setText(QString::fromUtf8("pregrade/grade"));
        gradeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        verticalLayout->addWidget(gradeLabel);

        verticalSpacer = new QSpacerItem(20, 143, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_12, 0, 0, 1, 1);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_13, 0, 2, 1, 1);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_14, 0, 4, 1, 1);

        verticalLayout_11 = new QVBoxLayout();
        verticalLayout_11->setObjectName("verticalLayout_11");
        verticalSpacer_4 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_4);

        rightContainer = new QWidget(PracticeMainWindow);
        rightContainer->setObjectName("rightContainer");
        verticalLayout_2 = new QVBoxLayout(rightContainer);
        verticalLayout_2->setObjectName("verticalLayout_2");
        statusToggle = new Practice::StatusToggle(rightContainer);
        statusToggle->setObjectName("statusToggle");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(statusToggle->sizePolicy().hasHeightForWidth());
        statusToggle->setSizePolicy(sizePolicy);
        statusToggle->setMinimumSize(QSize(128, 128));

        verticalLayout_2->addWidget(statusToggle);

        answerLaterButton = new QPushButton(rightContainer);
        answerLaterButton->setObjectName("answerLaterButton");
        answerLaterButton->setFocusPolicy(Qt::TabFocus);

        verticalLayout_2->addWidget(answerLaterButton);

        hintButton = new QPushButton(rightContainer);
        hintButton->setObjectName("hintButton");
        hintButton->setFocusPolicy(Qt::TabFocus);

        verticalLayout_2->addWidget(hintButton);


        verticalLayout_11->addWidget(rightContainer);

        verticalSpacer_5 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_11->addItem(verticalSpacer_5);


        gridLayout->addLayout(verticalLayout_11, 0, 5, 1, 1);

        horizontalSpacer_15 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_15, 0, 6, 1, 1);

        centralPracticeWidget = new QWidget(PracticeMainWindow);
        centralPracticeWidget->setObjectName("centralPracticeWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(centralPracticeWidget->sizePolicy().hasHeightForWidth());
        centralPracticeWidget->setSizePolicy(sizePolicy1);
        centralPracticeWidget->setMinimumSize(QSize(200, 100));

        gridLayout->addWidget(centralPracticeWidget, 0, 3, 1, 1);

        buttonStack = new QStackedWidget(PracticeMainWindow);
        buttonStack->setObjectName("buttonStack");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout_3 = new QVBoxLayout(page);
        verticalLayout_3->setObjectName("verticalLayout_3");
        continueButton = new QPushButton(page);
        continueButton->setObjectName("continueButton");
        continueButton->setAutoDefault(true);

        verticalLayout_3->addWidget(continueButton);

        buttonStack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        horizontalLayout = new QHBoxLayout(page_2);
        horizontalLayout->setObjectName("horizontalLayout");
        countAsWrongButton = new QPushButton(page_2);
        countAsWrongButton->setObjectName("countAsWrongButton");

        horizontalLayout->addWidget(countAsWrongButton);

        countAsCorrectButton = new QPushButton(page_2);
        countAsCorrectButton->setObjectName("countAsCorrectButton");

        horizontalLayout->addWidget(countAsCorrectButton);

        buttonStack->addWidget(page_2);

        gridLayout->addWidget(buttonStack, 1, 3, 1, 1);

        imageWidget = new Practice::ImageWidget(PracticeMainWindow);
        imageWidget->setObjectName("imageWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(imageWidget->sizePolicy().hasHeightForWidth());
        imageWidget->setSizePolicy(sizePolicy2);
        imageWidget->setMinimumSize(QSize(150, 150));
        imageWidget->setMaximumSize(QSize(400, 400));

        gridLayout->addWidget(imageWidget, 0, 1, 1, 1);

        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(1, 2);
        gridLayout->setColumnStretch(2, 1);
        gridLayout->setColumnStretch(3, 6);
        gridLayout->setColumnStretch(4, 1);
        gridLayout->setColumnStretch(5, 1);
        gridLayout->setColumnStretch(6, 1);

        verticalLayout->addLayout(gridLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        boxesWidget = new Practice::BoxesWidget(PracticeMainWindow);
        boxesWidget->setObjectName("boxesWidget");
        sizePolicy2.setHeightForWidth(boxesWidget->sizePolicy().hasHeightForWidth());
        boxesWidget->setSizePolicy(sizePolicy2);
        boxesWidget->setMinimumSize(QSize(5, 5));

        horizontalLayout_2->addWidget(boxesWidget);

        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalSpacer_2 = new QSpacerItem(20, 143, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);

        totalProgress = new QProgressBar(PracticeMainWindow);
        totalProgress->setObjectName("totalProgress");
        totalProgress->setMaximum(258);
        totalProgress->setValue(24);

        verticalLayout_4->addWidget(totalProgress);


        horizontalLayout_2->addLayout(verticalLayout_4);


        verticalLayout->addLayout(horizontalLayout_2);


        retranslateUi(PracticeMainWindow);

        buttonStack->setCurrentIndex(1);
        continueButton->setDefault(true);


        QMetaObject::connectSlotsByName(PracticeMainWindow);
    } // setupUi

    void retranslateUi(QWidget *PracticeMainWindow)
    {
#if QT_CONFIG(tooltip)
        answerLaterButton->setToolTip(tr2i18n("Skip this word for now and ask again later", nullptr));
#endif // QT_CONFIG(tooltip)
        answerLaterButton->setText(tr2i18n("Answer Later", nullptr));
        hintButton->setText(tr2i18n("Hint", nullptr));
        continueButton->setText(tr2i18n("Continue", nullptr));
        countAsWrongButton->setText(tr2i18n("I Did not Know it", nullptr));
        countAsCorrectButton->setText(tr2i18n("I Knew it", nullptr));
        totalProgress->setFormat(tr2i18n("%v/%m", nullptr));
        (void)PracticeMainWindow;
    } // retranslateUi

};

namespace Ui {
    class PracticeMainWindow: public Ui_PracticeMainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRACTICE_MAINWINDOW_H

