/********************************************************************************
** Form generated from reading UI file 'practice_widget_conjugation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRACTICE_WIDGET_CONJUGATION_H
#define UI_PRACTICE_WIDGET_CONJUGATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConjugationPracticeWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *tenseLabel;
    QGridLayout *conjugationsLayout;
    QLabel *questionLabel;
    QLineEdit *infinitiveEdit;
    QLabel *solutionLabel;
    QLabel *feedbackLabel;
    QLabel *helpLabel;

    void setupUi(QWidget *ConjugationPracticeWidget)
    {
        if (ConjugationPracticeWidget->objectName().isEmpty())
            ConjugationPracticeWidget->setObjectName("ConjugationPracticeWidget");
        ConjugationPracticeWidget->resize(340, 218);
        verticalLayout = new QVBoxLayout(ConjugationPracticeWidget);
        verticalLayout->setObjectName("verticalLayout");
        tenseLabel = new QLabel(ConjugationPracticeWidget);
        tenseLabel->setObjectName("tenseLabel");
        tenseLabel->setText(QString::fromUtf8("Pr\303\244sens"));
        tenseLabel->setAlignment(Qt::AlignCenter);
        tenseLabel->setWordWrap(true);

        verticalLayout->addWidget(tenseLabel);

        conjugationsLayout = new QGridLayout();
        conjugationsLayout->setObjectName("conjugationsLayout");
        questionLabel = new QLabel(ConjugationPracticeWidget);
        questionLabel->setObjectName("questionLabel");
        questionLabel->setText(QString::fromUtf8("to go"));
        questionLabel->setAlignment(Qt::AlignCenter);
        questionLabel->setWordWrap(true);
        questionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        conjugationsLayout->addWidget(questionLabel, 1, 0, 1, 1);

        infinitiveEdit = new QLineEdit(ConjugationPracticeWidget);
        infinitiveEdit->setObjectName("infinitiveEdit");
        infinitiveEdit->setText(QString::fromUtf8("gehen"));
        infinitiveEdit->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        infinitiveEdit->setReadOnly(true);
        infinitiveEdit->setProperty("trapEnterKeyEvent", QVariant(true));

        conjugationsLayout->addWidget(infinitiveEdit, 1, 1, 1, 1);

        solutionLabel = new QLabel(ConjugationPracticeWidget);
        solutionLabel->setObjectName("solutionLabel");
        solutionLabel->setText(QString::fromUtf8(""));
        solutionLabel->setAlignment(Qt::AlignCenter);
        solutionLabel->setWordWrap(true);
        solutionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        conjugationsLayout->addWidget(solutionLabel, 1, 2, 1, 1);


        verticalLayout->addLayout(conjugationsLayout);

        feedbackLabel = new QLabel(ConjugationPracticeWidget);
        feedbackLabel->setObjectName("feedbackLabel");

        verticalLayout->addWidget(feedbackLabel);

        helpLabel = new QLabel(ConjugationPracticeWidget);
        helpLabel->setObjectName("helpLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(helpLabel->sizePolicy().hasHeightForWidth());
        helpLabel->setSizePolicy(sizePolicy);
        helpLabel->setText(QString::fromUtf8(""));
        helpLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        helpLabel->setWordWrap(true);

        verticalLayout->addWidget(helpLabel);


        retranslateUi(ConjugationPracticeWidget);

        QMetaObject::connectSlotsByName(ConjugationPracticeWidget);
    } // setupUi

    void retranslateUi(QWidget *ConjugationPracticeWidget)
    {
        feedbackLabel->setText(QString());
        (void)ConjugationPracticeWidget;
    } // retranslateUi

};

namespace Ui {
    class ConjugationPracticeWidget: public Ui_ConjugationPracticeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRACTICE_WIDGET_CONJUGATION_H

