/********************************************************************************
** Form generated from reading UI file 'practice_widget_written.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRACTICE_WIDGET_WRITTEN_H
#define UI_PRACTICE_WIDGET_WRITTEN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "practice/audiobutton.h"

QT_BEGIN_NAMESPACE

class Ui_WrittenPracticeWidget
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_2;
    QGridLayout *gridLayout;
    QLabel *questionLabel;
    QLabel *questionPronunciationLabel;
    Practice::AudioButton *questionSoundButton;
    QLabel *mixedSolutionLabel;
    QLabel *solutionLabel;
    QLabel *solutionPronunciationLabel;
    Practice::AudioButton *solutionSoundButton;
    QVBoxLayout *synonymList;
    QLineEdit *answerEdit;
    QLabel *helpLabel;

    void setupUi(QWidget *WrittenPracticeWidget)
    {
        if (WrittenPracticeWidget->objectName().isEmpty())
            WrittenPracticeWidget->setObjectName("WrittenPracticeWidget");
        WrittenPracticeWidget->resize(549, 460);
        verticalLayout = new QVBoxLayout(WrittenPracticeWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        questionLabel = new QLabel(WrittenPracticeWidget);
        questionLabel->setObjectName("questionLabel");
        questionLabel->setText(QString::fromUtf8("Baum"));
        questionLabel->setAlignment(Qt::AlignCenter);
        questionLabel->setWordWrap(true);
        questionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        gridLayout->addWidget(questionLabel, 0, 0, 1, 1);

        questionPronunciationLabel = new QLabel(WrittenPracticeWidget);
        questionPronunciationLabel->setObjectName("questionPronunciationLabel");
        questionPronunciationLabel->setText(QString::fromUtf8("[foo]"));
        questionPronunciationLabel->setAlignment(Qt::AlignCenter);
        questionPronunciationLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        gridLayout->addWidget(questionPronunciationLabel, 0, 1, 1, 1);

        questionSoundButton = new Practice::AudioButton(WrittenPracticeWidget);
        questionSoundButton->setObjectName("questionSoundButton");
        questionSoundButton->setText(QString::fromUtf8("..."));
        questionSoundButton->setIconSize(QSize(40, 40));

        gridLayout->addWidget(questionSoundButton, 0, 2, 1, 1);

        mixedSolutionLabel = new QLabel(WrittenPracticeWidget);
        mixedSolutionLabel->setObjectName("mixedSolutionLabel");
        mixedSolutionLabel->setText(QString::fromUtf8("Baum"));
        mixedSolutionLabel->setAlignment(Qt::AlignCenter);
        mixedSolutionLabel->setWordWrap(true);
        mixedSolutionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        gridLayout->addWidget(mixedSolutionLabel, 1, 0, 1, 1);

        solutionLabel = new QLabel(WrittenPracticeWidget);
        solutionLabel->setObjectName("solutionLabel");
        solutionLabel->setText(QString::fromUtf8("tree"));
        solutionLabel->setAlignment(Qt::AlignCenter);
        solutionLabel->setWordWrap(true);
        solutionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        gridLayout->addWidget(solutionLabel, 2, 0, 1, 1);

        solutionPronunciationLabel = new QLabel(WrittenPracticeWidget);
        solutionPronunciationLabel->setObjectName("solutionPronunciationLabel");
        solutionPronunciationLabel->setText(QString::fromUtf8("[foo]"));
        solutionPronunciationLabel->setAlignment(Qt::AlignCenter);
        solutionPronunciationLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        gridLayout->addWidget(solutionPronunciationLabel, 2, 1, 1, 1);

        solutionSoundButton = new Practice::AudioButton(WrittenPracticeWidget);
        solutionSoundButton->setObjectName("solutionSoundButton");
        solutionSoundButton->setText(QString::fromUtf8("..."));
        solutionSoundButton->setIconSize(QSize(40, 40));

        gridLayout->addWidget(solutionSoundButton, 2, 2, 1, 1);

        synonymList = new QVBoxLayout();
        synonymList->setObjectName("synonymList");

        gridLayout->addLayout(synonymList, 3, 0, 1, 1);

        answerEdit = new QLineEdit(WrittenPracticeWidget);
        answerEdit->setObjectName("answerEdit");
        answerEdit->setText(QString::fromUtf8("tree"));
        answerEdit->setAlignment(Qt::AlignCenter);
        answerEdit->setProperty("trapEnterKeyEvent", QVariant(true));

        gridLayout->addWidget(answerEdit, 4, 0, 1, 1);

        gridLayout->setColumnStretch(0, 1);

        verticalLayout->addLayout(gridLayout);

        helpLabel = new QLabel(WrittenPracticeWidget);
        helpLabel->setObjectName("helpLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(helpLabel->sizePolicy().hasHeightForWidth());
        helpLabel->setSizePolicy(sizePolicy);
        helpLabel->setText(QString::fromUtf8("Waiting for an answer..."));
        helpLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        helpLabel->setWordWrap(true);

        verticalLayout->addWidget(helpLabel);


        retranslateUi(WrittenPracticeWidget);

        QMetaObject::connectSlotsByName(WrittenPracticeWidget);
    } // setupUi

    void retranslateUi(QWidget *WrittenPracticeWidget)
    {
        (void)WrittenPracticeWidget;
    } // retranslateUi

};

namespace Ui {
    class WrittenPracticeWidget: public Ui_WrittenPracticeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRACTICE_WIDGET_WRITTEN_H

