/****************************************************************************
** Meta object code from reading C++ file 'parleymainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../parley-26.04.0/src/parleymainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'parleymainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ParleyMainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto ParleyMainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN16ParleyMainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ParleyMainWindow",
        "recentFilesChanged",
        "",
        "preferencesChanged",
        "documentUpdated",
        "std::shared_ptr<KEduVocDocument>",
        "doc",
        "slotFileNew",
        "slotUpdateWindowCaption",
        "queryClose",
        "removeRecentFile",
        "QUrl",
        "url",
        "slotGeneralOptions",
        "slotApplyPreferences",
        "slotCloseDocument",
        "configurePractice",
        "startPractice",
        "showPracticeSummary",
        "practiceFinished",
        "showDashboard",
        "showEditor",
        "showPractice",
        "showPracticeConfiguration",
        "switchComponent",
        "ParleyMainWindow::Component",
        "component",
        "showDocumentActions",
        "open",
        "edit",
        "setVisibleToolbar",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'recentFilesChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferencesChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'documentUpdated'
        QtMocHelpers::SlotData<void(const std::shared_ptr<KEduVocDocument> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'slotFileNew'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateWindowCaption'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'queryClose'
        QtMocHelpers::SlotData<bool()>(9, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'removeRecentFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'slotGeneralOptions'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotApplyPreferences'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseDocument'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configurePractice'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startPractice'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPracticeSummary'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'practiceFinished'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showDashboard'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showEditor'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPractice'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showPracticeConfiguration'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchComponent'
        QtMocHelpers::SlotData<void(ParleyMainWindow::Component)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'showDocumentActions'
        QtMocHelpers::SlotData<void(bool, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 }, { QMetaType::Bool, 29 },
        }}),
        // Slot 'setVisibleToolbar'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ParleyMainWindow, qt_meta_tag_ZN16ParleyMainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ParleyMainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ParleyMainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ParleyMainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ParleyMainWindowE_t>.metaTypes,
    nullptr
} };

void ParleyMainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ParleyMainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->recentFilesChanged(); break;
        case 1: _t->preferencesChanged(); break;
        case 2: _t->documentUpdated((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<KEduVocDocument>>>(_a[1]))); break;
        case 3: _t->slotFileNew(); break;
        case 4: _t->slotUpdateWindowCaption(); break;
        case 5: { bool _r = _t->queryClose();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->removeRecentFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->slotGeneralOptions(); break;
        case 8: _t->slotApplyPreferences(); break;
        case 9: _t->slotCloseDocument(); break;
        case 10: _t->configurePractice(); break;
        case 11: _t->startPractice(); break;
        case 12: _t->showPracticeSummary(); break;
        case 13: _t->practiceFinished(); break;
        case 14: _t->showDashboard(); break;
        case 15: _t->showEditor(); break;
        case 16: _t->showPractice(); break;
        case 17: _t->showPracticeConfiguration(); break;
        case 18: _t->switchComponent((*reinterpret_cast<std::add_pointer_t<ParleyMainWindow::Component>>(_a[1]))); break;
        case 19: _t->showDocumentActions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->setVisibleToolbar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ParleyMainWindow::*)()>(_a, &ParleyMainWindow::recentFilesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ParleyMainWindow::*)()>(_a, &ParleyMainWindow::preferencesChanged, 1))
            return;
    }
}

const QMetaObject *ParleyMainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ParleyMainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ParleyMainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int ParleyMainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void ParleyMainWindow::recentFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ParleyMainWindow::preferencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
