/********************************************************************************
** Form generated from reading UI file 'practice_widget_comparison.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRACTICE_WIDGET_COMPARISON_H
#define UI_PRACTICE_WIDGET_COMPARISON_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ComparisonPracticeWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *questionLabel;
    QGridLayout *conjugationsLayout;
    QLabel *absoluteLabel;
    QLineEdit *absoluteEdit;
    QLabel *absoluteSolutionLabel;
    QLabel *comparativeLabel;
    QLineEdit *comparativeEdit;
    QLabel *comparativeSolutionLabel;
    QLabel *superlativeLabel;
    QLineEdit *superlativeEdit;
    QLabel *superlativeSolutionLabel;
    QLabel *feedbackLabel;
    QLabel *helpLabel;

    void setupUi(QWidget *ComparisonPracticeWidget)
    {
        if (ComparisonPracticeWidget->objectName().isEmpty())
            ComparisonPracticeWidget->setObjectName("ComparisonPracticeWidget");
        ComparisonPracticeWidget->resize(340, 218);
        verticalLayout = new QVBoxLayout(ComparisonPracticeWidget);
        verticalLayout->setObjectName("verticalLayout");
        questionLabel = new QLabel(ComparisonPracticeWidget);
        questionLabel->setObjectName("questionLabel");
        questionLabel->setAlignment(Qt::AlignCenter);
        questionLabel->setWordWrap(true);
        questionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        verticalLayout->addWidget(questionLabel);

        conjugationsLayout = new QGridLayout();
        conjugationsLayout->setObjectName("conjugationsLayout");
        absoluteLabel = new QLabel(ComparisonPracticeWidget);
        absoluteLabel->setObjectName("absoluteLabel");
        absoluteLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        absoluteLabel->setWordWrap(true);

        conjugationsLayout->addWidget(absoluteLabel, 1, 0, 1, 1);

        absoluteEdit = new QLineEdit(ComparisonPracticeWidget);
        absoluteEdit->setObjectName("absoluteEdit");
        absoluteEdit->setText(QString::fromUtf8("good"));
        absoluteEdit->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        absoluteEdit->setReadOnly(false);
        absoluteEdit->setProperty("trapEnterKeyEvent", QVariant(true));

        conjugationsLayout->addWidget(absoluteEdit, 1, 2, 1, 1);

        absoluteSolutionLabel = new QLabel(ComparisonPracticeWidget);
        absoluteSolutionLabel->setObjectName("absoluteSolutionLabel");
        absoluteSolutionLabel->setText(QString::fromUtf8(""));
        absoluteSolutionLabel->setAlignment(Qt::AlignCenter);
        absoluteSolutionLabel->setWordWrap(true);
        absoluteSolutionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        conjugationsLayout->addWidget(absoluteSolutionLabel, 1, 3, 1, 1);

        comparativeLabel = new QLabel(ComparisonPracticeWidget);
        comparativeLabel->setObjectName("comparativeLabel");
        comparativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        comparativeLabel->setWordWrap(true);

        conjugationsLayout->addWidget(comparativeLabel, 2, 0, 1, 1);

        comparativeEdit = new QLineEdit(ComparisonPracticeWidget);
        comparativeEdit->setObjectName("comparativeEdit");
        comparativeEdit->setText(QString::fromUtf8("better"));
        comparativeEdit->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        comparativeEdit->setReadOnly(false);
        comparativeEdit->setProperty("trapEnterKeyEvent", QVariant(true));

        conjugationsLayout->addWidget(comparativeEdit, 2, 2, 1, 1);

        comparativeSolutionLabel = new QLabel(ComparisonPracticeWidget);
        comparativeSolutionLabel->setObjectName("comparativeSolutionLabel");
        comparativeSolutionLabel->setText(QString::fromUtf8(""));
        comparativeSolutionLabel->setAlignment(Qt::AlignCenter);
        comparativeSolutionLabel->setWordWrap(true);
        comparativeSolutionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        conjugationsLayout->addWidget(comparativeSolutionLabel, 2, 3, 1, 1);

        superlativeLabel = new QLabel(ComparisonPracticeWidget);
        superlativeLabel->setObjectName("superlativeLabel");
        superlativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        superlativeLabel->setWordWrap(true);

        conjugationsLayout->addWidget(superlativeLabel, 3, 0, 1, 1);

        superlativeEdit = new QLineEdit(ComparisonPracticeWidget);
        superlativeEdit->setObjectName("superlativeEdit");
        superlativeEdit->setText(QString::fromUtf8("best"));
        superlativeEdit->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        superlativeEdit->setReadOnly(false);
        superlativeEdit->setProperty("trapEnterKeyEvent", QVariant(true));

        conjugationsLayout->addWidget(superlativeEdit, 3, 2, 1, 1);

        superlativeSolutionLabel = new QLabel(ComparisonPracticeWidget);
        superlativeSolutionLabel->setObjectName("superlativeSolutionLabel");
        superlativeSolutionLabel->setText(QString::fromUtf8(""));
        superlativeSolutionLabel->setAlignment(Qt::AlignCenter);
        superlativeSolutionLabel->setWordWrap(true);
        superlativeSolutionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse|Qt::TextSelectableByKeyboard);

        conjugationsLayout->addWidget(superlativeSolutionLabel, 3, 3, 1, 1);


        verticalLayout->addLayout(conjugationsLayout);

        feedbackLabel = new QLabel(ComparisonPracticeWidget);
        feedbackLabel->setObjectName("feedbackLabel");

        verticalLayout->addWidget(feedbackLabel);

        helpLabel = new QLabel(ComparisonPracticeWidget);
        helpLabel->setObjectName("helpLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(helpLabel->sizePolicy().hasHeightForWidth());
        helpLabel->setSizePolicy(sizePolicy);
        helpLabel->setText(QString::fromUtf8(""));
        helpLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        helpLabel->setWordWrap(true);

        verticalLayout->addWidget(helpLabel);


        retranslateUi(ComparisonPracticeWidget);

        QMetaObject::connectSlotsByName(ComparisonPracticeWidget);
    } // setupUi

    void retranslateUi(QWidget *ComparisonPracticeWidget)
    {
        questionLabel->setText(QString());
        absoluteLabel->setText(tr2i18n("absolute", nullptr));
        comparativeLabel->setText(tr2i18n("comparative", nullptr));
        superlativeLabel->setText(tr2i18n("superlative", nullptr));
        feedbackLabel->setText(QString());
        (void)ComparisonPracticeWidget;
    } // retranslateUi

};

namespace Ui {
    class ComparisonPracticeWidget: public Ui_ComparisonPracticeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRACTICE_WIDGET_COMPARISON_H

