/********************************************************************************
** Form generated from reading UI file 'kgamethemeselector.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KGAMETHEMESELECTOR_H
#define UI_KGAMETHEMESELECTOR_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"

QT_BEGIN_NAMESPACE

class Ui_KGameThemeSelectorBase
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    QListWidget *themeList;
    KNSWidgets::Button *getNewButton;
    QGroupBox *groupBox_2;
    QVBoxLayout *vboxLayout1;
    QLabel *themePreview;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *themeAuthor;
    QLabel *labelContact;
    QLabel *themeContact;
    QLabel *labelDescription;
    QLabel *themeDescription;
    QLabel *labelAuthor;
    QSpacerItem *verticalSpacer_2;
    QLineEdit *kcfg_Theme;

    void setupUi(QWidget *KGameThemeSelectorBase)
    {
        if (KGameThemeSelectorBase->objectName().isEmpty())
            KGameThemeSelectorBase->setObjectName("KGameThemeSelectorBase");
        KGameThemeSelectorBase->resize(520, 421);
        verticalLayout = new QVBoxLayout(KGameThemeSelectorBase);
        verticalLayout->setObjectName("verticalLayout");
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        themeList = new QListWidget(KGameThemeSelectorBase);
        themeList->setObjectName("themeList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(themeList->sizePolicy().hasHeightForWidth());
        themeList->setSizePolicy(sizePolicy);
        themeList->setMinimumSize(QSize(120, 0));

        vboxLayout->addWidget(themeList);

        getNewButton = new KNSWidgets::Button(KGameThemeSelectorBase);
        getNewButton->setObjectName("getNewButton");

        vboxLayout->addWidget(getNewButton);


        hboxLayout->addLayout(vboxLayout);

        groupBox_2 = new QGroupBox(KGameThemeSelectorBase);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);
        vboxLayout1 = new QVBoxLayout(groupBox_2);
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout1->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout1->setObjectName("vboxLayout1");
        themePreview = new QLabel(groupBox_2);
        themePreview->setObjectName("themePreview");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(themePreview->sizePolicy().hasHeightForWidth());
        themePreview->setSizePolicy(sizePolicy2);
        themePreview->setMinimumSize(QSize(160, 120));
        themePreview->setAlignment(Qt::AlignCenter);

        vboxLayout1->addWidget(themePreview);


        hboxLayout->addWidget(groupBox_2);


        verticalLayout->addLayout(hboxLayout);

        groupBox = new QGroupBox(KGameThemeSelectorBase);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy3);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setSpacing(9);
        gridLayout->setObjectName("gridLayout");
        themeAuthor = new QLabel(groupBox);
        themeAuthor->setObjectName("themeAuthor");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(themeAuthor->sizePolicy().hasHeightForWidth());
        themeAuthor->setSizePolicy(sizePolicy4);
        themeAuthor->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        themeAuthor->setWordWrap(true);
        themeAuthor->setOpenExternalLinks(false);
        themeAuthor->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout->addWidget(themeAuthor, 0, 1, 1, 1);

        labelContact = new QLabel(groupBox);
        labelContact->setObjectName("labelContact");
        labelContact->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(labelContact, 1, 0, 1, 1);

        themeContact = new QLabel(groupBox);
        themeContact->setObjectName("themeContact");
        sizePolicy4.setHeightForWidth(themeContact->sizePolicy().hasHeightForWidth());
        themeContact->setSizePolicy(sizePolicy4);
        themeContact->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        themeContact->setWordWrap(true);
        themeContact->setOpenExternalLinks(true);
        themeContact->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout->addWidget(themeContact, 1, 1, 1, 1);

        labelDescription = new QLabel(groupBox);
        labelDescription->setObjectName("labelDescription");
        labelDescription->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(labelDescription, 2, 0, 1, 1);

        themeDescription = new QLabel(groupBox);
        themeDescription->setObjectName("themeDescription");
        sizePolicy4.setHeightForWidth(themeDescription->sizePolicy().hasHeightForWidth());
        themeDescription->setSizePolicy(sizePolicy4);
        themeDescription->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        themeDescription->setWordWrap(true);
        themeDescription->setOpenExternalLinks(false);
        themeDescription->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout->addWidget(themeDescription, 2, 1, 1, 1);

        labelAuthor = new QLabel(groupBox);
        labelAuthor->setObjectName("labelAuthor");
        labelAuthor->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);

        gridLayout->addWidget(labelAuthor, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 3, 0, 1, 2);


        verticalLayout->addWidget(groupBox);

        kcfg_Theme = new QLineEdit(KGameThemeSelectorBase);
        kcfg_Theme->setObjectName("kcfg_Theme");
        kcfg_Theme->setEnabled(false);
        kcfg_Theme->setFrame(false);
        kcfg_Theme->setReadOnly(false);

        verticalLayout->addWidget(kcfg_Theme);


        retranslateUi(KGameThemeSelectorBase);

        QMetaObject::connectSlotsByName(KGameThemeSelectorBase);
    } // setupUi

    void retranslateUi(QWidget *KGameThemeSelectorBase)
    {
        getNewButton->setText(tr2i18n("&Get New Themes...", nullptr));
        groupBox_2->setTitle(tr2i18n("Preview", nullptr));
        groupBox->setTitle(tr2i18n("Theme Details", nullptr));
        themeAuthor->setText(QString());
        labelContact->setText(tr2i18n("Contact:", nullptr));
        themeContact->setText(QString());
        labelDescription->setText(tr2i18n("Description:", nullptr));
        themeDescription->setText(QString());
        labelAuthor->setText(tr2i18n("Author:", nullptr));
        (void)KGameThemeSelectorBase;
    } // retranslateUi

};

namespace Ui {
    class KGameThemeSelectorBase: public Ui_KGameThemeSelectorBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KGAMETHEMESELECTOR_H

