/********************************************************************************
** Form generated from reading UI file 'translationshellpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSLATIONSHELLPAGE_H
#define UI_TRANSLATIONSHELLPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TranslationShellPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBoxInstalledStatus;
    QVBoxLayout *groupBoxLayoutInstalledStatus;
    QLabel *label;
    QFormLayout *formLayoutInstalledState;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_4;
    QLabel *label_2;
    QWidget *widget;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *buttonRunTest;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QLabel *labelResultArea;
    QVBoxLayout *verticalLayout_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TranslationShellPage)
    {
        if (TranslationShellPage->objectName().isEmpty())
            TranslationShellPage->setObjectName("TranslationShellPage");
        TranslationShellPage->resize(574, 246);
        verticalLayout = new QVBoxLayout(TranslationShellPage);
        verticalLayout->setObjectName("verticalLayout");
        groupBoxInstalledStatus = new QGroupBox(TranslationShellPage);
        groupBoxInstalledStatus->setObjectName("groupBoxInstalledStatus");
        groupBoxLayoutInstalledStatus = new QVBoxLayout(groupBoxInstalledStatus);
        groupBoxLayoutInstalledStatus->setObjectName("groupBoxLayoutInstalledStatus");
        label = new QLabel(groupBoxInstalledStatus);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);
        label->setMinimumSize(QSize(0, 0));
        label->setText(QString::fromUtf8("Parley provides access to translation webservices via utilizing the \"translate-shell\" tool."));
        label->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        groupBoxLayoutInstalledStatus->addWidget(label);

        formLayoutInstalledState = new QFormLayout();
        formLayoutInstalledState->setObjectName("formLayoutInstalledState");

        groupBoxLayoutInstalledStatus->addLayout(formLayoutInstalledState);


        verticalLayout->addWidget(groupBoxInstalledStatus);

        groupBox = new QGroupBox(TranslationShellPage);
        groupBox->setObjectName("groupBox");
        verticalLayout_4 = new QVBoxLayout(groupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        verticalLayout_4->addWidget(label_2);

        widget = new QWidget(groupBox);
        widget->setObjectName("widget");
        horizontalLayout_2 = new QHBoxLayout(widget);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        buttonRunTest = new QToolButton(widget);
        buttonRunTest->setObjectName("buttonRunTest");

        horizontalLayout_2->addWidget(buttonRunTest);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        label_3 = new QLabel(widget);
        label_3->setObjectName("label_3");

        horizontalLayout_2->addWidget(label_3);

        labelResultArea = new QLabel(widget);
        labelResultArea->setObjectName("labelResultArea");
        labelResultArea->setMinimumSize(QSize(80, 0));

        horizontalLayout_2->addWidget(labelResultArea);


        verticalLayout_4->addWidget(widget);

        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");

        verticalLayout_4->addLayout(verticalLayout_3);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(TranslationShellPage);

        QMetaObject::connectSlotsByName(TranslationShellPage);
    } // setupUi

    void retranslateUi(QWidget *TranslationShellPage)
    {
        groupBoxInstalledStatus->setTitle(tr2i18n("Translation Shell Integration", nullptr));
        groupBox->setTitle(tr2i18n("Run Interactive Functionality Test", nullptr));
        label_2->setText(tr2i18n("The interaction test request translation of English word \"parley\" into German.", nullptr));
        buttonRunTest->setText(tr2i18n("Start online test", nullptr));
        label_3->setText(tr2i18n("Result:", nullptr));
        labelResultArea->setText(tr2i18n("...", nullptr));
        (void)TranslationShellPage;
    } // retranslateUi

};

namespace Ui {
    class TranslationShellPage: public Ui_TranslationShellPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSLATIONSHELLPAGE_H

