/********************************************************************************
** Form generated from reading UI file 'generaloptionsbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALOPTIONSBASE_H
#define UI_GENERALOPTIONSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralOptionsBase
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_AutoOpenLast;
    QCheckBox *kcfg_AutoSave;
    QHBoxLayout *hboxLayout;
    QCheckBox *kcfg_AutoBackup;
    QSpinBox *kcfg_BackupTime;
    QLabel *lblBackupInterva;
    QHBoxLayout *hboxLayout1;
    QLabel *label_sep;
    KComboBox *kcfg_SeparatorCombo;
    QSpacerItem *horizontalSpacer;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_SmartAppend;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GeneralOptionsBase)
    {
        if (GeneralOptionsBase->objectName().isEmpty())
            GeneralOptionsBase->setObjectName("GeneralOptionsBase");
        GeneralOptionsBase->resize(401, 244);
        verticalLayout = new QVBoxLayout(GeneralOptionsBase);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(GeneralOptionsBase);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_AutoOpenLast = new QCheckBox(groupBox);
        kcfg_AutoOpenLast->setObjectName("kcfg_AutoOpenLast");
        kcfg_AutoOpenLast->setChecked(false);

        verticalLayout_2->addWidget(kcfg_AutoOpenLast);

        kcfg_AutoSave = new QCheckBox(groupBox);
        kcfg_AutoSave->setObjectName("kcfg_AutoSave");

        verticalLayout_2->addWidget(kcfg_AutoSave);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        kcfg_AutoBackup = new QCheckBox(groupBox);
        kcfg_AutoBackup->setObjectName("kcfg_AutoBackup");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_AutoBackup->sizePolicy().hasHeightForWidth());
        kcfg_AutoBackup->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(kcfg_AutoBackup);

        kcfg_BackupTime = new QSpinBox(groupBox);
        kcfg_BackupTime->setObjectName("kcfg_BackupTime");
        sizePolicy.setHeightForWidth(kcfg_BackupTime->sizePolicy().hasHeightForWidth());
        kcfg_BackupTime->setSizePolicy(sizePolicy);

        hboxLayout->addWidget(kcfg_BackupTime);

        lblBackupInterva = new QLabel(groupBox);
        lblBackupInterva->setObjectName("lblBackupInterva");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lblBackupInterva->sizePolicy().hasHeightForWidth());
        lblBackupInterva->setSizePolicy(sizePolicy1);

        hboxLayout->addWidget(lblBackupInterva);


        verticalLayout_2->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName("hboxLayout1");
        label_sep = new QLabel(groupBox);
        label_sep->setObjectName("label_sep");

        hboxLayout1->addWidget(label_sep);

        kcfg_SeparatorCombo = new KComboBox(groupBox);
        kcfg_SeparatorCombo->setObjectName("kcfg_SeparatorCombo");
        kcfg_SeparatorCombo->setMinimumSize(QSize(140, 0));

        hboxLayout1->addWidget(kcfg_SeparatorCombo);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout1->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(hboxLayout1);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(GeneralOptionsBase);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout = new QHBoxLayout(groupBox_2);
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_SmartAppend = new QCheckBox(groupBox_2);
        kcfg_SmartAppend->setObjectName("kcfg_SmartAppend");
        sizePolicy.setHeightForWidth(kcfg_SmartAppend->sizePolicy().hasHeightForWidth());
        kcfg_SmartAppend->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(kcfg_SmartAppend);


        verticalLayout->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_sep->setBuddy(kcfg_SeparatorCombo);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_AutoSave, kcfg_BackupTime);

        retranslateUi(GeneralOptionsBase);

        QMetaObject::connectSlotsByName(GeneralOptionsBase);
    } // setupUi

    void retranslateUi(QWidget *GeneralOptionsBase)
    {
        groupBox->setTitle(tr2i18n("Open/Save", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoOpenLast->setToolTip(tr2i18n("Always open the collection that was active when quitting Parley", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_AutoOpenLast->setWhatsThis(tr2i18n("When this option is checked, the last active collection will be loaded automatically when starting Parley instead of showing the welcome screen.", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutoOpenLast->setText(tr2i18n("Always load the last opened collection on start", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoSave->setToolTip(tr2i18n("Allow automatic saving of your work", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_AutoSave->setWhatsThis(tr2i18n("Your work will be automatically saved if you check this option", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutoSave->setText(tr2i18n("&Save vocabularies automatically on close and quit", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AutoBackup->setToolTip(tr2i18n("Allow automatic saving of your work", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_AutoBackup->setWhatsThis(tr2i18n("Your work will be automatically saved if you check this option", nullptr));
#endif // QT_CONFIG(whatsthis)
        kcfg_AutoBackup->setText(tr2i18n("&Create a backup every", nullptr));
        lblBackupInterva->setText(tr2i18n("minutes", nullptr));
        label_sep->setText(tr2i18n("Sep&arator for text file import/export (CSV):", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SeparatorCombo->setToolTip(tr2i18n("Choose which separator you want to use to separate your data when importing and exporting text.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_SeparatorCombo->setWhatsThis(tr2i18n("Choose the separator to use to divide the parts of an expression when importing or exporting data as text.", nullptr));
#endif // QT_CONFIG(whatsthis)
        groupBox_2->setTitle(tr2i18n("Editing", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_SmartAppend->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        kcfg_SmartAppend->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        kcfg_SmartAppend->setText(tr2i18n("&Append new rows automatically when editing", nullptr));
        (void)GeneralOptionsBase;
    } // retranslateUi

};

namespace Ui {
    class GeneralOptionsBase: public Ui_GeneralOptionsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALOPTIONSBASE_H

