/********************************************************************************
** Form generated from reading UI file 'synonymwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SYNONYMWIDGET_H
#define UI_SYNONYMWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SynonymWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *synonymLabel;
    QListView *listView;
    QPushButton *synonymButton;

    void setupUi(QWidget *SynonymWidget)
    {
        if (SynonymWidget->objectName().isEmpty())
            SynonymWidget->setObjectName("SynonymWidget");
        SynonymWidget->resize(297, 196);
        verticalLayout = new QVBoxLayout(SynonymWidget);
        verticalLayout->setObjectName("verticalLayout");
        synonymLabel = new QLabel(SynonymWidget);
        synonymLabel->setObjectName("synonymLabel");

        verticalLayout->addWidget(synonymLabel);

        listView = new QListView(SynonymWidget);
        listView->setObjectName("listView");

        verticalLayout->addWidget(listView);

        synonymButton = new QPushButton(SynonymWidget);
        synonymButton->setObjectName("synonymButton");

        verticalLayout->addWidget(synonymButton);


        retranslateUi(SynonymWidget);

        QMetaObject::connectSlotsByName(SynonymWidget);
    } // setupUi

    void retranslateUi(QWidget *SynonymWidget)
    {
        synonymLabel->setText(tr2i18n("Synonyms", nullptr));
        synonymButton->setText(tr2i18n("Synonym", nullptr));
        (void)SynonymWidget;
    } // retranslateUi

};

namespace Ui {
    class SynonymWidget: public Ui_SynonymWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SYNONYMWIDGET_H

