/********************************************************************************
** Form generated from reading UI file 'imagechooserwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGECHOOSERWIDGET_H
#define UI_IMAGECHOOSERWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"
#include "practice/imagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ImageChooserWidget
{
public:
    QVBoxLayout *vboxLayout;
    Practice::ImageWidget *imageWidget;
    KUrlRequester *imageUrlRequester;

    void setupUi(QWidget *ImageChooserWidget)
    {
        if (ImageChooserWidget->objectName().isEmpty())
            ImageChooserWidget->setObjectName("ImageChooserWidget");
        ImageChooserWidget->resize(142, 130);
        vboxLayout = new QVBoxLayout(ImageChooserWidget);
        vboxLayout->setObjectName("vboxLayout");
        imageWidget = new Practice::ImageWidget(ImageChooserWidget);
        imageWidget->setObjectName("imageWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(imageWidget->sizePolicy().hasHeightForWidth());
        imageWidget->setSizePolicy(sizePolicy);
        imageWidget->setMinimumSize(QSize(20, 20));

        vboxLayout->addWidget(imageWidget);

        imageUrlRequester = new KUrlRequester(ImageChooserWidget);
        imageUrlRequester->setObjectName("imageUrlRequester");

        vboxLayout->addWidget(imageUrlRequester);


        retranslateUi(ImageChooserWidget);

        QMetaObject::connectSlotsByName(ImageChooserWidget);
    } // setupUi

    void retranslateUi(QWidget *ImageChooserWidget)
    {
        (void)ImageChooserWidget;
    } // retranslateUi

};

namespace Ui {
    class ImageChooserWidget: public Ui_ImageChooserWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGECHOOSERWIDGET_H

