/********************************************************************************
** Form generated from reading UI file 'declensionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DECLENSIONWIDGET_H
#define UI_DECLENSIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DeclensionWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *declensionGroupBox;
    QGridLayout *gridLayout;
    QGridLayout *mainLayout;
    QLabel *nominativeLabel;
    QLabel *genitivLabel;
    QLabel *dativLabel;
    QLabel *accusativeLabel;
    QLabel *ablativLabel;
    QLabel *locativeLabel;
    QLabel *vocativeLabel;
    QLabel *label_3;
    QLineEdit *masculine_1;
    QLineEdit *masculine_2;
    QLineEdit *masculine_3;
    QLineEdit *masculine_4;
    QLineEdit *masculine_5;
    QLineEdit *masculine_6;
    QLineEdit *masculine_7;
    QLabel *label_4;
    QLineEdit *feminine_1;
    QLineEdit *feminine_2;
    QLineEdit *feminine_3;
    QLineEdit *feminine_4;
    QLineEdit *feminine_5;
    QLineEdit *feminine_6;
    QLineEdit *feminine_7;
    QLabel *label_5;
    QLineEdit *neuter_1;
    QLineEdit *neuter_2;
    QLineEdit *neuter_3;
    QLineEdit *neuter_4;
    QLineEdit *neuter_5;
    QLineEdit *neuter_6;
    QLineEdit *neuter_7;
    QHBoxLayout *numberLayout;
    QLabel *numberLabel;
    QComboBox *numberSelection;
    QPushButton *nextButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *DeclensionWidget)
    {
        if (DeclensionWidget->objectName().isEmpty())
            DeclensionWidget->setObjectName("DeclensionWidget");
        DeclensionWidget->resize(637, 326);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(DeclensionWidget->sizePolicy().hasHeightForWidth());
        DeclensionWidget->setSizePolicy(sizePolicy);
        DeclensionWidget->setMinimumSize(QSize(332, 326));
        vboxLayout = new QVBoxLayout(DeclensionWidget);
        vboxLayout->setObjectName("vboxLayout");
        declensionGroupBox = new QGroupBox(DeclensionWidget);
        declensionGroupBox->setObjectName("declensionGroupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(declensionGroupBox->sizePolicy().hasHeightForWidth());
        declensionGroupBox->setSizePolicy(sizePolicy1);
        gridLayout = new QGridLayout(declensionGroupBox);
        gridLayout->setObjectName("gridLayout");
        mainLayout = new QGridLayout();
        mainLayout->setObjectName("mainLayout");
        nominativeLabel = new QLabel(declensionGroupBox);
        nominativeLabel->setObjectName("nominativeLabel");
        sizePolicy1.setHeightForWidth(nominativeLabel->sizePolicy().hasHeightForWidth());
        nominativeLabel->setSizePolicy(sizePolicy1);
        nominativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(nominativeLabel, 3, 0, 1, 1);

        genitivLabel = new QLabel(declensionGroupBox);
        genitivLabel->setObjectName("genitivLabel");
        sizePolicy1.setHeightForWidth(genitivLabel->sizePolicy().hasHeightForWidth());
        genitivLabel->setSizePolicy(sizePolicy1);
        genitivLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(genitivLabel, 4, 0, 1, 1);

        dativLabel = new QLabel(declensionGroupBox);
        dativLabel->setObjectName("dativLabel");
        sizePolicy1.setHeightForWidth(dativLabel->sizePolicy().hasHeightForWidth());
        dativLabel->setSizePolicy(sizePolicy1);
        dativLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(dativLabel, 6, 0, 1, 1);

        accusativeLabel = new QLabel(declensionGroupBox);
        accusativeLabel->setObjectName("accusativeLabel");
        sizePolicy1.setHeightForWidth(accusativeLabel->sizePolicy().hasHeightForWidth());
        accusativeLabel->setSizePolicy(sizePolicy1);
        accusativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(accusativeLabel, 5, 0, 1, 1);

        ablativLabel = new QLabel(declensionGroupBox);
        ablativLabel->setObjectName("ablativLabel");
        sizePolicy1.setHeightForWidth(ablativLabel->sizePolicy().hasHeightForWidth());
        ablativLabel->setSizePolicy(sizePolicy1);
        ablativLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(ablativLabel, 7, 0, 1, 1);

        locativeLabel = new QLabel(declensionGroupBox);
        locativeLabel->setObjectName("locativeLabel");
        sizePolicy1.setHeightForWidth(locativeLabel->sizePolicy().hasHeightForWidth());
        locativeLabel->setSizePolicy(sizePolicy1);
        locativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(locativeLabel, 8, 0, 1, 1);

        vocativeLabel = new QLabel(declensionGroupBox);
        vocativeLabel->setObjectName("vocativeLabel");
        sizePolicy1.setHeightForWidth(vocativeLabel->sizePolicy().hasHeightForWidth());
        vocativeLabel->setSizePolicy(sizePolicy1);
        vocativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        mainLayout->addWidget(vocativeLabel, 9, 0, 1, 1);

        label_3 = new QLabel(declensionGroupBox);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy2);
        label_3->setAlignment(Qt::AlignCenter);

        mainLayout->addWidget(label_3, 2, 1, 1, 1);

        masculine_1 = new QLineEdit(declensionGroupBox);
        masculine_1->setObjectName("masculine_1");
        sizePolicy1.setHeightForWidth(masculine_1->sizePolicy().hasHeightForWidth());
        masculine_1->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_1, 3, 1, 1, 1);

        masculine_2 = new QLineEdit(declensionGroupBox);
        masculine_2->setObjectName("masculine_2");
        sizePolicy1.setHeightForWidth(masculine_2->sizePolicy().hasHeightForWidth());
        masculine_2->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_2, 4, 1, 1, 1);

        masculine_3 = new QLineEdit(declensionGroupBox);
        masculine_3->setObjectName("masculine_3");
        sizePolicy1.setHeightForWidth(masculine_3->sizePolicy().hasHeightForWidth());
        masculine_3->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_3, 5, 1, 1, 1);

        masculine_4 = new QLineEdit(declensionGroupBox);
        masculine_4->setObjectName("masculine_4");
        sizePolicy1.setHeightForWidth(masculine_4->sizePolicy().hasHeightForWidth());
        masculine_4->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_4, 6, 1, 1, 1);

        masculine_5 = new QLineEdit(declensionGroupBox);
        masculine_5->setObjectName("masculine_5");
        sizePolicy1.setHeightForWidth(masculine_5->sizePolicy().hasHeightForWidth());
        masculine_5->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_5, 7, 1, 1, 1);

        masculine_6 = new QLineEdit(declensionGroupBox);
        masculine_6->setObjectName("masculine_6");
        sizePolicy1.setHeightForWidth(masculine_6->sizePolicy().hasHeightForWidth());
        masculine_6->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_6, 8, 1, 1, 1);

        masculine_7 = new QLineEdit(declensionGroupBox);
        masculine_7->setObjectName("masculine_7");
        sizePolicy1.setHeightForWidth(masculine_7->sizePolicy().hasHeightForWidth());
        masculine_7->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(masculine_7, 9, 1, 1, 1);

        label_4 = new QLabel(declensionGroupBox);
        label_4->setObjectName("label_4");
        sizePolicy2.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy2);
        label_4->setAlignment(Qt::AlignCenter);

        mainLayout->addWidget(label_4, 2, 2, 1, 1);

        feminine_1 = new QLineEdit(declensionGroupBox);
        feminine_1->setObjectName("feminine_1");
        sizePolicy1.setHeightForWidth(feminine_1->sizePolicy().hasHeightForWidth());
        feminine_1->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_1, 3, 2, 1, 1);

        feminine_2 = new QLineEdit(declensionGroupBox);
        feminine_2->setObjectName("feminine_2");
        sizePolicy1.setHeightForWidth(feminine_2->sizePolicy().hasHeightForWidth());
        feminine_2->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_2, 4, 2, 1, 1);

        feminine_3 = new QLineEdit(declensionGroupBox);
        feminine_3->setObjectName("feminine_3");
        sizePolicy1.setHeightForWidth(feminine_3->sizePolicy().hasHeightForWidth());
        feminine_3->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_3, 5, 2, 1, 1);

        feminine_4 = new QLineEdit(declensionGroupBox);
        feminine_4->setObjectName("feminine_4");
        sizePolicy1.setHeightForWidth(feminine_4->sizePolicy().hasHeightForWidth());
        feminine_4->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_4, 6, 2, 1, 1);

        feminine_5 = new QLineEdit(declensionGroupBox);
        feminine_5->setObjectName("feminine_5");
        sizePolicy1.setHeightForWidth(feminine_5->sizePolicy().hasHeightForWidth());
        feminine_5->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_5, 7, 2, 1, 1);

        feminine_6 = new QLineEdit(declensionGroupBox);
        feminine_6->setObjectName("feminine_6");
        sizePolicy1.setHeightForWidth(feminine_6->sizePolicy().hasHeightForWidth());
        feminine_6->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_6, 8, 2, 1, 1);

        feminine_7 = new QLineEdit(declensionGroupBox);
        feminine_7->setObjectName("feminine_7");
        sizePolicy1.setHeightForWidth(feminine_7->sizePolicy().hasHeightForWidth());
        feminine_7->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(feminine_7, 9, 2, 1, 1);

        label_5 = new QLabel(declensionGroupBox);
        label_5->setObjectName("label_5");
        sizePolicy2.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy2);
        label_5->setAlignment(Qt::AlignCenter);

        mainLayout->addWidget(label_5, 2, 3, 1, 1);

        neuter_1 = new QLineEdit(declensionGroupBox);
        neuter_1->setObjectName("neuter_1");
        sizePolicy1.setHeightForWidth(neuter_1->sizePolicy().hasHeightForWidth());
        neuter_1->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_1, 3, 3, 1, 1);

        neuter_2 = new QLineEdit(declensionGroupBox);
        neuter_2->setObjectName("neuter_2");
        sizePolicy1.setHeightForWidth(neuter_2->sizePolicy().hasHeightForWidth());
        neuter_2->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_2, 4, 3, 1, 1);

        neuter_3 = new QLineEdit(declensionGroupBox);
        neuter_3->setObjectName("neuter_3");
        sizePolicy1.setHeightForWidth(neuter_3->sizePolicy().hasHeightForWidth());
        neuter_3->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_3, 5, 3, 1, 1);

        neuter_4 = new QLineEdit(declensionGroupBox);
        neuter_4->setObjectName("neuter_4");
        sizePolicy1.setHeightForWidth(neuter_4->sizePolicy().hasHeightForWidth());
        neuter_4->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_4, 6, 3, 1, 1);

        neuter_5 = new QLineEdit(declensionGroupBox);
        neuter_5->setObjectName("neuter_5");
        sizePolicy1.setHeightForWidth(neuter_5->sizePolicy().hasHeightForWidth());
        neuter_5->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_5, 7, 3, 1, 1);

        neuter_6 = new QLineEdit(declensionGroupBox);
        neuter_6->setObjectName("neuter_6");
        sizePolicy1.setHeightForWidth(neuter_6->sizePolicy().hasHeightForWidth());
        neuter_6->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_6, 8, 3, 1, 1);

        neuter_7 = new QLineEdit(declensionGroupBox);
        neuter_7->setObjectName("neuter_7");
        sizePolicy1.setHeightForWidth(neuter_7->sizePolicy().hasHeightForWidth());
        neuter_7->setSizePolicy(sizePolicy1);

        mainLayout->addWidget(neuter_7, 9, 3, 1, 1);

        numberLayout = new QHBoxLayout();
        numberLayout->setObjectName("numberLayout");
        numberLabel = new QLabel(declensionGroupBox);
        numberLabel->setObjectName("numberLabel");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(numberLabel->sizePolicy().hasHeightForWidth());
        numberLabel->setSizePolicy(sizePolicy3);
        numberLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        numberLayout->addWidget(numberLabel);

        numberSelection = new QComboBox(declensionGroupBox);
        numberSelection->addItem(QString());
        numberSelection->addItem(QString());
        numberSelection->addItem(QString());
        numberSelection->setObjectName("numberSelection");

        numberLayout->addWidget(numberSelection);

        nextButton = new QPushButton(declensionGroupBox);
        nextButton->setObjectName("nextButton");

        numberLayout->addWidget(nextButton);

        numberLayout->setStretch(1, 2);
        numberLayout->setStretch(2, 1);

        mainLayout->addLayout(numberLayout, 1, 0, 1, 4);

        mainLayout->setColumnStretch(1, 1);
        mainLayout->setColumnStretch(2, 1);
        mainLayout->setColumnStretch(3, 1);

        gridLayout->addLayout(mainLayout, 6, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 2);


        vboxLayout->addWidget(declensionGroupBox);

#if QT_CONFIG(shortcut)
        nominativeLabel->setBuddy(masculine_1);
        genitivLabel->setBuddy(masculine_2);
        dativLabel->setBuddy(masculine_3);
        accusativeLabel->setBuddy(masculine_4);
        ablativLabel->setBuddy(masculine_5);
        locativeLabel->setBuddy(masculine_6);
        vocativeLabel->setBuddy(masculine_7);
        numberLabel->setBuddy(numberSelection);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(nextButton, numberSelection);

        retranslateUi(DeclensionWidget);

        QMetaObject::connectSlotsByName(DeclensionWidget);
    } // setupUi

    void retranslateUi(QWidget *DeclensionWidget)
    {
        DeclensionWidget->setWindowTitle(tr2i18n("-", nullptr));
        declensionGroupBox->setTitle(tr2i18n("Declension Forms", nullptr));
        nominativeLabel->setText(tr2i18n("Nominative:", "one of the seven cases (grammatical)"));
        genitivLabel->setText(tr2i18n("Genitive:", "one of the seven cases (grammatical)"));
        dativLabel->setText(tr2i18n("Dative:", "one of the seven cases (grammatical)"));
        accusativeLabel->setText(tr2i18n("Accusative:", "one of the seven cases (grammatical)"));
        ablativLabel->setText(tr2i18n("Ablative:", "one of the seven cases (grammatical)"));
        locativeLabel->setText(tr2i18n("Locative:", "one of the seven cases (grammatical)"));
        vocativeLabel->setText(tr2i18n("Vocative:", "one of the seven cases (grammatical)"));
        label_3->setText(tr2i18n("Masculine", nullptr));
        label_4->setText(tr2i18n("Feminine", nullptr));
        label_5->setText(tr2i18n("Neuter", nullptr));
        numberLabel->setText(tr2i18n("Number:", nullptr));
        numberSelection->setItemText(0, tr2i18n("Singular", nullptr));
        numberSelection->setItemText(1, tr2i18n("Dual", nullptr));
        numberSelection->setItemText(2, tr2i18n("Plural", nullptr));

        nextButton->setText(tr2i18n("Next", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DeclensionWidget: public Ui_DeclensionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DECLENSIONWIDGET_H

