/********************************************************************************
** Form generated from reading UI file 'latexwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LATEXWIDGET_H
#define UI_LATEXWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_LatexWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *texLabel;
    QLineEdit *lineEdit;
    QLabel *label;
    QLabel *previewLabel;
    QCheckBox *mathModeCheckBox;

    void setupUi(QWidget *LatexWidget)
    {
        if (LatexWidget->objectName().isEmpty())
            LatexWidget->setObjectName("LatexWidget");
        LatexWidget->resize(411, 236);
        gridLayout = new QGridLayout(LatexWidget);
        gridLayout->setObjectName("gridLayout");
        texLabel = new QLabel(LatexWidget);
        texLabel->setObjectName("texLabel");
        texLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(texLabel, 0, 0, 1, 1);

        lineEdit = new QLineEdit(LatexWidget);
        lineEdit->setObjectName("lineEdit");

        gridLayout->addWidget(lineEdit, 0, 2, 1, 1);

        label = new QLabel(LatexWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 2, 0, 1, 1);

        previewLabel = new QLabel(LatexWidget);
        previewLabel->setObjectName("previewLabel");
        previewLabel->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(previewLabel, 2, 2, 1, 1);

        mathModeCheckBox = new QCheckBox(LatexWidget);
        mathModeCheckBox->setObjectName("mathModeCheckBox");
        mathModeCheckBox->setChecked(true);

        gridLayout->addWidget(mathModeCheckBox, 1, 2, 1, 1);

#if QT_CONFIG(shortcut)
        texLabel->setBuddy(lineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(LatexWidget);

        QMetaObject::connectSlotsByName(LatexWidget);
    } // setupUi

    void retranslateUi(QWidget *LatexWidget)
    {
        texLabel->setText(tr2i18n("LaTeX code:", nullptr));
        lineEdit->setPlaceholderText(QString());
        label->setText(tr2i18n("Preview", nullptr));
        previewLabel->setText(QString());
        mathModeCheckBox->setText(tr2i18n("Math mode", nullptr));
        (void)LatexWidget;
    } // retranslateUi

};

namespace Ui {
    class LatexWidget: public Ui_LatexWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LATEXWIDGET_H

