/********************************************************************************
** Form generated from reading UI file 'multiplechoicewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MULTIPLECHOICEWIDGET_H
#define UI_MULTIPLECHOICEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_multipleChoiceWidget
{
public:
    QVBoxLayout *vboxLayout;
    QListView *multipleChoiceListView;
    QHBoxLayout *hboxLayout;
    QPushButton *addChoiceButton;
    QPushButton *removeChoiceButton;

    void setupUi(QWidget *multipleChoiceWidget)
    {
        if (multipleChoiceWidget->objectName().isEmpty())
            multipleChoiceWidget->setObjectName("multipleChoiceWidget");
        multipleChoiceWidget->resize(400, 300);
        vboxLayout = new QVBoxLayout(multipleChoiceWidget);
        vboxLayout->setObjectName("vboxLayout");
        multipleChoiceListView = new QListView(multipleChoiceWidget);
        multipleChoiceListView->setObjectName("multipleChoiceListView");

        vboxLayout->addWidget(multipleChoiceListView);

        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        addChoiceButton = new QPushButton(multipleChoiceWidget);
        addChoiceButton->setObjectName("addChoiceButton");

        hboxLayout->addWidget(addChoiceButton);

        removeChoiceButton = new QPushButton(multipleChoiceWidget);
        removeChoiceButton->setObjectName("removeChoiceButton");

        hboxLayout->addWidget(removeChoiceButton);


        vboxLayout->addLayout(hboxLayout);


        retranslateUi(multipleChoiceWidget);

        QMetaObject::connectSlotsByName(multipleChoiceWidget);
    } // setupUi

    void retranslateUi(QWidget *multipleChoiceWidget)
    {
        addChoiceButton->setText(tr2i18n("Add", nullptr));
        removeChoiceButton->setText(tr2i18n("Remove", nullptr));
        (void)multipleChoiceWidget;
    } // retranslateUi

};

namespace Ui {
    class multipleChoiceWidget: public Ui_multipleChoiceWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MULTIPLECHOICEWIDGET_H

