/********************************************************************************
** Form generated from reading UI file 'dashboard.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DASHBOARD_H
#define UI_DASHBOARD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"

QT_BEGIN_NAMESPACE

class Ui_Dashboard
{
public:
    QGridLayout *gridLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_2;
    QLabel *recentLabel;
    QSpacerItem *verticalSpacer1;
    QSpacerItem *verticalSpacer2;
    QLabel *completedLabel;
    QSpacerItem *verticalSpacer3;
    QSpacerItem *verticalSpacer4;
    QPushButton *newButton;
    QPushButton *openButton;
    KNSWidgets::Button *ghnsButton;
    QLabel *headingLabel;

    void setupUi(QWidget *Dashboard)
    {
        if (Dashboard->objectName().isEmpty())
            Dashboard->setObjectName("Dashboard");
        Dashboard->resize(569, 526);
        gridLayout = new QGridLayout(Dashboard);
        gridLayout->setObjectName("gridLayout");
        scrollArea = new QScrollArea(Dashboard);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 551, 437));
        gridLayout_2 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_2->setObjectName("gridLayout_2");
        recentLabel = new QLabel(scrollAreaWidgetContents);
        recentLabel->setObjectName("recentLabel");

        gridLayout_2->addWidget(recentLabel, 0, 0, 1, 1);

        verticalSpacer1 = new QSpacerItem(20, 25, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer1, 1, 0, 1, 1);

        verticalSpacer2 = new QSpacerItem(20, 25, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer2, 2, 0, 1, 1);

        completedLabel = new QLabel(scrollAreaWidgetContents);
        completedLabel->setObjectName("completedLabel");

        gridLayout_2->addWidget(completedLabel, 3, 0, 1, 1);

        verticalSpacer3 = new QSpacerItem(20, 25, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer3, 4, 0, 1, 1);

        verticalSpacer4 = new QSpacerItem(20, 25, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer4, 5, 0, 1, 1);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout->addWidget(scrollArea, 2, 0, 1, 4);

        newButton = new QPushButton(Dashboard);
        newButton->setObjectName("newButton");

        gridLayout->addWidget(newButton, 5, 1, 1, 1);

        openButton = new QPushButton(Dashboard);
        openButton->setObjectName("openButton");

        gridLayout->addWidget(openButton, 5, 2, 1, 1);

        ghnsButton = new KNSWidgets::Button(Dashboard);
        ghnsButton->setObjectName("ghnsButton");

        gridLayout->addWidget(ghnsButton, 5, 3, 1, 1);

        headingLabel = new QLabel(Dashboard);
        headingLabel->setObjectName("headingLabel");

        gridLayout->addWidget(headingLabel, 0, 0, 1, 2);


        retranslateUi(Dashboard);

        QMetaObject::connectSlotsByName(Dashboard);
    } // setupUi

    void retranslateUi(QWidget *Dashboard)
    {
        Dashboard->setWindowTitle(tr2i18n("Parley", nullptr));
        recentLabel->setText(tr2i18n("Active Collections", nullptr));
        completedLabel->setText(tr2i18n("Completed Collections", nullptr));
        newButton->setText(tr2i18n("Create a New Collection...", nullptr));
        openButton->setText(tr2i18n("Open an Existing Collection...", nullptr));
        ghnsButton->setText(tr2i18n("Download New Collections...", nullptr));
        headingLabel->setText(tr2i18n("<h1>Parley</h1>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class Dashboard: public Ui_Dashboard {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DASHBOARD_H

