// This file is generated by kconfig_compiler_kf6 from documentsettings.kcfg.
// All changes you do to this file will be lost.

#include "documentsettings.h"

DocumentSettings::DocumentSettings( const QString & fileurl )
  : KConfigSkeleton( QStringLiteral( "parleyrc" ) )
  , mParamfileurl(fileurl)
{
  setCurrentGroup( QStringLiteral( "Document %1" ).arg( mParamfileurl ) );

  mConjugationTensesItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "ConjugationTenses" ), mConjugationTenses );
  mConjugationTensesItem->setLabel( QCoreApplication::translate("DocumentSettings", "Selected tenses for conjugation practice.") );
  mConjugationTensesItem->setWhatsThis( QCoreApplication::translate("DocumentSettings", "Selected tenses for conjugation practice.") );
  addItem( mConjugationTensesItem, QStringLiteral( "ConjugationTenses" ) );
  QList<int> defaultVisibleColumns;

  mVisibleColumnsItem = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "VisibleColumns" ), mVisibleColumns, defaultVisibleColumns );
  mVisibleColumnsItem->setLabel( QCoreApplication::translate("DocumentSettings", "Visible columns in the main editor window.") );
  mVisibleColumnsItem->setWhatsThis( QCoreApplication::translate("DocumentSettings", "Visible columns in the main editor window.") );
  addItem( mVisibleColumnsItem, QStringLiteral( "VisibleColumns" ) );
  mCollapsedStatisticsViewItemsItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "CollapsedStatisticsViewItems" ), mCollapsedStatisticsViewItems );
  mCollapsedStatisticsViewItemsItem->setLabel( QCoreApplication::translate("DocumentSettings", "Collapsed tree view items of statistics view window.") );
  mCollapsedStatisticsViewItemsItem->setWhatsThis( QCoreApplication::translate("DocumentSettings", "Collapsed tree view items of statistics view window.") );
  addItem( mCollapsedStatisticsViewItemsItem, QStringLiteral( "CollapsedStatisticsViewItems" ) );
}

DocumentSettings::~DocumentSettings()
{
}

