/********************************************************************************
** Form generated from reading UI file 'entryfilterdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENTRYFILTERDIALOG_H
#define UI_ENTRYFILTERDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_EntryFilterDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *headerLabel;
    QGroupBox *ignoreGroupBox;
    QGridLayout *_2;
    QCheckBox *lessonCheckBox;
    QLabel *lessonLabel;
    QCheckBox *wordTypeCheckBox;
    QLabel *wordTypeLabel;
    QCheckBox *blockedCheckBox;
    QLabel *blockedLabel;
    QCheckBox *timesWrongCheckBox;
    QLabel *timesWrongLabel;
    QCheckBox *timesPracticedCheckBox;
    QLabel *timesPracticedLabel;
    QCheckBox *minMaxGradeCheckBox;
    QLabel *minMaxGradeLabel;
    QLabel *numberAffectedWordsLabel;
    QHBoxLayout *documentTotalLayout;
    QLabel *documentTotalDescriptionLabel;
    QLabel *documentTotalLabel;
    QHBoxLayout *totalLayout;
    QLabel *totalDescriptionLabel;
    QLabel *totalLabel;
    QSpacerItem *spacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EntryFilterDialog)
    {
        if (EntryFilterDialog->objectName().isEmpty())
            EntryFilterDialog->setObjectName("EntryFilterDialog");
        EntryFilterDialog->resize(440, 430);
        verticalLayout = new QVBoxLayout(EntryFilterDialog);
        verticalLayout->setObjectName("verticalLayout");
        headerLabel = new QLabel(EntryFilterDialog);
        headerLabel->setObjectName("headerLabel");
        headerLabel->setWordWrap(true);

        verticalLayout->addWidget(headerLabel);

        ignoreGroupBox = new QGroupBox(EntryFilterDialog);
        ignoreGroupBox->setObjectName("ignoreGroupBox");
        _2 = new QGridLayout(ignoreGroupBox);
        _2->setObjectName("_2");
        lessonCheckBox = new QCheckBox(ignoreGroupBox);
        lessonCheckBox->setObjectName("lessonCheckBox");
        lessonCheckBox->setChecked(false);

        _2->addWidget(lessonCheckBox, 1, 0, 1, 1);

        lessonLabel = new QLabel(ignoreGroupBox);
        lessonLabel->setObjectName("lessonLabel");
        lessonLabel->setText(QString::fromUtf8("TextLabel"));
        lessonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(lessonLabel, 1, 1, 1, 1);

        wordTypeCheckBox = new QCheckBox(ignoreGroupBox);
        wordTypeCheckBox->setObjectName("wordTypeCheckBox");
        wordTypeCheckBox->setChecked(false);

        _2->addWidget(wordTypeCheckBox, 2, 0, 1, 1);

        wordTypeLabel = new QLabel(ignoreGroupBox);
        wordTypeLabel->setObjectName("wordTypeLabel");
        wordTypeLabel->setText(QString::fromUtf8("TextLabel"));
        wordTypeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(wordTypeLabel, 2, 1, 1, 1);

        blockedCheckBox = new QCheckBox(ignoreGroupBox);
        blockedCheckBox->setObjectName("blockedCheckBox");
        blockedCheckBox->setChecked(false);

        _2->addWidget(blockedCheckBox, 3, 0, 1, 1);

        blockedLabel = new QLabel(ignoreGroupBox);
        blockedLabel->setObjectName("blockedLabel");
        blockedLabel->setText(QString::fromUtf8("TextLabel"));
        blockedLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(blockedLabel, 3, 1, 1, 1);

        timesWrongCheckBox = new QCheckBox(ignoreGroupBox);
        timesWrongCheckBox->setObjectName("timesWrongCheckBox");
        timesWrongCheckBox->setChecked(false);

        _2->addWidget(timesWrongCheckBox, 4, 0, 1, 1);

        timesWrongLabel = new QLabel(ignoreGroupBox);
        timesWrongLabel->setObjectName("timesWrongLabel");
        timesWrongLabel->setText(QString::fromUtf8("TextLabel"));
        timesWrongLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(timesWrongLabel, 4, 1, 1, 1);

        timesPracticedCheckBox = new QCheckBox(ignoreGroupBox);
        timesPracticedCheckBox->setObjectName("timesPracticedCheckBox");
        timesPracticedCheckBox->setChecked(false);

        _2->addWidget(timesPracticedCheckBox, 5, 0, 1, 1);

        timesPracticedLabel = new QLabel(ignoreGroupBox);
        timesPracticedLabel->setObjectName("timesPracticedLabel");
        timesPracticedLabel->setText(QString::fromUtf8("TextLabel"));
        timesPracticedLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(timesPracticedLabel, 5, 1, 1, 1);

        minMaxGradeCheckBox = new QCheckBox(ignoreGroupBox);
        minMaxGradeCheckBox->setObjectName("minMaxGradeCheckBox");
        minMaxGradeCheckBox->setChecked(false);

        _2->addWidget(minMaxGradeCheckBox, 6, 0, 1, 1);

        minMaxGradeLabel = new QLabel(ignoreGroupBox);
        minMaxGradeLabel->setObjectName("minMaxGradeLabel");
        minMaxGradeLabel->setText(QString::fromUtf8("TextLabel"));
        minMaxGradeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(minMaxGradeLabel, 6, 1, 1, 1);

        numberAffectedWordsLabel = new QLabel(ignoreGroupBox);
        numberAffectedWordsLabel->setObjectName("numberAffectedWordsLabel");
        numberAffectedWordsLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        _2->addWidget(numberAffectedWordsLabel, 0, 1, 1, 1);


        verticalLayout->addWidget(ignoreGroupBox);

        documentTotalLayout = new QHBoxLayout();
        documentTotalLayout->setObjectName("documentTotalLayout");
        documentTotalDescriptionLabel = new QLabel(EntryFilterDialog);
        documentTotalDescriptionLabel->setObjectName("documentTotalDescriptionLabel");

        documentTotalLayout->addWidget(documentTotalDescriptionLabel);

        documentTotalLabel = new QLabel(EntryFilterDialog);
        documentTotalLabel->setObjectName("documentTotalLabel");
        documentTotalLabel->setText(QString::fromUtf8("TextLabel"));
        documentTotalLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        documentTotalLayout->addWidget(documentTotalLabel);


        verticalLayout->addLayout(documentTotalLayout);

        totalLayout = new QHBoxLayout();
        totalLayout->setObjectName("totalLayout");
        totalDescriptionLabel = new QLabel(EntryFilterDialog);
        totalDescriptionLabel->setObjectName("totalDescriptionLabel");

        totalLayout->addWidget(totalDescriptionLabel);

        totalLabel = new QLabel(EntryFilterDialog);
        totalLabel->setObjectName("totalLabel");
        totalLabel->setText(QString::fromUtf8("TextLabel"));
        totalLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        totalLayout->addWidget(totalLabel);


        verticalLayout->addLayout(totalLayout);

        spacer = new QSpacerItem(20, 57, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacer);

        buttonBox = new QDialogButtonBox(EntryFilterDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(EntryFilterDialog);

        QMetaObject::connectSlotsByName(EntryFilterDialog);
    } // setupUi

    void retranslateUi(QDialog *EntryFilterDialog)
    {
        EntryFilterDialog->setWindowTitle(tr2i18n("Start Practice", nullptr));
        headerLabel->setText(tr2i18n("<p>Your selection of vocabulary for the practice is empty.</p><p>Below you can choose to ignore some of your configuration settings to start a practice anyway.</p>", nullptr));
        ignoreGroupBox->setTitle(tr2i18n("Ignore Configuration for:", nullptr));
        lessonCheckBox->setText(tr2i18n("Ignore Lessons", nullptr));
        wordTypeCheckBox->setText(tr2i18n("Ignore Word Types", nullptr));
        blockedCheckBox->setText(tr2i18n("Ignore Blocked", nullptr));
        timesWrongCheckBox->setText(tr2i18n("Ignore Times Answered Incorrectly", nullptr));
        timesPracticedCheckBox->setText(tr2i18n("Ignore Times Practiced", nullptr));
        minMaxGradeCheckBox->setText(tr2i18n("Ignore Minimum/Maximum Grade", nullptr));
        numberAffectedWordsLabel->setText(tr2i18n("Number of Affected Words", nullptr));
        documentTotalDescriptionLabel->setText(tr2i18n("Total number of entries:", nullptr));
        totalDescriptionLabel->setText(tr2i18n("Resulting number of words to practice:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EntryFilterDialog: public Ui_EntryFilterDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENTRYFILTERDIALOG_H

