/********************************************************************************
** Form generated from reading UI file 'comparisonwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPARISONWIDGET_H
#define UI_COMPARISONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_comparisonWidget
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout;
    QLabel *absoluteLabel;
    QLabel *absoluteEntryLabel;
    QLabel *comparativeLabel;
    QLineEdit *comparativeLineEdit;
    QLabel *superlativeLabel;
    QLineEdit *superlativeLineEdit;
    QPushButton *makeAdjectiveButton;
    QPushButton *makeAdverbButton;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *comparisonWidget)
    {
        if (comparisonWidget->objectName().isEmpty())
            comparisonWidget->setObjectName("comparisonWidget");
        comparisonWidget->resize(175, 196);
        vboxLayout = new QVBoxLayout(comparisonWidget);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        absoluteLabel = new QLabel(comparisonWidget);
        absoluteLabel->setObjectName("absoluteLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(absoluteLabel->sizePolicy().hasHeightForWidth());
        absoluteLabel->setSizePolicy(sizePolicy);
        absoluteLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(absoluteLabel, 0, 0, 1, 1);

        absoluteEntryLabel = new QLabel(comparisonWidget);
        absoluteEntryLabel->setObjectName("absoluteEntryLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(absoluteEntryLabel->sizePolicy().hasHeightForWidth());
        absoluteEntryLabel->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(absoluteEntryLabel, 0, 1, 1, 1);

        comparativeLabel = new QLabel(comparisonWidget);
        comparativeLabel->setObjectName("comparativeLabel");
        sizePolicy.setHeightForWidth(comparativeLabel->sizePolicy().hasHeightForWidth());
        comparativeLabel->setSizePolicy(sizePolicy);
        comparativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(comparativeLabel, 1, 0, 1, 1);

        comparativeLineEdit = new QLineEdit(comparisonWidget);
        comparativeLineEdit->setObjectName("comparativeLineEdit");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(comparativeLineEdit->sizePolicy().hasHeightForWidth());
        comparativeLineEdit->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(comparativeLineEdit, 1, 1, 1, 1);

        superlativeLabel = new QLabel(comparisonWidget);
        superlativeLabel->setObjectName("superlativeLabel");
        sizePolicy.setHeightForWidth(superlativeLabel->sizePolicy().hasHeightForWidth());
        superlativeLabel->setSizePolicy(sizePolicy);
        superlativeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(superlativeLabel, 2, 0, 1, 1);

        superlativeLineEdit = new QLineEdit(comparisonWidget);
        superlativeLineEdit->setObjectName("superlativeLineEdit");
        sizePolicy2.setHeightForWidth(superlativeLineEdit->sizePolicy().hasHeightForWidth());
        superlativeLineEdit->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(superlativeLineEdit, 2, 1, 1, 1);


        vboxLayout->addLayout(gridLayout);

        makeAdjectiveButton = new QPushButton(comparisonWidget);
        makeAdjectiveButton->setObjectName("makeAdjectiveButton");

        vboxLayout->addWidget(makeAdjectiveButton);

        makeAdverbButton = new QPushButton(comparisonWidget);
        makeAdverbButton->setObjectName("makeAdverbButton");

        vboxLayout->addWidget(makeAdverbButton);

        spacerItem = new QSpacerItem(20, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);

#if QT_CONFIG(shortcut)
        comparativeLabel->setBuddy(comparativeLineEdit);
        superlativeLabel->setBuddy(superlativeLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(comparisonWidget);

        QMetaObject::connectSlotsByName(comparisonWidget);
    } // setupUi

    void retranslateUi(QWidget *comparisonWidget)
    {
#if QT_CONFIG(tooltip)
        absoluteLabel->setToolTip(tr2i18n("The comparative is used to compare nouns or verbs (faster)", nullptr));
#endif // QT_CONFIG(tooltip)
        absoluteLabel->setText(tr2i18n("Absolute:", nullptr));
        absoluteEntryLabel->setText(QString());
#if QT_CONFIG(tooltip)
        comparativeLabel->setToolTip(tr2i18n("The comparative is used to compare nouns or verbs (faster)", nullptr));
#endif // QT_CONFIG(tooltip)
        comparativeLabel->setText(tr2i18n("Comparative:", nullptr));
#if QT_CONFIG(tooltip)
        superlativeLabel->setToolTip(tr2i18n("The superlative (fastest)", nullptr));
#endif // QT_CONFIG(tooltip)
        superlativeLabel->setText(tr2i18n("Superlative:", nullptr));
        makeAdjectiveButton->setText(tr2i18n("Adjective", nullptr));
        makeAdverbButton->setText(tr2i18n("Adverb", nullptr));
        (void)comparisonWidget;
    } // retranslateUi

};

namespace Ui {
    class comparisonWidget: public Ui_comparisonWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPARISONWIDGET_H

