/****************************************************************************
** Meta object code from reading C++ file 'vocabularyview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../parley-26.04.0/src/editor/vocabularyview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'vocabularyview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Editor14VocabularyViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Editor::VocabularyView::qt_create_metaobjectdata<qt_meta_tag_ZN6Editor14VocabularyViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Editor::VocabularyView",
        "translationChanged",
        "",
        "KEduVocExpression*",
        "reset",
        "appendEntry",
        "deleteSelectedEntries",
        "askConfirmation",
        "slotEditCopy",
        "slotCutEntry",
        "slotEditPaste",
        "appendChar",
        "c",
        "setDocument",
        "std::shared_ptr<KEduVocDocument>",
        "doc",
        "checkSpelling",
        "language",
        "slotShowVocabularyColumnsDialog",
        "slotCurrentChanged",
        "QModelIndex",
        "current",
        "previous",
        "slotSelectionChanged",
        "QItemSelection",
        "continueSpelling",
        "misspelling",
        "word",
        "start",
        "spellingReplace",
        "oldWord",
        "newWord"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'translationChanged'
        QtMocHelpers::SignalData<void(KEduVocExpression *, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appendEntry'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteSelectedEntries'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'deleteSelectedEntries'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotEditCopy'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCutEntry'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditPaste'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appendChar'
        QtMocHelpers::SlotData<void(const QChar &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QChar, 12 },
        }}),
        // Slot 'setDocument'
        QtMocHelpers::SlotData<void(const std::shared_ptr<KEduVocDocument> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'checkSpelling'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'slotShowVocabularyColumnsDialog'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 20, 22 },
        }}),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 2 }, { 0x80000000 | 24, 2 },
        }}),
        // Slot 'continueSpelling'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'misspelling'
        QtMocHelpers::SlotData<void(const QString &, int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'spellingReplace'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 30 }, { QMetaType::Int, 28 }, { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VocabularyView, qt_meta_tag_ZN6Editor14VocabularyViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Editor::VocabularyView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTableView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor14VocabularyViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor14VocabularyViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Editor14VocabularyViewE_t>.metaTypes,
    nullptr
} };

void Editor::VocabularyView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VocabularyView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->translationChanged((*reinterpret_cast<std::add_pointer_t<KEduVocExpression*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->reset(); break;
        case 2: _t->appendEntry(); break;
        case 3: _t->deleteSelectedEntries((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->deleteSelectedEntries(); break;
        case 5: _t->slotEditCopy(); break;
        case 6: _t->slotCutEntry(); break;
        case 7: _t->slotEditPaste(); break;
        case 8: _t->appendChar((*reinterpret_cast<std::add_pointer_t<QChar>>(_a[1]))); break;
        case 9: _t->setDocument((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<KEduVocDocument>>>(_a[1]))); break;
        case 10: _t->checkSpelling((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->slotShowVocabularyColumnsDialog(); break;
        case 12: _t->slotCurrentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 13: _t->slotSelectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 14: _t->continueSpelling(); break;
        case 15: _t->misspelling((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->spellingReplace((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VocabularyView::*)(KEduVocExpression * , int )>(_a, &VocabularyView::translationChanged, 0))
            return;
    }
}

const QMetaObject *Editor::VocabularyView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Editor::VocabularyView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor14VocabularyViewE_t>.strings))
        return static_cast<void*>(this);
    return QTableView::qt_metacast(_clname);
}

int Editor::VocabularyView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTableView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Editor::VocabularyView::translationChanged(KEduVocExpression * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
