/****************************************************************************
** Meta object code from reading C++ file 'guifrontend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../parley-26.04.0/src/practice/guifrontend.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'guifrontend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Practice11GuiFrontendE_t {};
} // unnamed namespace

template <> constexpr inline auto Practice::GuiFrontend::qt_create_metaobjectdata<qt_meta_tag_ZN8Practice11GuiFrontendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Practice::GuiFrontend",
        "setMode",
        "",
        "Practice::AbstractFrontend::Mode",
        "mode",
        "showQuestion",
        "showSolution",
        "setBoxes",
        "grade_t",
        "currentBox",
        "newBoxIfCorrect",
        "newBoxIfWrong",
        "showSynonym",
        "backgroundChanged",
        "QPixmap",
        "pixmap",
        "showSetResultButtons",
        "show",
        "toggleResultState",
        "countAsCorrectButtonClicked",
        "countAsWrongButtonClicked",
        "updateBackground",
        "updateFontColors",
        "setTheme"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setMode'
        QtMocHelpers::SlotData<void(Practice::AbstractFrontend::Mode)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'showQuestion'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showSolution'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBoxes'
        QtMocHelpers::SlotData<void(grade_t, grade_t, grade_t)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 }, { 0x80000000 | 8, 11 },
        }}),
        // Slot 'showSynonym'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'backgroundChanged'
        QtMocHelpers::SlotData<void(const QPixmap &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'showSetResultButtons'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'toggleResultState'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'countAsCorrectButtonClicked'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'countAsWrongButtonClicked'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateBackground'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFontColors'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setTheme'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GuiFrontend, qt_meta_tag_ZN8Practice11GuiFrontendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Practice::GuiFrontend::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractFrontend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Practice11GuiFrontendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Practice11GuiFrontendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Practice11GuiFrontendE_t>.metaTypes,
    nullptr
} };

void Practice::GuiFrontend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GuiFrontend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setMode((*reinterpret_cast<std::add_pointer_t<Practice::AbstractFrontend::Mode>>(_a[1]))); break;
        case 1: _t->showQuestion(); break;
        case 2: _t->showSolution(); break;
        case 3: _t->setBoxes((*reinterpret_cast<std::add_pointer_t<grade_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<grade_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<grade_t>>(_a[3]))); break;
        case 4: _t->showSynonym(); break;
        case 5: _t->backgroundChanged((*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[1]))); break;
        case 6: _t->showSetResultButtons((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->toggleResultState(); break;
        case 8: _t->countAsCorrectButtonClicked(); break;
        case 9: _t->countAsWrongButtonClicked(); break;
        case 10: _t->updateBackground(); break;
        case 11: _t->updateFontColors(); break;
        case 12: _t->setTheme(); break;
        default: ;
        }
    }
}

const QMetaObject *Practice::GuiFrontend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Practice::GuiFrontend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Practice11GuiFrontendE_t>.strings))
        return static_cast<void*>(this);
    return AbstractFrontend::qt_metacast(_clname);
}

int Practice::GuiFrontend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractFrontend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
