/********************************************************************************
** Form generated from reading UI file 'practice_widget_multiplechoice.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRACTICE_WIDGET_MULTIPLECHOICE_H
#define UI_PRACTICE_WIDGET_MULTIPLECHOICE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "practice/audiobutton.h"

QT_BEGIN_NAMESPACE

class Ui_MultiplechoicePracticeWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *questionLabel;
    QLabel *questionPronunciationLabel;
    Practice::AudioButton *questionSoundButton;
    QLabel *feedbackLabel;
    QLabel *solutionPronunciationLabel;
    Practice::AudioButton *solutionSoundButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MultiplechoicePracticeWidget)
    {
        if (MultiplechoicePracticeWidget->objectName().isEmpty())
            MultiplechoicePracticeWidget->setObjectName("MultiplechoicePracticeWidget");
        MultiplechoicePracticeWidget->resize(403, 201);
        verticalLayout = new QVBoxLayout(MultiplechoicePracticeWidget);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        questionLabel = new QLabel(MultiplechoicePracticeWidget);
        questionLabel->setObjectName("questionLabel");
        questionLabel->setText(QString::fromUtf8("Baum"));
        questionLabel->setAlignment(Qt::AlignCenter);
        questionLabel->setWordWrap(true);
        questionLabel->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(questionLabel, 0, 0, 1, 1);

        questionPronunciationLabel = new QLabel(MultiplechoicePracticeWidget);
        questionPronunciationLabel->setObjectName("questionPronunciationLabel");
        questionPronunciationLabel->setText(QString::fromUtf8("[foo]"));
        questionPronunciationLabel->setAlignment(Qt::AlignCenter);
        questionPronunciationLabel->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(questionPronunciationLabel, 0, 1, 1, 1);

        questionSoundButton = new Practice::AudioButton(MultiplechoicePracticeWidget);
        questionSoundButton->setObjectName("questionSoundButton");
        questionSoundButton->setText(QString::fromUtf8("..."));
        questionSoundButton->setIconSize(QSize(40, 40));

        gridLayout->addWidget(questionSoundButton, 0, 2, 1, 1);

        feedbackLabel = new QLabel(MultiplechoicePracticeWidget);
        feedbackLabel->setObjectName("feedbackLabel");
        feedbackLabel->setText(QString::fromUtf8("Feedback"));

        gridLayout->addWidget(feedbackLabel, 1, 0, 1, 1);

        solutionPronunciationLabel = new QLabel(MultiplechoicePracticeWidget);
        solutionPronunciationLabel->setObjectName("solutionPronunciationLabel");
        solutionPronunciationLabel->setText(QString::fromUtf8("[foo]"));
        solutionPronunciationLabel->setAlignment(Qt::AlignCenter);
        solutionPronunciationLabel->setTextInteractionFlags(Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);

        gridLayout->addWidget(solutionPronunciationLabel, 2, 1, 1, 1);

        solutionSoundButton = new Practice::AudioButton(MultiplechoicePracticeWidget);
        solutionSoundButton->setObjectName("solutionSoundButton");
        solutionSoundButton->setText(QString::fromUtf8("..."));
        solutionSoundButton->setIconSize(QSize(40, 40));

        gridLayout->addWidget(solutionSoundButton, 2, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 1);

        gridLayout->setColumnStretch(0, 1);

        verticalLayout->addLayout(gridLayout);


        retranslateUi(MultiplechoicePracticeWidget);

        QMetaObject::connectSlotsByName(MultiplechoicePracticeWidget);
    } // setupUi

    void retranslateUi(QWidget *MultiplechoicePracticeWidget)
    {
        (void)MultiplechoicePracticeWidget;
    } // retranslateUi

};

namespace Ui {
    class MultiplechoicePracticeWidget: public Ui_MultiplechoicePracticeWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRACTICE_WIDGET_MULTIPLECHOICE_H

