/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.parley.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef PARLEYADAPTOR_H
#define PARLEYADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "editor/editor.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface local.Editor.EditorWindow
 */
class EditorWindowAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "local.Editor.EditorWindow")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"local.Editor.EditorWindow\">\n"
"    <method name=\"addWordWithTranslation\">\n"
"      <arg direction=\"in\" type=\"as\" name=\"w\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    EditorWindowAdaptor(Editor::EditorWindow *parent);
    ~EditorWindowAdaptor() override;

    inline Editor::EditorWindow *parent() const
    { return static_cast<Editor::EditorWindow *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void addWordWithTranslation(const QStringList &w);
Q_SIGNALS: // SIGNALS
};

#endif
