/********************************************************************************
** Form generated from reading UI file 'summarywordwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SUMMARYWORDWIDGET_H
#define UI_SUMMARYWORDWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SummaryWordWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *languageLabel;
    QLineEdit *wordEntry;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLineEdit *pronunciationEntry;
    QLabel *label_4;
    QLineEdit *exampleEntry;
    QLabel *label_5;
    QLineEdit *paraphraseEntry;
    QLabel *label_6;
    QLineEdit *commentEntry;
    KComboBox *wordTypeComboBox;
    QLabel *lessonLabel;

    void setupUi(QWidget *SummaryWordWidget)
    {
        if (SummaryWordWidget->objectName().isEmpty())
            SummaryWordWidget->setObjectName("SummaryWordWidget");
        SummaryWordWidget->resize(411, 236);
        gridLayout = new QGridLayout(SummaryWordWidget);
        gridLayout->setObjectName("gridLayout");
        languageLabel = new QLabel(SummaryWordWidget);
        languageLabel->setObjectName("languageLabel");
        languageLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(languageLabel, 0, 0, 1, 1);

        wordEntry = new QLineEdit(SummaryWordWidget);
        wordEntry->setObjectName("wordEntry");

        gridLayout->addWidget(wordEntry, 0, 2, 1, 1);

        label = new QLabel(SummaryWordWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        label_2 = new QLabel(SummaryWordWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        label_3 = new QLabel(SummaryWordWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        pronunciationEntry = new QLineEdit(SummaryWordWidget);
        pronunciationEntry->setObjectName("pronunciationEntry");

        gridLayout->addWidget(pronunciationEntry, 3, 2, 1, 1);

        label_4 = new QLabel(SummaryWordWidget);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 4, 0, 1, 1);

        exampleEntry = new QLineEdit(SummaryWordWidget);
        exampleEntry->setObjectName("exampleEntry");

        gridLayout->addWidget(exampleEntry, 4, 2, 1, 1);

        label_5 = new QLabel(SummaryWordWidget);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 5, 0, 1, 1);

        paraphraseEntry = new QLineEdit(SummaryWordWidget);
        paraphraseEntry->setObjectName("paraphraseEntry");

        gridLayout->addWidget(paraphraseEntry, 5, 2, 1, 1);

        label_6 = new QLabel(SummaryWordWidget);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 6, 0, 1, 1);

        commentEntry = new QLineEdit(SummaryWordWidget);
        commentEntry->setObjectName("commentEntry");

        gridLayout->addWidget(commentEntry, 6, 2, 1, 1);

        wordTypeComboBox = new KComboBox(SummaryWordWidget);
        wordTypeComboBox->setObjectName("wordTypeComboBox");

        gridLayout->addWidget(wordTypeComboBox, 2, 2, 1, 1);

        lessonLabel = new QLabel(SummaryWordWidget);
        lessonLabel->setObjectName("lessonLabel");

        gridLayout->addWidget(lessonLabel, 1, 2, 1, 1);

#if QT_CONFIG(shortcut)
        languageLabel->setBuddy(wordEntry);
        label_2->setBuddy(wordTypeComboBox);
        label_3->setBuddy(pronunciationEntry);
        label_4->setBuddy(exampleEntry);
        label_5->setBuddy(paraphraseEntry);
        label_6->setBuddy(commentEntry);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SummaryWordWidget);

        QMetaObject::connectSlotsByName(SummaryWordWidget);
    } // setupUi

    void retranslateUi(QWidget *SummaryWordWidget)
    {
        languageLabel->setText(tr2i18n("Language", nullptr));
        label->setText(tr2i18n("Lesson", nullptr));
        label_2->setText(tr2i18n("Word type:", nullptr));
        label_3->setText(tr2i18n("Pronunciation:", nullptr));
        label_4->setText(tr2i18n("Example:", nullptr));
        label_5->setText(tr2i18n("Paraphrase:", nullptr));
        label_6->setText(tr2i18n("Comment:", nullptr));
        lessonLabel->setText(QString());
        (void)SummaryWordWidget;
    } // retranslateUi

};

namespace Ui {
    class SummaryWordWidget: public Ui_SummaryWordWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SUMMARYWORDWIDGET_H

