/********************************************************************************
** Form generated from reading UI file 'generalpracticeoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALPRACTICEOPTIONS_H
#define UI_GENERALPRACTICEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GeneralPracticeOptions
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_4;
    QCheckBox *kcfg_IgnoreAccentMistakes;
    QCheckBox *kcfg_IgnoreCapitalizationMistakes;
    QCheckBox *kcfg_IgnorePunctuationMistakes;
    QCheckBox *kcfg_ShowHints;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_4;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *kcfg_FlashcardsFrontImage;
    QCheckBox *kcfg_FlashcardsBackImage;
    QCheckBox *kcfg_AllowImageInsteadOfWord;
    QCheckBox *kcfg_PracticeSoundEnabled;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QCheckBox *kcfg_CountSynonymsAsCorrect;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label_4;
    QSpinBox *kcfg_SessionMaxSize;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_5;
    QSpinBox *kcfg_SessionMaxNewWords;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *GeneralPracticeOptions)
    {
        if (GeneralPracticeOptions->objectName().isEmpty())
            GeneralPracticeOptions->setObjectName("GeneralPracticeOptions");
        GeneralPracticeOptions->resize(558, 364);
        gridLayout = new QGridLayout(GeneralPracticeOptions);
        gridLayout->setObjectName("gridLayout");
        groupBox_3 = new QGroupBox(GeneralPracticeOptions);
        groupBox_3->setObjectName("groupBox_3");
        verticalLayout_4 = new QVBoxLayout(groupBox_3);
        verticalLayout_4->setObjectName("verticalLayout_4");
        kcfg_IgnoreAccentMistakes = new QCheckBox(groupBox_3);
        kcfg_IgnoreAccentMistakes->setObjectName("kcfg_IgnoreAccentMistakes");
        kcfg_IgnoreAccentMistakes->setChecked(true);

        verticalLayout_4->addWidget(kcfg_IgnoreAccentMistakes);

        kcfg_IgnoreCapitalizationMistakes = new QCheckBox(groupBox_3);
        kcfg_IgnoreCapitalizationMistakes->setObjectName("kcfg_IgnoreCapitalizationMistakes");
        kcfg_IgnoreCapitalizationMistakes->setChecked(true);

        verticalLayout_4->addWidget(kcfg_IgnoreCapitalizationMistakes);

        kcfg_IgnorePunctuationMistakes = new QCheckBox(groupBox_3);
        kcfg_IgnorePunctuationMistakes->setObjectName("kcfg_IgnorePunctuationMistakes");
        kcfg_IgnorePunctuationMistakes->setChecked(true);

        verticalLayout_4->addWidget(kcfg_IgnorePunctuationMistakes);

        kcfg_ShowHints = new QCheckBox(groupBox_3);
        kcfg_ShowHints->setObjectName("kcfg_ShowHints");
        kcfg_ShowHints->setChecked(true);

        verticalLayout_4->addWidget(kcfg_ShowHints);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);


        gridLayout->addWidget(groupBox_3, 0, 0, 1, 1);

        groupBox_4 = new QGroupBox(GeneralPracticeOptions);
        groupBox_4->setObjectName("groupBox_4");
        verticalLayout_3 = new QVBoxLayout(groupBox_4);
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_FlashcardsFrontImage = new QCheckBox(groupBox_4);
        kcfg_FlashcardsFrontImage->setObjectName("kcfg_FlashcardsFrontImage");
        kcfg_FlashcardsFrontImage->setChecked(true);

        verticalLayout_3->addWidget(kcfg_FlashcardsFrontImage);

        kcfg_FlashcardsBackImage = new QCheckBox(groupBox_4);
        kcfg_FlashcardsBackImage->setObjectName("kcfg_FlashcardsBackImage");
        kcfg_FlashcardsBackImage->setChecked(true);

        verticalLayout_3->addWidget(kcfg_FlashcardsBackImage);

        kcfg_AllowImageInsteadOfWord = new QCheckBox(groupBox_4);
        kcfg_AllowImageInsteadOfWord->setObjectName("kcfg_AllowImageInsteadOfWord");
        kcfg_AllowImageInsteadOfWord->setChecked(true);

        verticalLayout_3->addWidget(kcfg_AllowImageInsteadOfWord);

        kcfg_PracticeSoundEnabled = new QCheckBox(groupBox_4);
        kcfg_PracticeSoundEnabled->setObjectName("kcfg_PracticeSoundEnabled");
        kcfg_PracticeSoundEnabled->setChecked(true);

        verticalLayout_3->addWidget(kcfg_PracticeSoundEnabled);


        gridLayout->addWidget(groupBox_4, 0, 1, 1, 1);

        groupBox = new QGroupBox(GeneralPracticeOptions);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        kcfg_CountSynonymsAsCorrect = new QCheckBox(groupBox);
        kcfg_CountSynonymsAsCorrect->setObjectName("kcfg_CountSynonymsAsCorrect");

        verticalLayout->addWidget(kcfg_CountSynonymsAsCorrect);


        gridLayout->addWidget(groupBox, 2, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 3, 0, 1, 2);

        groupBox_2 = new QGroupBox(GeneralPracticeOptions);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");
        label_4->setLineWidth(1);
        label_4->setIndent(0);

        horizontalLayout->addWidget(label_4);

        kcfg_SessionMaxSize = new QSpinBox(groupBox_2);
        kcfg_SessionMaxSize->setObjectName("kcfg_SessionMaxSize");
        kcfg_SessionMaxSize->setMaximumSize(QSize(74, 16777215));
        kcfg_SessionMaxSize->setMinimum(5);
        kcfg_SessionMaxSize->setMaximum(100);
        kcfg_SessionMaxSize->setValue(20);

        horizontalLayout->addWidget(kcfg_SessionMaxSize);

        horizontalSpacer = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");
        label_5->setLineWidth(1);
        label_5->setIndent(0);

        horizontalLayout_2->addWidget(label_5);

        kcfg_SessionMaxNewWords = new QSpinBox(groupBox_2);
        kcfg_SessionMaxNewWords->setObjectName("kcfg_SessionMaxNewWords");
        kcfg_SessionMaxNewWords->setMaximumSize(QSize(74, 16777215));
        kcfg_SessionMaxNewWords->setMinimum(2);
        kcfg_SessionMaxNewWords->setMaximum(20);
        kcfg_SessionMaxNewWords->setValue(5);

        horizontalLayout_2->addWidget(kcfg_SessionMaxNewWords);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout_2);


        gridLayout->addWidget(groupBox_2, 1, 0, 1, 2);


        retranslateUi(GeneralPracticeOptions);

        QMetaObject::connectSlotsByName(GeneralPracticeOptions);
    } // setupUi

    void retranslateUi(QWidget *GeneralPracticeOptions)
    {
        groupBox_3->setTitle(tr2i18n("Correction", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_IgnoreAccentMistakes->setToolTip(tr2i18n("Answers with wrong accents are still counted as correct.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_IgnoreAccentMistakes->setText(tr2i18n("Ignore accents", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_IgnoreCapitalizationMistakes->setToolTip(tr2i18n("Any captitalization in the answer is counted as correct.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_IgnoreCapitalizationMistakes->setText(tr2i18n("Ignore capitalization", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_IgnorePunctuationMistakes->setToolTip(tr2i18n("Any punctuation mistake in the answer is counted as correct.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_IgnorePunctuationMistakes->setText(tr2i18n("Ignore punctuation", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_ShowHints->setToolTip(tr2i18n("During the practice you can use the hint button to see parts of the solution.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_ShowHints->setText(tr2i18n("Enable hints", nullptr));
        groupBox_4->setTitle(tr2i18n("Images and Sound", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FlashcardsFrontImage->setToolTip(tr2i18n("During the practice, images are shown for the question.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FlashcardsFrontImage->setText(tr2i18n("Image for question", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_FlashcardsBackImage->setToolTip(tr2i18n("During the practice, images are shown for the solution.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_FlashcardsBackImage->setText(tr2i18n("Image for solution", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_AllowImageInsteadOfWord->setToolTip(tr2i18n("Allow using images instead of words in flashcards.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_AllowImageInsteadOfWord->setText(tr2i18n("Allow images instead of words", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_PracticeSoundEnabled->setToolTip(tr2i18n("Enable playing of pronunciation sound files during the practice.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_PracticeSoundEnabled->setText(tr2i18n("Sound", nullptr));
        groupBox->setTitle(tr2i18n("Synonyms", nullptr));
        label->setText(tr2i18n("By default you are asked to enter synonyms until you enter the one that is associated directly with the current word. With this option enabled any synonym is accepted.", nullptr));
        kcfg_CountSynonymsAsCorrect->setText(tr2i18n("Accept any synonym", nullptr));
        groupBox_2->setTitle(tr2i18n("Sessions", nullptr));
        label_4->setText(tr2i18n("Max session size:", nullptr));
        label_5->setText(tr2i18n("Max number of new words:", nullptr));
        (void)GeneralPracticeOptions;
    } // retranslateUi

};

namespace Ui {
    class GeneralPracticeOptions: public Ui_GeneralPracticeOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALPRACTICEOPTIONS_H

