/********************************************************************************
** Form generated from reading UI file 'conjugationwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONJUGATIONWIDGET_H
#define UI_CONJUGATIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ConjugationWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *layout;
    QGridLayout *gridLayout;
    QLabel *singularFirstPersonLabel;
    QLineEdit *singularFirstPersonLineEdit;
    QLabel *singularSecondPersonLabel;
    QLineEdit *singularSecondPersonLineEdit;
    QLabel *singularThirdMalePersonLabel;
    QLineEdit *singularThirdMalePersonLineEdit;
    QLabel *singularThirdFemalePersonLabel;
    QLineEdit *singularThirdFemalePersonLineEdit;
    QLabel *singularThirdNeutralPersonLabel;
    QLineEdit *singularThirdNeutralPersonLineEdit;
    QLabel *dualFirstPersonLabel;
    QLineEdit *dualFirstPersonLineEdit;
    QLabel *dualSecondPersonLabel;
    QLineEdit *dualSecondPersonLineEdit;
    QLabel *dualThirdMalePersonLabel;
    QLabel *dualThirdFemalePersonLabel;
    QLineEdit *dualThirdFemalePersonLineEdit;
    QLabel *dualThirdNeutralPersonLabel;
    QLineEdit *dualThirdNeutralPersonLineEdit;
    QLabel *pluralFirstPersonLabel;
    QLineEdit *pluralFirstPersonLineEdit;
    QLabel *pluralSecondPersonLabel;
    QLineEdit *pluralSecondPersonLineEdit;
    QLabel *pluralThirdMalePersonLabel;
    QLineEdit *dualThirdMalePersonLineEdit;
    QLineEdit *pluralThirdMalePersonLineEdit;
    QLabel *pluralThirdFemalePersonLabel;
    QLineEdit *pluralThirdFemalePersonLineEdit;
    QLineEdit *pluralThirdNeutralPersonLineEdit;
    QLabel *pluralThirdNeutralPersonLabel;
    KComboBox *tenseComboBox;
    QPushButton *nextTenseButton;
    QLabel *tenselabel;
    QLabel *singularLabel;
    QLabel *dualLabel;
    QLabel *pluralLabel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ConjugationWidget)
    {
        if (ConjugationWidget->objectName().isEmpty())
            ConjugationWidget->setObjectName("ConjugationWidget");
        ConjugationWidget->resize(296, 535);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ConjugationWidget->sizePolicy().hasHeightForWidth());
        ConjugationWidget->setSizePolicy(sizePolicy);
        ConjugationWidget->setMinimumSize(QSize(0, 0));
        verticalLayout = new QVBoxLayout(ConjugationWidget);
        verticalLayout->setObjectName("verticalLayout");
        layout = new QGroupBox(ConjugationWidget);
        layout->setObjectName("layout");
        gridLayout = new QGridLayout(layout);
        gridLayout->setObjectName("gridLayout");
        singularFirstPersonLabel = new QLabel(layout);
        singularFirstPersonLabel->setObjectName("singularFirstPersonLabel");
        singularFirstPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(singularFirstPersonLabel, 2, 0, 1, 1);

        singularFirstPersonLineEdit = new QLineEdit(layout);
        singularFirstPersonLineEdit->setObjectName("singularFirstPersonLineEdit");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(singularFirstPersonLineEdit->sizePolicy().hasHeightForWidth());
        singularFirstPersonLineEdit->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(singularFirstPersonLineEdit, 2, 1, 1, 2);

        singularSecondPersonLabel = new QLabel(layout);
        singularSecondPersonLabel->setObjectName("singularSecondPersonLabel");
        singularSecondPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(singularSecondPersonLabel, 3, 0, 1, 1);

        singularSecondPersonLineEdit = new QLineEdit(layout);
        singularSecondPersonLineEdit->setObjectName("singularSecondPersonLineEdit");
        sizePolicy1.setHeightForWidth(singularSecondPersonLineEdit->sizePolicy().hasHeightForWidth());
        singularSecondPersonLineEdit->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(singularSecondPersonLineEdit, 3, 1, 1, 2);

        singularThirdMalePersonLabel = new QLabel(layout);
        singularThirdMalePersonLabel->setObjectName("singularThirdMalePersonLabel");
        singularThirdMalePersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(singularThirdMalePersonLabel, 4, 0, 1, 1);

        singularThirdMalePersonLineEdit = new QLineEdit(layout);
        singularThirdMalePersonLineEdit->setObjectName("singularThirdMalePersonLineEdit");

        gridLayout->addWidget(singularThirdMalePersonLineEdit, 4, 1, 1, 2);

        singularThirdFemalePersonLabel = new QLabel(layout);
        singularThirdFemalePersonLabel->setObjectName("singularThirdFemalePersonLabel");
        singularThirdFemalePersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(singularThirdFemalePersonLabel, 5, 0, 1, 1);

        singularThirdFemalePersonLineEdit = new QLineEdit(layout);
        singularThirdFemalePersonLineEdit->setObjectName("singularThirdFemalePersonLineEdit");

        gridLayout->addWidget(singularThirdFemalePersonLineEdit, 5, 1, 1, 2);

        singularThirdNeutralPersonLabel = new QLabel(layout);
        singularThirdNeutralPersonLabel->setObjectName("singularThirdNeutralPersonLabel");
        singularThirdNeutralPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(singularThirdNeutralPersonLabel, 6, 0, 1, 1);

        singularThirdNeutralPersonLineEdit = new QLineEdit(layout);
        singularThirdNeutralPersonLineEdit->setObjectName("singularThirdNeutralPersonLineEdit");

        gridLayout->addWidget(singularThirdNeutralPersonLineEdit, 6, 1, 1, 2);

        dualFirstPersonLabel = new QLabel(layout);
        dualFirstPersonLabel->setObjectName("dualFirstPersonLabel");
        dualFirstPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dualFirstPersonLabel, 9, 0, 1, 1);

        dualFirstPersonLineEdit = new QLineEdit(layout);
        dualFirstPersonLineEdit->setObjectName("dualFirstPersonLineEdit");

        gridLayout->addWidget(dualFirstPersonLineEdit, 9, 1, 1, 2);

        dualSecondPersonLabel = new QLabel(layout);
        dualSecondPersonLabel->setObjectName("dualSecondPersonLabel");
        dualSecondPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dualSecondPersonLabel, 10, 0, 1, 1);

        dualSecondPersonLineEdit = new QLineEdit(layout);
        dualSecondPersonLineEdit->setObjectName("dualSecondPersonLineEdit");

        gridLayout->addWidget(dualSecondPersonLineEdit, 10, 1, 1, 2);

        dualThirdMalePersonLabel = new QLabel(layout);
        dualThirdMalePersonLabel->setObjectName("dualThirdMalePersonLabel");
        dualThirdMalePersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dualThirdMalePersonLabel, 11, 0, 1, 1);

        dualThirdFemalePersonLabel = new QLabel(layout);
        dualThirdFemalePersonLabel->setObjectName("dualThirdFemalePersonLabel");
        dualThirdFemalePersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dualThirdFemalePersonLabel, 12, 0, 1, 1);

        dualThirdFemalePersonLineEdit = new QLineEdit(layout);
        dualThirdFemalePersonLineEdit->setObjectName("dualThirdFemalePersonLineEdit");

        gridLayout->addWidget(dualThirdFemalePersonLineEdit, 12, 1, 1, 2);

        dualThirdNeutralPersonLabel = new QLabel(layout);
        dualThirdNeutralPersonLabel->setObjectName("dualThirdNeutralPersonLabel");
        dualThirdNeutralPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dualThirdNeutralPersonLabel, 13, 0, 1, 1);

        dualThirdNeutralPersonLineEdit = new QLineEdit(layout);
        dualThirdNeutralPersonLineEdit->setObjectName("dualThirdNeutralPersonLineEdit");

        gridLayout->addWidget(dualThirdNeutralPersonLineEdit, 13, 1, 1, 2);

        pluralFirstPersonLabel = new QLabel(layout);
        pluralFirstPersonLabel->setObjectName("pluralFirstPersonLabel");
        pluralFirstPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(pluralFirstPersonLabel, 15, 0, 1, 1);

        pluralFirstPersonLineEdit = new QLineEdit(layout);
        pluralFirstPersonLineEdit->setObjectName("pluralFirstPersonLineEdit");

        gridLayout->addWidget(pluralFirstPersonLineEdit, 15, 1, 1, 2);

        pluralSecondPersonLabel = new QLabel(layout);
        pluralSecondPersonLabel->setObjectName("pluralSecondPersonLabel");
        pluralSecondPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(pluralSecondPersonLabel, 16, 0, 1, 1);

        pluralSecondPersonLineEdit = new QLineEdit(layout);
        pluralSecondPersonLineEdit->setObjectName("pluralSecondPersonLineEdit");

        gridLayout->addWidget(pluralSecondPersonLineEdit, 16, 1, 1, 2);

        pluralThirdMalePersonLabel = new QLabel(layout);
        pluralThirdMalePersonLabel->setObjectName("pluralThirdMalePersonLabel");
        pluralThirdMalePersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(pluralThirdMalePersonLabel, 17, 0, 1, 1);

        dualThirdMalePersonLineEdit = new QLineEdit(layout);
        dualThirdMalePersonLineEdit->setObjectName("dualThirdMalePersonLineEdit");

        gridLayout->addWidget(dualThirdMalePersonLineEdit, 11, 1, 1, 2);

        pluralThirdMalePersonLineEdit = new QLineEdit(layout);
        pluralThirdMalePersonLineEdit->setObjectName("pluralThirdMalePersonLineEdit");

        gridLayout->addWidget(pluralThirdMalePersonLineEdit, 17, 1, 1, 2);

        pluralThirdFemalePersonLabel = new QLabel(layout);
        pluralThirdFemalePersonLabel->setObjectName("pluralThirdFemalePersonLabel");
        pluralThirdFemalePersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(pluralThirdFemalePersonLabel, 18, 0, 1, 1);

        pluralThirdFemalePersonLineEdit = new QLineEdit(layout);
        pluralThirdFemalePersonLineEdit->setObjectName("pluralThirdFemalePersonLineEdit");

        gridLayout->addWidget(pluralThirdFemalePersonLineEdit, 18, 1, 1, 2);

        pluralThirdNeutralPersonLineEdit = new QLineEdit(layout);
        pluralThirdNeutralPersonLineEdit->setObjectName("pluralThirdNeutralPersonLineEdit");

        gridLayout->addWidget(pluralThirdNeutralPersonLineEdit, 19, 1, 1, 2);

        pluralThirdNeutralPersonLabel = new QLabel(layout);
        pluralThirdNeutralPersonLabel->setObjectName("pluralThirdNeutralPersonLabel");
        pluralThirdNeutralPersonLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(pluralThirdNeutralPersonLabel, 19, 0, 1, 1);

        tenseComboBox = new KComboBox(layout);
        tenseComboBox->setObjectName("tenseComboBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tenseComboBox->sizePolicy().hasHeightForWidth());
        tenseComboBox->setSizePolicy(sizePolicy2);
        tenseComboBox->setEditable(true);
        tenseComboBox->setMaxVisibleItems(20);

        gridLayout->addWidget(tenseComboBox, 0, 1, 1, 1);

        nextTenseButton = new QPushButton(layout);
        nextTenseButton->setObjectName("nextTenseButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(nextTenseButton->sizePolicy().hasHeightForWidth());
        nextTenseButton->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(nextTenseButton, 0, 2, 1, 1);

        tenselabel = new QLabel(layout);
        tenselabel->setObjectName("tenselabel");
        sizePolicy.setHeightForWidth(tenselabel->sizePolicy().hasHeightForWidth());
        tenselabel->setSizePolicy(sizePolicy);
        tenselabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(tenselabel, 0, 0, 1, 1);

        singularLabel = new QLabel(layout);
        singularLabel->setObjectName("singularLabel");
        QFont font;
        font.setBold(true);
        singularLabel->setFont(font);
        singularLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(singularLabel, 1, 1, 1, 1);

        dualLabel = new QLabel(layout);
        dualLabel->setObjectName("dualLabel");
        dualLabel->setFont(font);
        dualLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(dualLabel, 7, 1, 1, 1);

        pluralLabel = new QLabel(layout);
        pluralLabel->setObjectName("pluralLabel");
        pluralLabel->setFont(font);
        pluralLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(pluralLabel, 14, 1, 1, 1);


        verticalLayout->addWidget(layout);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        singularFirstPersonLabel->setBuddy(singularFirstPersonLineEdit);
        singularSecondPersonLabel->setBuddy(singularSecondPersonLineEdit);
        singularThirdMalePersonLabel->setBuddy(singularThirdMalePersonLineEdit);
        singularThirdFemalePersonLabel->setBuddy(singularThirdFemalePersonLineEdit);
        singularThirdNeutralPersonLabel->setBuddy(singularThirdNeutralPersonLineEdit);
        dualFirstPersonLabel->setBuddy(dualFirstPersonLineEdit);
        dualSecondPersonLabel->setBuddy(dualSecondPersonLineEdit);
        dualThirdMalePersonLabel->setBuddy(dualThirdMalePersonLineEdit);
        dualThirdFemalePersonLabel->setBuddy(dualThirdFemalePersonLineEdit);
        dualThirdNeutralPersonLabel->setBuddy(dualThirdNeutralPersonLineEdit);
        pluralFirstPersonLabel->setBuddy(pluralFirstPersonLineEdit);
        pluralSecondPersonLabel->setBuddy(pluralSecondPersonLineEdit);
        pluralThirdMalePersonLabel->setBuddy(pluralThirdMalePersonLineEdit);
        pluralThirdFemalePersonLabel->setBuddy(pluralThirdFemalePersonLineEdit);
        pluralThirdNeutralPersonLabel->setBuddy(pluralThirdNeutralPersonLineEdit);
        tenselabel->setBuddy(tenseComboBox);
        singularLabel->setBuddy(singularFirstPersonLineEdit);
        dualLabel->setBuddy(dualFirstPersonLineEdit);
        pluralLabel->setBuddy(pluralFirstPersonLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ConjugationWidget);

        tenseComboBox->setCurrentIndex(-1);


        QMetaObject::connectSlotsByName(ConjugationWidget);
    } // setupUi

    void retranslateUi(QWidget *ConjugationWidget)
    {
        ConjugationWidget->setWindowTitle(tr2i18n("-", nullptr));
        layout->setTitle(tr2i18n("Conjugation Forms", nullptr));
        singularFirstPersonLabel->setText(tr2i18n("First", nullptr));
        singularSecondPersonLabel->setText(tr2i18n("Second", nullptr));
        singularThirdMalePersonLabel->setText(tr2i18n("Third Male", nullptr));
        singularThirdFemalePersonLabel->setText(tr2i18n("Third Female", nullptr));
        singularThirdNeutralPersonLabel->setText(tr2i18n("Third Neutral", nullptr));
        dualFirstPersonLabel->setText(tr2i18n("First", nullptr));
        dualSecondPersonLabel->setText(tr2i18n("Second", nullptr));
        dualThirdMalePersonLabel->setText(tr2i18n("Third Male", nullptr));
        dualThirdFemalePersonLabel->setText(tr2i18n("Third Female", nullptr));
        dualThirdNeutralPersonLabel->setText(tr2i18n("Third Neutral", nullptr));
        pluralFirstPersonLabel->setText(tr2i18n("First", nullptr));
        pluralSecondPersonLabel->setText(tr2i18n("Second", nullptr));
        pluralThirdMalePersonLabel->setText(tr2i18n("Third Male", nullptr));
        pluralThirdFemalePersonLabel->setText(tr2i18n("Third Female", nullptr));
        pluralThirdNeutralPersonLabel->setText(tr2i18n("Third Neutral", nullptr));
        nextTenseButton->setText(tr2i18n("Ne&xt", nullptr));
        tenselabel->setText(tr2i18n("&Tense:", nullptr));
        singularLabel->setText(tr2i18n("Singular", nullptr));
        dualLabel->setText(tr2i18n("Dual", nullptr));
        pluralLabel->setText(tr2i18n("Plural", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ConjugationWidget: public Ui_ConjugationWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONJUGATIONWIDGET_H

