/****************************************************************************
** Meta object code from reading C++ file 'wordtypeview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../parley-26.04.0/src/editor/wordtypeview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wordtypeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Editor12WordTypeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Editor::WordTypeView::qt_create_metaobjectdata<qt_meta_tag_ZN6Editor12WordTypeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Editor::WordTypeView",
        "selectedWordTypeChanged",
        "",
        "KEduVocWordType*",
        "wordType",
        "slotCreateNewWordType",
        "slotDeleteWordType",
        "setTranslation",
        "KEduVocExpression*",
        "entry",
        "translationId",
        "setWordTypeNone",
        "setWordTypeNoun",
        "setWordTypeNounMale",
        "setWordTypeNounFemale",
        "setWordTypeNounNeutral",
        "setWordTypeAdjective",
        "setWordTypeAdverb",
        "setWordTypeVerb",
        "setWordTypeConjunction"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectedWordTypeChanged'
        QtMocHelpers::SignalData<void(KEduVocWordType *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotCreateNewWordType'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteWordType'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTranslation'
        QtMocHelpers::SlotData<void(KEduVocExpression *, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'setWordTypeNone'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeNoun'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeNounMale'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeNounFemale'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeNounNeutral'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeAdjective'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeAdverb'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeVerb'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWordTypeConjunction'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WordTypeView, qt_meta_tag_ZN6Editor12WordTypeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Editor::WordTypeView::staticMetaObject = { {
    QMetaObject::SuperData::link<ContainerView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor12WordTypeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor12WordTypeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Editor12WordTypeViewE_t>.metaTypes,
    nullptr
} };

void Editor::WordTypeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WordTypeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectedWordTypeChanged((*reinterpret_cast<std::add_pointer_t<KEduVocWordType*>>(_a[1]))); break;
        case 1: _t->slotCreateNewWordType(); break;
        case 2: _t->slotDeleteWordType(); break;
        case 3: _t->setTranslation((*reinterpret_cast<std::add_pointer_t<KEduVocExpression*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->setWordTypeNone(); break;
        case 5: _t->setWordTypeNoun(); break;
        case 6: _t->setWordTypeNounMale(); break;
        case 7: _t->setWordTypeNounFemale(); break;
        case 8: _t->setWordTypeNounNeutral(); break;
        case 9: _t->setWordTypeAdjective(); break;
        case 10: _t->setWordTypeAdverb(); break;
        case 11: _t->setWordTypeVerb(); break;
        case 12: _t->setWordTypeConjunction(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WordTypeView::*)(KEduVocWordType * )>(_a, &WordTypeView::selectedWordTypeChanged, 0))
            return;
    }
}

const QMetaObject *Editor::WordTypeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Editor::WordTypeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor12WordTypeViewE_t>.strings))
        return static_cast<void*>(this);
    return ContainerView::qt_metacast(_clname);
}

int Editor::WordTypeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ContainerView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Editor::WordTypeView::selectedWordTypeChanged(KEduVocWordType * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
