/********************************************************************************
** Form generated from reading UI file 'statisticsmainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STATISTICSMAINWINDOW_H
#define UI_STATISTICSMAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "statistics/lessonstatisticsview.h"
#include "statistics/statisticslegendwidget.h"

QT_BEGIN_NAMESPACE

class Ui_StatisticsMainWindow
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBoxLanguages;
    QVBoxLayout *verticalLayout_3;
    QLabel *label;
    QComboBox *learnedLanguage;
    QLabel *label_3;
    QComboBox *knownLanguage;
    QSplitter *splitter;
    LessonStatisticsView *lessonStatistics;
    StatisticsLegendWidget *statisticsLegend;
    QGroupBox *groupBoxPracticeMode;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *flashCard;
    QRadioButton *mixedLetters;
    QRadioButton *multipleChoice;
    QRadioButton *written;
    QRadioButton *exampleSentence;
    QRadioButton *gender;
    QRadioButton *comparisonForms;
    QRadioButton *conjugations;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QWidget *modeSpecificOptions;
    QGroupBox *groupBoxPracticeDirection;
    QVBoxLayout *verticalLayout;
    QComboBox *practiceDirection;
    QCheckBox *rememberPracticeDirection;

    void setupUi(QWidget *StatisticsMainWindow)
    {
        if (StatisticsMainWindow->objectName().isEmpty())
            StatisticsMainWindow->setObjectName("StatisticsMainWindow");
        StatisticsMainWindow->resize(602, 580);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(StatisticsMainWindow->sizePolicy().hasHeightForWidth());
        StatisticsMainWindow->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(StatisticsMainWindow);
        gridLayout->setObjectName("gridLayout");
        groupBoxLanguages = new QGroupBox(StatisticsMainWindow);
        groupBoxLanguages->setObjectName("groupBoxLanguages");
        verticalLayout_3 = new QVBoxLayout(groupBoxLanguages);
        verticalLayout_3->setObjectName("verticalLayout_3");
        label = new QLabel(groupBoxLanguages);
        label->setObjectName("label");

        verticalLayout_3->addWidget(label);

        learnedLanguage = new QComboBox(groupBoxLanguages);
        learnedLanguage->setObjectName("learnedLanguage");

        verticalLayout_3->addWidget(learnedLanguage);

        label_3 = new QLabel(groupBoxLanguages);
        label_3->setObjectName("label_3");

        verticalLayout_3->addWidget(label_3);

        knownLanguage = new QComboBox(groupBoxLanguages);
        knownLanguage->setObjectName("knownLanguage");

        verticalLayout_3->addWidget(knownLanguage);


        gridLayout->addWidget(groupBoxLanguages, 0, 0, 1, 1);

        splitter = new QSplitter(StatisticsMainWindow);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        lessonStatistics = new LessonStatisticsView(splitter);
        lessonStatistics->setObjectName("lessonStatistics");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(lessonStatistics->sizePolicy().hasHeightForWidth());
        lessonStatistics->setSizePolicy(sizePolicy1);
        splitter->addWidget(lessonStatistics);
        statisticsLegend = new StatisticsLegendWidget(splitter);
        statisticsLegend->setObjectName("statisticsLegend");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(statisticsLegend->sizePolicy().hasHeightForWidth());
        statisticsLegend->setSizePolicy(sizePolicy2);
        splitter->addWidget(statisticsLegend);

        gridLayout->addWidget(splitter, 0, 1, 4, 1);

        groupBoxPracticeMode = new QGroupBox(StatisticsMainWindow);
        groupBoxPracticeMode->setObjectName("groupBoxPracticeMode");
        verticalLayout_2 = new QVBoxLayout(groupBoxPracticeMode);
        verticalLayout_2->setObjectName("verticalLayout_2");
        flashCard = new QRadioButton(groupBoxPracticeMode);
        flashCard->setObjectName("flashCard");
        flashCard->setChecked(true);

        verticalLayout_2->addWidget(flashCard);

        mixedLetters = new QRadioButton(groupBoxPracticeMode);
        mixedLetters->setObjectName("mixedLetters");

        verticalLayout_2->addWidget(mixedLetters);

        multipleChoice = new QRadioButton(groupBoxPracticeMode);
        multipleChoice->setObjectName("multipleChoice");

        verticalLayout_2->addWidget(multipleChoice);

        written = new QRadioButton(groupBoxPracticeMode);
        written->setObjectName("written");

        verticalLayout_2->addWidget(written);

        exampleSentence = new QRadioButton(groupBoxPracticeMode);
        exampleSentence->setObjectName("exampleSentence");
        exampleSentence->setEnabled(true);

        verticalLayout_2->addWidget(exampleSentence);

        gender = new QRadioButton(groupBoxPracticeMode);
        gender->setObjectName("gender");
        gender->setEnabled(true);

        verticalLayout_2->addWidget(gender);

        comparisonForms = new QRadioButton(groupBoxPracticeMode);
        comparisonForms->setObjectName("comparisonForms");
        comparisonForms->setEnabled(true);

        verticalLayout_2->addWidget(comparisonForms);

        conjugations = new QRadioButton(groupBoxPracticeMode);
        conjugations->setObjectName("conjugations");
        conjugations->setEnabled(true);

        verticalLayout_2->addWidget(conjugations);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        modeSpecificOptions = new QWidget(groupBoxPracticeMode);
        modeSpecificOptions->setObjectName("modeSpecificOptions");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(modeSpecificOptions->sizePolicy().hasHeightForWidth());
        modeSpecificOptions->setSizePolicy(sizePolicy3);
        modeSpecificOptions->setMaximumSize(QSize(200, 16777215));

        horizontalLayout->addWidget(modeSpecificOptions);


        verticalLayout_2->addLayout(horizontalLayout);


        gridLayout->addWidget(groupBoxPracticeMode, 1, 0, 1, 1);

        groupBoxPracticeDirection = new QGroupBox(StatisticsMainWindow);
        groupBoxPracticeDirection->setObjectName("groupBoxPracticeDirection");
        verticalLayout = new QVBoxLayout(groupBoxPracticeDirection);
        verticalLayout->setObjectName("verticalLayout");
        practiceDirection = new QComboBox(groupBoxPracticeDirection);
        practiceDirection->setObjectName("practiceDirection");

        verticalLayout->addWidget(practiceDirection);

        rememberPracticeDirection = new QCheckBox(groupBoxPracticeDirection);
        rememberPracticeDirection->setObjectName("rememberPracticeDirection");

        verticalLayout->addWidget(rememberPracticeDirection);


        gridLayout->addWidget(groupBoxPracticeDirection, 2, 0, 1, 1);

        gridLayout->setColumnStretch(1, 1);

        retranslateUi(StatisticsMainWindow);

        QMetaObject::connectSlotsByName(StatisticsMainWindow);
    } // setupUi

    void retranslateUi(QWidget *StatisticsMainWindow)
    {
        groupBoxLanguages->setTitle(tr2i18n("Languages", nullptr));
        label->setText(tr2i18n("Language to Learn", nullptr));
        label_3->setText(tr2i18n("Known Language", nullptr));
        groupBoxPracticeMode->setTitle(tr2i18n("Practice Mode", nullptr));
        flashCard->setText(tr2i18n("Flash Cards", nullptr));
        mixedLetters->setText(tr2i18n("Mixed &Letters", nullptr));
        multipleChoice->setText(tr2i18n("M&ultiple Choice", nullptr));
        written->setText(tr2i18n("Wri&tten", nullptr));
        exampleSentence->setText(tr2i18n("E&xample Sentences", nullptr));
        gender->setText(tr2i18n("&Gender of Nouns", nullptr));
        comparisonForms->setText(tr2i18n("Comparison Forms", nullptr));
        conjugations->setText(tr2i18n("Co&njugations", nullptr));
        groupBoxPracticeDirection->setTitle(tr2i18n("Practice Direction", nullptr));
        rememberPracticeDirection->setText(tr2i18n("Remember for each Practice Mode", nullptr));
        (void)StatisticsMainWindow;
    } // retranslateUi

};

namespace Ui {
    class StatisticsMainWindow: public Ui_StatisticsMainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STATISTICSMAINWINDOW_H

