/****************************************************************************
** Meta object code from reading C++ file 'lessonview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../parley-26.04.0/src/editor/lessonview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lessonview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Editor10LessonViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Editor::LessonView::qt_create_metaobjectdata<qt_meta_tag_ZN6Editor10LessonViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Editor::LessonView",
        "selectedLessonChanged",
        "",
        "KEduVocLesson*",
        "lesson",
        "signalShowContainer",
        "KEduVocContainer*",
        "selected",
        "lessonsInPracticeChanged",
        "slotCreateNewLesson",
        "slotDeleteLesson",
        "slotSplitLesson",
        "moveToNewLesson",
        "slotRemoveGradesLesson",
        "slotRemoveGradesLessonChildren",
        "columnsInserted",
        "setTranslation",
        "KEduVocExpression*",
        "entry",
        "translationId",
        "expandAllLesson",
        "collapseAllLesson",
        "selectionChanged",
        "QItemSelection",
        "deselected",
        "currentChanged",
        "QModelIndex",
        "current",
        "previous"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectedLessonChanged'
        QtMocHelpers::SignalData<void(KEduVocLesson *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'signalShowContainer'
        QtMocHelpers::SignalData<void(KEduVocContainer *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'lessonsInPracticeChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCreateNewLesson'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteLesson'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSplitLesson'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveToNewLesson'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveGradesLesson'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRemoveGradesLessonChildren'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'columnsInserted'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setTranslation'
        QtMocHelpers::SlotData<void(KEduVocExpression *, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'expandAllLesson'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'collapseAllLesson'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 23, 7 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'currentChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 26, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LessonView, qt_meta_tag_ZN6Editor10LessonViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Editor::LessonView::staticMetaObject = { {
    QMetaObject::SuperData::link<ContainerView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor10LessonViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor10LessonViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Editor10LessonViewE_t>.metaTypes,
    nullptr
} };

void Editor::LessonView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LessonView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectedLessonChanged((*reinterpret_cast<std::add_pointer_t<KEduVocLesson*>>(_a[1]))); break;
        case 1: _t->signalShowContainer((*reinterpret_cast<std::add_pointer_t<KEduVocContainer*>>(_a[1]))); break;
        case 2: _t->lessonsInPracticeChanged(); break;
        case 3: _t->slotCreateNewLesson(); break;
        case 4: _t->slotDeleteLesson(); break;
        case 5: _t->slotSplitLesson(); break;
        case 6: _t->moveToNewLesson(); break;
        case 7: _t->slotRemoveGradesLesson(); break;
        case 8: _t->slotRemoveGradesLessonChildren(); break;
        case 9: _t->columnsInserted(); break;
        case 10: _t->setTranslation((*reinterpret_cast<std::add_pointer_t<KEduVocExpression*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->expandAllLesson(); break;
        case 12: _t->collapseAllLesson(); break;
        case 13: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 14: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LessonView::*)(KEduVocLesson * )>(_a, &LessonView::selectedLessonChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonView::*)(KEduVocContainer * )>(_a, &LessonView::signalShowContainer, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LessonView::*)()>(_a, &LessonView::lessonsInPracticeChanged, 2))
            return;
    }
}

const QMetaObject *Editor::LessonView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Editor::LessonView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Editor10LessonViewE_t>.strings))
        return static_cast<void*>(this);
    return ContainerView::qt_metacast(_clname);
}

int Editor::LessonView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ContainerView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Editor::LessonView::selectedLessonChanged(KEduVocLesson * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Editor::LessonView::signalShowContainer(KEduVocContainer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Editor::LessonView::lessonsInPracticeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
