// This file is generated by kconfig_compiler_kf6 from languagesettings.kcfg.
// All changes you do to this file will be lost.

#include "languagesettings.h"

LanguageSettings::LanguageSettings( const QString & locale )
  : KConfigSkeleton( QStringLiteral( "parleyrc" ) )
  , mParamlocale(locale)
{
  setCurrentGroup( QStringLiteral( "Locale %1" ).arg( mParamlocale ) );

  mKeyboardLayoutItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "KeyboardLayout" ), mKeyboardLayout );
  mKeyboardLayoutItem->setLabel( QCoreApplication::translate("LanguageSettings", "Keyboard layout for this locale") );
  mKeyboardLayoutItem->setWhatsThis( QCoreApplication::translate("LanguageSettings", "Keyboard layout for this locale") );
  addItem( mKeyboardLayoutItem, QStringLiteral( "KeyboardLayout" ) );
  mSpellCheckerItem = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "SpellChecker" ), mSpellChecker );
  mSpellCheckerItem->setLabel( QCoreApplication::translate("LanguageSettings", "Spell checker for this language") );
  mSpellCheckerItem->setWhatsThis( QCoreApplication::translate("LanguageSettings", "Spell checker for this language") );
  addItem( mSpellCheckerItem, QStringLiteral( "SpellChecker" ) );
  mConjugationTensesItem = new KConfigSkeleton::ItemStringList( currentGroup(), QStringLiteral( "ConjugationTenses" ), mConjugationTenses );
  mConjugationTensesItem->setLabel( QCoreApplication::translate("LanguageSettings", "Selected tenses for conjugation practice.") );
  mConjugationTensesItem->setWhatsThis( QCoreApplication::translate("LanguageSettings", "Selected tenses for conjugation practice.") );
  addItem( mConjugationTensesItem, QStringLiteral( "ConjugationTenses" ) );
  QList<int> defaultVisibleColumns;

  mVisibleColumnsItem = new KConfigSkeleton::ItemIntList( currentGroup(), QStringLiteral( "VisibleColumns" ), mVisibleColumns, defaultVisibleColumns );
  mVisibleColumnsItem->setLabel( QCoreApplication::translate("LanguageSettings", "Visible columns in the main editor window.") );
  mVisibleColumnsItem->setWhatsThis( QCoreApplication::translate("LanguageSettings", "Visible columns in the main editor window.") );
  addItem( mVisibleColumnsItem, QStringLiteral( "VisibleColumns" ) );
  mPracticeFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "PracticeFont" ), mPracticeFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont) );
  mPracticeFontItem->setLabel( QCoreApplication::translate("LanguageSettings", "The font used during practice") );
  addItem( mPracticeFontItem, QStringLiteral( "PracticeFont" ) );
  mEditorFontItem = new KConfigSkeleton::ItemFont( currentGroup(), QStringLiteral( "EditorFont" ), mEditorFont, QFontDatabase::systemFont(QFontDatabase::GeneralFont) );
  mEditorFontItem->setLabel( QCoreApplication::translate("LanguageSettings", "The font used in the editor") );
  addItem( mEditorFontItem, QStringLiteral( "EditorFont" ) );
}

LanguageSettings::~LanguageSettings()
{
}

