/********************************************************************************
** Form generated from reading UI file 'practicesummarywidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRACTICESUMMARYWIDGET_H
#define UI_PRACTICESUMMARYWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "practice/summarybarwidget.h"

QT_BEGIN_NAMESPACE

class Ui_PracticeSummaryWidget
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *testSummaryLabel;
    Practice::SummaryBarWidget *summaryBar;
    QTableWidget *tableWidget;

    void setupUi(QWidget *PracticeSummaryWidget)
    {
        if (PracticeSummaryWidget->objectName().isEmpty())
            PracticeSummaryWidget->setObjectName("PracticeSummaryWidget");
        PracticeSummaryWidget->resize(625, 565);
        verticalLayout = new QVBoxLayout(PracticeSummaryWidget);
        verticalLayout->setObjectName("verticalLayout");
        testSummaryLabel = new QLabel(PracticeSummaryWidget);
        testSummaryLabel->setObjectName("testSummaryLabel");

        verticalLayout->addWidget(testSummaryLabel);

        summaryBar = new Practice::SummaryBarWidget(PracticeSummaryWidget);
        summaryBar->setObjectName("summaryBar");

        verticalLayout->addWidget(summaryBar);

        tableWidget = new QTableWidget(PracticeSummaryWidget);
        if (tableWidget->columnCount() < 4)
            tableWidget->setColumnCount(4);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        tableWidget->setObjectName("tableWidget");

        verticalLayout->addWidget(tableWidget);


        retranslateUi(PracticeSummaryWidget);

        QMetaObject::connectSlotsByName(PracticeSummaryWidget);
    } // setupUi

    void retranslateUi(QWidget *PracticeSummaryWidget)
    {
        testSummaryLabel->setText(QString());
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Attempts", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("Question", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Solution", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidget->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(tr2i18n("Your Answer", nullptr));
        (void)PracticeSummaryWidget;
    } // retranslateUi

};

namespace Ui {
    class PracticeSummaryWidget: public Ui_PracticeSummaryWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRACTICESUMMARYWIDGET_H

